var Ai = { exports: {} }, M = {};
/**
 * @license React
 * react.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
var Xn = Symbol.for("react.element"), tc = Symbol.for("react.portal"), nc = Symbol.for("react.fragment"), rc = Symbol.for("react.strict_mode"), lc = Symbol.for("react.profiler"), oc = Symbol.for("react.provider"), uc = Symbol.for("react.context"), ic = Symbol.for("react.forward_ref"), sc = Symbol.for("react.suspense"), ac = Symbol.for("react.memo"), cc = Symbol.for("react.lazy"), Ou = Symbol.iterator;
function fc(e) {
  return e === null || typeof e != "object" ? null : (e = Ou && e[Ou] || e["@@iterator"], typeof e == "function" ? e : null);
}
var Hi = { isMounted: function() {
  return !1;
}, enqueueForceUpdate: function() {
}, enqueueReplaceState: function() {
}, enqueueSetState: function() {
} }, Wi = Object.assign, Qi = {};
function ln(e, t, n) {
  this.props = e, this.context = t, this.refs = Qi, this.updater = n || Hi;
}
ln.prototype.isReactComponent = {};
ln.prototype.setState = function(e, t) {
  if (typeof e != "object" && typeof e != "function" && e != null) throw Error("setState(...): takes an object of state variables to update or a function which returns an object of state variables.");
  this.updater.enqueueSetState(this, e, t, "setState");
};
ln.prototype.forceUpdate = function(e) {
  this.updater.enqueueForceUpdate(this, e, "forceUpdate");
};
function Ki() {
}
Ki.prototype = ln.prototype;
function Uo(e, t, n) {
  this.props = e, this.context = t, this.refs = Qi, this.updater = n || Hi;
}
var $o = Uo.prototype = new Ki();
$o.constructor = Uo;
Wi($o, ln.prototype);
$o.isPureReactComponent = !0;
var Du = Array.isArray, Yi = Object.prototype.hasOwnProperty, Bo = { current: null }, Xi = { key: !0, ref: !0, __self: !0, __source: !0 };
function Gi(e, t, n) {
  var r, l = {}, o = null, u = null;
  if (t != null) for (r in t.ref !== void 0 && (u = t.ref), t.key !== void 0 && (o = "" + t.key), t) Yi.call(t, r) && !Xi.hasOwnProperty(r) && (l[r] = t[r]);
  var i = arguments.length - 2;
  if (i === 1) l.children = n;
  else if (1 < i) {
    for (var s = Array(i), c = 0; c < i; c++) s[c] = arguments[c + 2];
    l.children = s;
  }
  if (e && e.defaultProps) for (r in i = e.defaultProps, i) l[r] === void 0 && (l[r] = i[r]);
  return { $$typeof: Xn, type: e, key: o, ref: u, props: l, _owner: Bo.current };
}
function dc(e, t) {
  return { $$typeof: Xn, type: e.type, key: t, ref: e.ref, props: e.props, _owner: e._owner };
}
function Vo(e) {
  return typeof e == "object" && e !== null && e.$$typeof === Xn;
}
function pc(e) {
  var t = { "=": "=0", ":": "=2" };
  return "$" + e.replace(/[=:]/g, function(n) {
    return t[n];
  });
}
var Iu = /\/+/g;
function gl(e, t) {
  return typeof e == "object" && e !== null && e.key != null ? pc("" + e.key) : t.toString(36);
}
function gr(e, t, n, r, l) {
  var o = typeof e;
  (o === "undefined" || o === "boolean") && (e = null);
  var u = !1;
  if (e === null) u = !0;
  else switch (o) {
    case "string":
    case "number":
      u = !0;
      break;
    case "object":
      switch (e.$$typeof) {
        case Xn:
        case tc:
          u = !0;
      }
  }
  if (u) return u = e, l = l(u), e = r === "" ? "." + gl(u, 0) : r, Du(l) ? (n = "", e != null && (n = e.replace(Iu, "$&/") + "/"), gr(l, t, n, "", function(c) {
    return c;
  })) : l != null && (Vo(l) && (l = dc(l, n + (!l.key || u && u.key === l.key ? "" : ("" + l.key).replace(Iu, "$&/") + "/") + e)), t.push(l)), 1;
  if (u = 0, r = r === "" ? "." : r + ":", Du(e)) for (var i = 0; i < e.length; i++) {
    o = e[i];
    var s = r + gl(o, i);
    u += gr(o, t, n, s, l);
  }
  else if (s = fc(e), typeof s == "function") for (e = s.call(e), i = 0; !(o = e.next()).done; ) o = o.value, s = r + gl(o, i++), u += gr(o, t, n, s, l);
  else if (o === "object") throw t = String(e), Error("Objects are not valid as a React child (found: " + (t === "[object Object]" ? "object with keys {" + Object.keys(e).join(", ") + "}" : t) + "). If you meant to render a collection of children, use an array instead.");
  return u;
}
function tr(e, t, n) {
  if (e == null) return e;
  var r = [], l = 0;
  return gr(e, r, "", "", function(o) {
    return t.call(n, o, l++);
  }), r;
}
function mc(e) {
  if (e._status === -1) {
    var t = e._result;
    t = t(), t.then(function(n) {
      (e._status === 0 || e._status === -1) && (e._status = 1, e._result = n);
    }, function(n) {
      (e._status === 0 || e._status === -1) && (e._status = 2, e._result = n);
    }), e._status === -1 && (e._status = 0, e._result = t);
  }
  if (e._status === 1) return e._result.default;
  throw e._result;
}
var ie = { current: null }, wr = { transition: null }, vc = { ReactCurrentDispatcher: ie, ReactCurrentBatchConfig: wr, ReactCurrentOwner: Bo };
function Zi() {
  throw Error("act(...) is not supported in production builds of React.");
}
M.Children = { map: tr, forEach: function(e, t, n) {
  tr(e, function() {
    t.apply(this, arguments);
  }, n);
}, count: function(e) {
  var t = 0;
  return tr(e, function() {
    t++;
  }), t;
}, toArray: function(e) {
  return tr(e, function(t) {
    return t;
  }) || [];
}, only: function(e) {
  if (!Vo(e)) throw Error("React.Children.only expected to receive a single React element child.");
  return e;
} };
M.Component = ln;
M.Fragment = nc;
M.Profiler = lc;
M.PureComponent = Uo;
M.StrictMode = rc;
M.Suspense = sc;
M.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED = vc;
M.act = Zi;
M.cloneElement = function(e, t, n) {
  if (e == null) throw Error("React.cloneElement(...): The argument must be a React element, but you passed " + e + ".");
  var r = Wi({}, e.props), l = e.key, o = e.ref, u = e._owner;
  if (t != null) {
    if (t.ref !== void 0 && (o = t.ref, u = Bo.current), t.key !== void 0 && (l = "" + t.key), e.type && e.type.defaultProps) var i = e.type.defaultProps;
    for (s in t) Yi.call(t, s) && !Xi.hasOwnProperty(s) && (r[s] = t[s] === void 0 && i !== void 0 ? i[s] : t[s]);
  }
  var s = arguments.length - 2;
  if (s === 1) r.children = n;
  else if (1 < s) {
    i = Array(s);
    for (var c = 0; c < s; c++) i[c] = arguments[c + 2];
    r.children = i;
  }
  return { $$typeof: Xn, type: e.type, key: l, ref: o, props: r, _owner: u };
};
M.createContext = function(e) {
  return e = { $$typeof: uc, _currentValue: e, _currentValue2: e, _threadCount: 0, Provider: null, Consumer: null, _defaultValue: null, _globalName: null }, e.Provider = { $$typeof: oc, _context: e }, e.Consumer = e;
};
M.createElement = Gi;
M.createFactory = function(e) {
  var t = Gi.bind(null, e);
  return t.type = e, t;
};
M.createRef = function() {
  return { current: null };
};
M.forwardRef = function(e) {
  return { $$typeof: ic, render: e };
};
M.isValidElement = Vo;
M.lazy = function(e) {
  return { $$typeof: cc, _payload: { _status: -1, _result: e }, _init: mc };
};
M.memo = function(e, t) {
  return { $$typeof: ac, type: e, compare: t === void 0 ? null : t };
};
M.startTransition = function(e) {
  var t = wr.transition;
  wr.transition = {};
  try {
    e();
  } finally {
    wr.transition = t;
  }
};
M.unstable_act = Zi;
M.useCallback = function(e, t) {
  return ie.current.useCallback(e, t);
};
M.useContext = function(e) {
  return ie.current.useContext(e);
};
M.useDebugValue = function() {
};
M.useDeferredValue = function(e) {
  return ie.current.useDeferredValue(e);
};
M.useEffect = function(e, t) {
  return ie.current.useEffect(e, t);
};
M.useId = function() {
  return ie.current.useId();
};
M.useImperativeHandle = function(e, t, n) {
  return ie.current.useImperativeHandle(e, t, n);
};
M.useInsertionEffect = function(e, t) {
  return ie.current.useInsertionEffect(e, t);
};
M.useLayoutEffect = function(e, t) {
  return ie.current.useLayoutEffect(e, t);
};
M.useMemo = function(e, t) {
  return ie.current.useMemo(e, t);
};
M.useReducer = function(e, t, n) {
  return ie.current.useReducer(e, t, n);
};
M.useRef = function(e) {
  return ie.current.useRef(e);
};
M.useState = function(e) {
  return ie.current.useState(e);
};
M.useSyncExternalStore = function(e, t, n) {
  return ie.current.useSyncExternalStore(e, t, n);
};
M.useTransition = function() {
  return ie.current.useTransition();
};
M.version = "18.3.1";
Ai.exports = M;
var w = Ai.exports, Ji = { exports: {} }, we = {}, qi = { exports: {} }, bi = {};
/**
 * @license React
 * scheduler.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
(function(e) {
  function t(C, P) {
    var L = C.length;
    C.push(P);
    e: for (; 0 < L; ) {
      var W = L - 1 >>> 1, G = C[W];
      if (0 < l(G, P)) C[W] = P, C[L] = G, L = W;
      else break e;
    }
  }
  function n(C) {
    return C.length === 0 ? null : C[0];
  }
  function r(C) {
    if (C.length === 0) return null;
    var P = C[0], L = C.pop();
    if (L !== P) {
      C[0] = L;
      e: for (var W = 0, G = C.length, bn = G >>> 1; W < bn; ) {
        var ht = 2 * (W + 1) - 1, yl = C[ht], yt = ht + 1, er = C[yt];
        if (0 > l(yl, L)) yt < G && 0 > l(er, yl) ? (C[W] = er, C[yt] = L, W = yt) : (C[W] = yl, C[ht] = L, W = ht);
        else if (yt < G && 0 > l(er, L)) C[W] = er, C[yt] = L, W = yt;
        else break e;
      }
    }
    return P;
  }
  function l(C, P) {
    var L = C.sortIndex - P.sortIndex;
    return L !== 0 ? L : C.id - P.id;
  }
  if (typeof performance == "object" && typeof performance.now == "function") {
    var o = performance;
    e.unstable_now = function() {
      return o.now();
    };
  } else {
    var u = Date, i = u.now();
    e.unstable_now = function() {
      return u.now() - i;
    };
  }
  var s = [], c = [], v = 1, m = null, p = 3, g = !1, k = !1, S = !1, O = typeof setTimeout == "function" ? setTimeout : null, f = typeof clearTimeout == "function" ? clearTimeout : null, a = typeof setImmediate < "u" ? setImmediate : null;
  typeof navigator < "u" && navigator.scheduling !== void 0 && navigator.scheduling.isInputPending !== void 0 && navigator.scheduling.isInputPending.bind(navigator.scheduling);
  function d(C) {
    for (var P = n(c); P !== null; ) {
      if (P.callback === null) r(c);
      else if (P.startTime <= C) r(c), P.sortIndex = P.expirationTime, t(s, P);
      else break;
      P = n(c);
    }
  }
  function h(C) {
    if (S = !1, d(C), !k) if (n(s) !== null) k = !0, vl(E);
    else {
      var P = n(c);
      P !== null && hl(h, P.startTime - C);
    }
  }
  function E(C, P) {
    k = !1, S && (S = !1, f(z), z = -1), g = !0;
    var L = p;
    try {
      for (d(P), m = n(s); m !== null && (!(m.expirationTime > P) || C && !ze()); ) {
        var W = m.callback;
        if (typeof W == "function") {
          m.callback = null, p = m.priorityLevel;
          var G = W(m.expirationTime <= P);
          P = e.unstable_now(), typeof G == "function" ? m.callback = G : m === n(s) && r(s), d(P);
        } else r(s);
        m = n(s);
      }
      if (m !== null) var bn = !0;
      else {
        var ht = n(c);
        ht !== null && hl(h, ht.startTime - P), bn = !1;
      }
      return bn;
    } finally {
      m = null, p = L, g = !1;
    }
  }
  var _ = !1, N = null, z = -1, F = 5, T = -1;
  function ze() {
    return !(e.unstable_now() - T < F);
  }
  function sn() {
    if (N !== null) {
      var C = e.unstable_now();
      T = C;
      var P = !0;
      try {
        P = N(!0, C);
      } finally {
        P ? an() : (_ = !1, N = null);
      }
    } else _ = !1;
  }
  var an;
  if (typeof a == "function") an = function() {
    a(sn);
  };
  else if (typeof MessageChannel < "u") {
    var Ru = new MessageChannel(), ec = Ru.port2;
    Ru.port1.onmessage = sn, an = function() {
      ec.postMessage(null);
    };
  } else an = function() {
    O(sn, 0);
  };
  function vl(C) {
    N = C, _ || (_ = !0, an());
  }
  function hl(C, P) {
    z = O(function() {
      C(e.unstable_now());
    }, P);
  }
  e.unstable_IdlePriority = 5, e.unstable_ImmediatePriority = 1, e.unstable_LowPriority = 4, e.unstable_NormalPriority = 3, e.unstable_Profiling = null, e.unstable_UserBlockingPriority = 2, e.unstable_cancelCallback = function(C) {
    C.callback = null;
  }, e.unstable_continueExecution = function() {
    k || g || (k = !0, vl(E));
  }, e.unstable_forceFrameRate = function(C) {
    0 > C || 125 < C ? console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported") : F = 0 < C ? Math.floor(1e3 / C) : 5;
  }, e.unstable_getCurrentPriorityLevel = function() {
    return p;
  }, e.unstable_getFirstCallbackNode = function() {
    return n(s);
  }, e.unstable_next = function(C) {
    switch (p) {
      case 1:
      case 2:
      case 3:
        var P = 3;
        break;
      default:
        P = p;
    }
    var L = p;
    p = P;
    try {
      return C();
    } finally {
      p = L;
    }
  }, e.unstable_pauseExecution = function() {
  }, e.unstable_requestPaint = function() {
  }, e.unstable_runWithPriority = function(C, P) {
    switch (C) {
      case 1:
      case 2:
      case 3:
      case 4:
      case 5:
        break;
      default:
        C = 3;
    }
    var L = p;
    p = C;
    try {
      return P();
    } finally {
      p = L;
    }
  }, e.unstable_scheduleCallback = function(C, P, L) {
    var W = e.unstable_now();
    switch (typeof L == "object" && L !== null ? (L = L.delay, L = typeof L == "number" && 0 < L ? W + L : W) : L = W, C) {
      case 1:
        var G = -1;
        break;
      case 2:
        G = 250;
        break;
      case 5:
        G = 1073741823;
        break;
      case 4:
        G = 1e4;
        break;
      default:
        G = 5e3;
    }
    return G = L + G, C = { id: v++, callback: P, priorityLevel: C, startTime: L, expirationTime: G, sortIndex: -1 }, L > W ? (C.sortIndex = L, t(c, C), n(s) === null && C === n(c) && (S ? (f(z), z = -1) : S = !0, hl(h, L - W))) : (C.sortIndex = G, t(s, C), k || g || (k = !0, vl(E))), C;
  }, e.unstable_shouldYield = ze, e.unstable_wrapCallback = function(C) {
    var P = p;
    return function() {
      var L = p;
      p = P;
      try {
        return C.apply(this, arguments);
      } finally {
        p = L;
      }
    };
  };
})(bi);
qi.exports = bi;
var hc = qi.exports;
/**
 * @license React
 * react-dom.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
var yc = w, ge = hc;
function y(e) {
  for (var t = "https://reactjs.org/docs/error-decoder.html?invariant=" + e, n = 1; n < arguments.length; n++) t += "&args[]=" + encodeURIComponent(arguments[n]);
  return "Minified React error #" + e + "; visit " + t + " for the full message or use the non-minified dev environment for full errors and additional helpful warnings.";
}
var es = /* @__PURE__ */ new Set(), Mn = {};
function Tt(e, t) {
  Jt(e, t), Jt(e + "Capture", t);
}
function Jt(e, t) {
  for (Mn[e] = t, e = 0; e < t.length; e++) es.add(t[e]);
}
var Qe = !(typeof window > "u" || typeof window.document > "u" || typeof window.document.createElement > "u"), Wl = Object.prototype.hasOwnProperty, gc = /^[:A-Z_a-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD][:A-Z_a-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD\-.0-9\u00B7\u0300-\u036F\u203F-\u2040]*$/, Fu = {}, ju = {};
function wc(e) {
  return Wl.call(ju, e) ? !0 : Wl.call(Fu, e) ? !1 : gc.test(e) ? ju[e] = !0 : (Fu[e] = !0, !1);
}
function kc(e, t, n, r) {
  if (n !== null && n.type === 0) return !1;
  switch (typeof t) {
    case "function":
    case "symbol":
      return !0;
    case "boolean":
      return r ? !1 : n !== null ? !n.acceptsBooleans : (e = e.toLowerCase().slice(0, 5), e !== "data-" && e !== "aria-");
    default:
      return !1;
  }
}
function Sc(e, t, n, r) {
  if (t === null || typeof t > "u" || kc(e, t, n, r)) return !0;
  if (r) return !1;
  if (n !== null) switch (n.type) {
    case 3:
      return !t;
    case 4:
      return t === !1;
    case 5:
      return isNaN(t);
    case 6:
      return isNaN(t) || 1 > t;
  }
  return !1;
}
function se(e, t, n, r, l, o, u) {
  this.acceptsBooleans = t === 2 || t === 3 || t === 4, this.attributeName = r, this.attributeNamespace = l, this.mustUseProperty = n, this.propertyName = e, this.type = t, this.sanitizeURL = o, this.removeEmptyString = u;
}
var ee = {};
"children dangerouslySetInnerHTML defaultValue defaultChecked innerHTML suppressContentEditableWarning suppressHydrationWarning style".split(" ").forEach(function(e) {
  ee[e] = new se(e, 0, !1, e, null, !1, !1);
});
[["acceptCharset", "accept-charset"], ["className", "class"], ["htmlFor", "for"], ["httpEquiv", "http-equiv"]].forEach(function(e) {
  var t = e[0];
  ee[t] = new se(t, 1, !1, e[1], null, !1, !1);
});
["contentEditable", "draggable", "spellCheck", "value"].forEach(function(e) {
  ee[e] = new se(e, 2, !1, e.toLowerCase(), null, !1, !1);
});
["autoReverse", "externalResourcesRequired", "focusable", "preserveAlpha"].forEach(function(e) {
  ee[e] = new se(e, 2, !1, e, null, !1, !1);
});
"allowFullScreen async autoFocus autoPlay controls default defer disabled disablePictureInPicture disableRemotePlayback formNoValidate hidden loop noModule noValidate open playsInline readOnly required reversed scoped seamless itemScope".split(" ").forEach(function(e) {
  ee[e] = new se(e, 3, !1, e.toLowerCase(), null, !1, !1);
});
["checked", "multiple", "muted", "selected"].forEach(function(e) {
  ee[e] = new se(e, 3, !0, e, null, !1, !1);
});
["capture", "download"].forEach(function(e) {
  ee[e] = new se(e, 4, !1, e, null, !1, !1);
});
["cols", "rows", "size", "span"].forEach(function(e) {
  ee[e] = new se(e, 6, !1, e, null, !1, !1);
});
["rowSpan", "start"].forEach(function(e) {
  ee[e] = new se(e, 5, !1, e.toLowerCase(), null, !1, !1);
});
var Ao = /[\-:]([a-z])/g;
function Ho(e) {
  return e[1].toUpperCase();
}
"accent-height alignment-baseline arabic-form baseline-shift cap-height clip-path clip-rule color-interpolation color-interpolation-filters color-profile color-rendering dominant-baseline enable-background fill-opacity fill-rule flood-color flood-opacity font-family font-size font-size-adjust font-stretch font-style font-variant font-weight glyph-name glyph-orientation-horizontal glyph-orientation-vertical horiz-adv-x horiz-origin-x image-rendering letter-spacing lighting-color marker-end marker-mid marker-start overline-position overline-thickness paint-order panose-1 pointer-events rendering-intent shape-rendering stop-color stop-opacity strikethrough-position strikethrough-thickness stroke-dasharray stroke-dashoffset stroke-linecap stroke-linejoin stroke-miterlimit stroke-opacity stroke-width text-anchor text-decoration text-rendering underline-position underline-thickness unicode-bidi unicode-range units-per-em v-alphabetic v-hanging v-ideographic v-mathematical vector-effect vert-adv-y vert-origin-x vert-origin-y word-spacing writing-mode xmlns:xlink x-height".split(" ").forEach(function(e) {
  var t = e.replace(
    Ao,
    Ho
  );
  ee[t] = new se(t, 1, !1, e, null, !1, !1);
});
"xlink:actuate xlink:arcrole xlink:role xlink:show xlink:title xlink:type".split(" ").forEach(function(e) {
  var t = e.replace(Ao, Ho);
  ee[t] = new se(t, 1, !1, e, "http://www.w3.org/1999/xlink", !1, !1);
});
["xml:base", "xml:lang", "xml:space"].forEach(function(e) {
  var t = e.replace(Ao, Ho);
  ee[t] = new se(t, 1, !1, e, "http://www.w3.org/XML/1998/namespace", !1, !1);
});
["tabIndex", "crossOrigin"].forEach(function(e) {
  ee[e] = new se(e, 1, !1, e.toLowerCase(), null, !1, !1);
});
ee.xlinkHref = new se("xlinkHref", 1, !1, "xlink:href", "http://www.w3.org/1999/xlink", !0, !1);
["src", "href", "action", "formAction"].forEach(function(e) {
  ee[e] = new se(e, 1, !1, e.toLowerCase(), null, !0, !0);
});
function Wo(e, t, n, r) {
  var l = ee.hasOwnProperty(t) ? ee[t] : null;
  (l !== null ? l.type !== 0 : r || !(2 < t.length) || t[0] !== "o" && t[0] !== "O" || t[1] !== "n" && t[1] !== "N") && (Sc(t, n, l, r) && (n = null), r || l === null ? wc(t) && (n === null ? e.removeAttribute(t) : e.setAttribute(t, "" + n)) : l.mustUseProperty ? e[l.propertyName] = n === null ? l.type === 3 ? !1 : "" : n : (t = l.attributeName, r = l.attributeNamespace, n === null ? e.removeAttribute(t) : (l = l.type, n = l === 3 || l === 4 && n === !0 ? "" : "" + n, r ? e.setAttributeNS(r, t, n) : e.setAttribute(t, n))));
}
var Ge = yc.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED, nr = Symbol.for("react.element"), Ot = Symbol.for("react.portal"), Dt = Symbol.for("react.fragment"), Qo = Symbol.for("react.strict_mode"), Ql = Symbol.for("react.profiler"), ts = Symbol.for("react.provider"), ns = Symbol.for("react.context"), Ko = Symbol.for("react.forward_ref"), Kl = Symbol.for("react.suspense"), Yl = Symbol.for("react.suspense_list"), Yo = Symbol.for("react.memo"), Je = Symbol.for("react.lazy"), rs = Symbol.for("react.offscreen"), Uu = Symbol.iterator;
function cn(e) {
  return e === null || typeof e != "object" ? null : (e = Uu && e[Uu] || e["@@iterator"], typeof e == "function" ? e : null);
}
var A = Object.assign, wl;
function gn(e) {
  if (wl === void 0) try {
    throw Error();
  } catch (n) {
    var t = n.stack.trim().match(/\n( *(at )?)/);
    wl = t && t[1] || "";
  }
  return `
` + wl + e;
}
var kl = !1;
function Sl(e, t) {
  if (!e || kl) return "";
  kl = !0;
  var n = Error.prepareStackTrace;
  Error.prepareStackTrace = void 0;
  try {
    if (t) if (t = function() {
      throw Error();
    }, Object.defineProperty(t.prototype, "props", { set: function() {
      throw Error();
    } }), typeof Reflect == "object" && Reflect.construct) {
      try {
        Reflect.construct(t, []);
      } catch (c) {
        var r = c;
      }
      Reflect.construct(e, [], t);
    } else {
      try {
        t.call();
      } catch (c) {
        r = c;
      }
      e.call(t.prototype);
    }
    else {
      try {
        throw Error();
      } catch (c) {
        r = c;
      }
      e();
    }
  } catch (c) {
    if (c && r && typeof c.stack == "string") {
      for (var l = c.stack.split(`
`), o = r.stack.split(`
`), u = l.length - 1, i = o.length - 1; 1 <= u && 0 <= i && l[u] !== o[i]; ) i--;
      for (; 1 <= u && 0 <= i; u--, i--) if (l[u] !== o[i]) {
        if (u !== 1 || i !== 1)
          do
            if (u--, i--, 0 > i || l[u] !== o[i]) {
              var s = `
` + l[u].replace(" at new ", " at ");
              return e.displayName && s.includes("<anonymous>") && (s = s.replace("<anonymous>", e.displayName)), s;
            }
          while (1 <= u && 0 <= i);
        break;
      }
    }
  } finally {
    kl = !1, Error.prepareStackTrace = n;
  }
  return (e = e ? e.displayName || e.name : "") ? gn(e) : "";
}
function Ec(e) {
  switch (e.tag) {
    case 5:
      return gn(e.type);
    case 16:
      return gn("Lazy");
    case 13:
      return gn("Suspense");
    case 19:
      return gn("SuspenseList");
    case 0:
    case 2:
    case 15:
      return e = Sl(e.type, !1), e;
    case 11:
      return e = Sl(e.type.render, !1), e;
    case 1:
      return e = Sl(e.type, !0), e;
    default:
      return "";
  }
}
function Xl(e) {
  if (e == null) return null;
  if (typeof e == "function") return e.displayName || e.name || null;
  if (typeof e == "string") return e;
  switch (e) {
    case Dt:
      return "Fragment";
    case Ot:
      return "Portal";
    case Ql:
      return "Profiler";
    case Qo:
      return "StrictMode";
    case Kl:
      return "Suspense";
    case Yl:
      return "SuspenseList";
  }
  if (typeof e == "object") switch (e.$$typeof) {
    case ns:
      return (e.displayName || "Context") + ".Consumer";
    case ts:
      return (e._context.displayName || "Context") + ".Provider";
    case Ko:
      var t = e.render;
      return e = e.displayName, e || (e = t.displayName || t.name || "", e = e !== "" ? "ForwardRef(" + e + ")" : "ForwardRef"), e;
    case Yo:
      return t = e.displayName || null, t !== null ? t : Xl(e.type) || "Memo";
    case Je:
      t = e._payload, e = e._init;
      try {
        return Xl(e(t));
      } catch {
      }
  }
  return null;
}
function xc(e) {
  var t = e.type;
  switch (e.tag) {
    case 24:
      return "Cache";
    case 9:
      return (t.displayName || "Context") + ".Consumer";
    case 10:
      return (t._context.displayName || "Context") + ".Provider";
    case 18:
      return "DehydratedFragment";
    case 11:
      return e = t.render, e = e.displayName || e.name || "", t.displayName || (e !== "" ? "ForwardRef(" + e + ")" : "ForwardRef");
    case 7:
      return "Fragment";
    case 5:
      return t;
    case 4:
      return "Portal";
    case 3:
      return "Root";
    case 6:
      return "Text";
    case 16:
      return Xl(t);
    case 8:
      return t === Qo ? "StrictMode" : "Mode";
    case 22:
      return "Offscreen";
    case 12:
      return "Profiler";
    case 21:
      return "Scope";
    case 13:
      return "Suspense";
    case 19:
      return "SuspenseList";
    case 25:
      return "TracingMarker";
    case 1:
    case 0:
    case 17:
    case 2:
    case 14:
    case 15:
      if (typeof t == "function") return t.displayName || t.name || null;
      if (typeof t == "string") return t;
  }
  return null;
}
function ft(e) {
  switch (typeof e) {
    case "boolean":
    case "number":
    case "string":
    case "undefined":
      return e;
    case "object":
      return e;
    default:
      return "";
  }
}
function ls(e) {
  var t = e.type;
  return (e = e.nodeName) && e.toLowerCase() === "input" && (t === "checkbox" || t === "radio");
}
function Cc(e) {
  var t = ls(e) ? "checked" : "value", n = Object.getOwnPropertyDescriptor(e.constructor.prototype, t), r = "" + e[t];
  if (!e.hasOwnProperty(t) && typeof n < "u" && typeof n.get == "function" && typeof n.set == "function") {
    var l = n.get, o = n.set;
    return Object.defineProperty(e, t, { configurable: !0, get: function() {
      return l.call(this);
    }, set: function(u) {
      r = "" + u, o.call(this, u);
    } }), Object.defineProperty(e, t, { enumerable: n.enumerable }), { getValue: function() {
      return r;
    }, setValue: function(u) {
      r = "" + u;
    }, stopTracking: function() {
      e._valueTracker = null, delete e[t];
    } };
  }
}
function rr(e) {
  e._valueTracker || (e._valueTracker = Cc(e));
}
function os(e) {
  if (!e) return !1;
  var t = e._valueTracker;
  if (!t) return !0;
  var n = t.getValue(), r = "";
  return e && (r = ls(e) ? e.checked ? "true" : "false" : e.value), e = r, e !== n ? (t.setValue(e), !0) : !1;
}
function Tr(e) {
  if (e = e || (typeof document < "u" ? document : void 0), typeof e > "u") return null;
  try {
    return e.activeElement || e.body;
  } catch {
    return e.body;
  }
}
function Gl(e, t) {
  var n = t.checked;
  return A({}, t, { defaultChecked: void 0, defaultValue: void 0, value: void 0, checked: n ?? e._wrapperState.initialChecked });
}
function $u(e, t) {
  var n = t.defaultValue == null ? "" : t.defaultValue, r = t.checked != null ? t.checked : t.defaultChecked;
  n = ft(t.value != null ? t.value : n), e._wrapperState = { initialChecked: r, initialValue: n, controlled: t.type === "checkbox" || t.type === "radio" ? t.checked != null : t.value != null };
}
function us(e, t) {
  t = t.checked, t != null && Wo(e, "checked", t, !1);
}
function Zl(e, t) {
  us(e, t);
  var n = ft(t.value), r = t.type;
  if (n != null) r === "number" ? (n === 0 && e.value === "" || e.value != n) && (e.value = "" + n) : e.value !== "" + n && (e.value = "" + n);
  else if (r === "submit" || r === "reset") {
    e.removeAttribute("value");
    return;
  }
  t.hasOwnProperty("value") ? Jl(e, t.type, n) : t.hasOwnProperty("defaultValue") && Jl(e, t.type, ft(t.defaultValue)), t.checked == null && t.defaultChecked != null && (e.defaultChecked = !!t.defaultChecked);
}
function Bu(e, t, n) {
  if (t.hasOwnProperty("value") || t.hasOwnProperty("defaultValue")) {
    var r = t.type;
    if (!(r !== "submit" && r !== "reset" || t.value !== void 0 && t.value !== null)) return;
    t = "" + e._wrapperState.initialValue, n || t === e.value || (e.value = t), e.defaultValue = t;
  }
  n = e.name, n !== "" && (e.name = ""), e.defaultChecked = !!e._wrapperState.initialChecked, n !== "" && (e.name = n);
}
function Jl(e, t, n) {
  (t !== "number" || Tr(e.ownerDocument) !== e) && (n == null ? e.defaultValue = "" + e._wrapperState.initialValue : e.defaultValue !== "" + n && (e.defaultValue = "" + n));
}
var wn = Array.isArray;
function Qt(e, t, n, r) {
  if (e = e.options, t) {
    t = {};
    for (var l = 0; l < n.length; l++) t["$" + n[l]] = !0;
    for (n = 0; n < e.length; n++) l = t.hasOwnProperty("$" + e[n].value), e[n].selected !== l && (e[n].selected = l), l && r && (e[n].defaultSelected = !0);
  } else {
    for (n = "" + ft(n), t = null, l = 0; l < e.length; l++) {
      if (e[l].value === n) {
        e[l].selected = !0, r && (e[l].defaultSelected = !0);
        return;
      }
      t !== null || e[l].disabled || (t = e[l]);
    }
    t !== null && (t.selected = !0);
  }
}
function ql(e, t) {
  if (t.dangerouslySetInnerHTML != null) throw Error(y(91));
  return A({}, t, { value: void 0, defaultValue: void 0, children: "" + e._wrapperState.initialValue });
}
function Vu(e, t) {
  var n = t.value;
  if (n == null) {
    if (n = t.children, t = t.defaultValue, n != null) {
      if (t != null) throw Error(y(92));
      if (wn(n)) {
        if (1 < n.length) throw Error(y(93));
        n = n[0];
      }
      t = n;
    }
    t == null && (t = ""), n = t;
  }
  e._wrapperState = { initialValue: ft(n) };
}
function is(e, t) {
  var n = ft(t.value), r = ft(t.defaultValue);
  n != null && (n = "" + n, n !== e.value && (e.value = n), t.defaultValue == null && e.defaultValue !== n && (e.defaultValue = n)), r != null && (e.defaultValue = "" + r);
}
function Au(e) {
  var t = e.textContent;
  t === e._wrapperState.initialValue && t !== "" && t !== null && (e.value = t);
}
function ss(e) {
  switch (e) {
    case "svg":
      return "http://www.w3.org/2000/svg";
    case "math":
      return "http://www.w3.org/1998/Math/MathML";
    default:
      return "http://www.w3.org/1999/xhtml";
  }
}
function bl(e, t) {
  return e == null || e === "http://www.w3.org/1999/xhtml" ? ss(t) : e === "http://www.w3.org/2000/svg" && t === "foreignObject" ? "http://www.w3.org/1999/xhtml" : e;
}
var lr, as = function(e) {
  return typeof MSApp < "u" && MSApp.execUnsafeLocalFunction ? function(t, n, r, l) {
    MSApp.execUnsafeLocalFunction(function() {
      return e(t, n, r, l);
    });
  } : e;
}(function(e, t) {
  if (e.namespaceURI !== "http://www.w3.org/2000/svg" || "innerHTML" in e) e.innerHTML = t;
  else {
    for (lr = lr || document.createElement("div"), lr.innerHTML = "<svg>" + t.valueOf().toString() + "</svg>", t = lr.firstChild; e.firstChild; ) e.removeChild(e.firstChild);
    for (; t.firstChild; ) e.appendChild(t.firstChild);
  }
});
function Rn(e, t) {
  if (t) {
    var n = e.firstChild;
    if (n && n === e.lastChild && n.nodeType === 3) {
      n.nodeValue = t;
      return;
    }
  }
  e.textContent = t;
}
var En = {
  animationIterationCount: !0,
  aspectRatio: !0,
  borderImageOutset: !0,
  borderImageSlice: !0,
  borderImageWidth: !0,
  boxFlex: !0,
  boxFlexGroup: !0,
  boxOrdinalGroup: !0,
  columnCount: !0,
  columns: !0,
  flex: !0,
  flexGrow: !0,
  flexPositive: !0,
  flexShrink: !0,
  flexNegative: !0,
  flexOrder: !0,
  gridArea: !0,
  gridRow: !0,
  gridRowEnd: !0,
  gridRowSpan: !0,
  gridRowStart: !0,
  gridColumn: !0,
  gridColumnEnd: !0,
  gridColumnSpan: !0,
  gridColumnStart: !0,
  fontWeight: !0,
  lineClamp: !0,
  lineHeight: !0,
  opacity: !0,
  order: !0,
  orphans: !0,
  tabSize: !0,
  widows: !0,
  zIndex: !0,
  zoom: !0,
  fillOpacity: !0,
  floodOpacity: !0,
  stopOpacity: !0,
  strokeDasharray: !0,
  strokeDashoffset: !0,
  strokeMiterlimit: !0,
  strokeOpacity: !0,
  strokeWidth: !0
}, _c = ["Webkit", "ms", "Moz", "O"];
Object.keys(En).forEach(function(e) {
  _c.forEach(function(t) {
    t = t + e.charAt(0).toUpperCase() + e.substring(1), En[t] = En[e];
  });
});
function cs(e, t, n) {
  return t == null || typeof t == "boolean" || t === "" ? "" : n || typeof t != "number" || t === 0 || En.hasOwnProperty(e) && En[e] ? ("" + t).trim() : t + "px";
}
function fs(e, t) {
  e = e.style;
  for (var n in t) if (t.hasOwnProperty(n)) {
    var r = n.indexOf("--") === 0, l = cs(n, t[n], r);
    n === "float" && (n = "cssFloat"), r ? e.setProperty(n, l) : e[n] = l;
  }
}
var Nc = A({ menuitem: !0 }, { area: !0, base: !0, br: !0, col: !0, embed: !0, hr: !0, img: !0, input: !0, keygen: !0, link: !0, meta: !0, param: !0, source: !0, track: !0, wbr: !0 });
function eo(e, t) {
  if (t) {
    if (Nc[e] && (t.children != null || t.dangerouslySetInnerHTML != null)) throw Error(y(137, e));
    if (t.dangerouslySetInnerHTML != null) {
      if (t.children != null) throw Error(y(60));
      if (typeof t.dangerouslySetInnerHTML != "object" || !("__html" in t.dangerouslySetInnerHTML)) throw Error(y(61));
    }
    if (t.style != null && typeof t.style != "object") throw Error(y(62));
  }
}
function to(e, t) {
  if (e.indexOf("-") === -1) return typeof t.is == "string";
  switch (e) {
    case "annotation-xml":
    case "color-profile":
    case "font-face":
    case "font-face-src":
    case "font-face-uri":
    case "font-face-format":
    case "font-face-name":
    case "missing-glyph":
      return !1;
    default:
      return !0;
  }
}
var no = null;
function Xo(e) {
  return e = e.target || e.srcElement || window, e.correspondingUseElement && (e = e.correspondingUseElement), e.nodeType === 3 ? e.parentNode : e;
}
var ro = null, Kt = null, Yt = null;
function Hu(e) {
  if (e = Jn(e)) {
    if (typeof ro != "function") throw Error(y(280));
    var t = e.stateNode;
    t && (t = ll(t), ro(e.stateNode, e.type, t));
  }
}
function ds(e) {
  Kt ? Yt ? Yt.push(e) : Yt = [e] : Kt = e;
}
function ps() {
  if (Kt) {
    var e = Kt, t = Yt;
    if (Yt = Kt = null, Hu(e), t) for (e = 0; e < t.length; e++) Hu(t[e]);
  }
}
function ms(e, t) {
  return e(t);
}
function vs() {
}
var El = !1;
function hs(e, t, n) {
  if (El) return e(t, n);
  El = !0;
  try {
    return ms(e, t, n);
  } finally {
    El = !1, (Kt !== null || Yt !== null) && (vs(), ps());
  }
}
function On(e, t) {
  var n = e.stateNode;
  if (n === null) return null;
  var r = ll(n);
  if (r === null) return null;
  n = r[t];
  e: switch (t) {
    case "onClick":
    case "onClickCapture":
    case "onDoubleClick":
    case "onDoubleClickCapture":
    case "onMouseDown":
    case "onMouseDownCapture":
    case "onMouseMove":
    case "onMouseMoveCapture":
    case "onMouseUp":
    case "onMouseUpCapture":
    case "onMouseEnter":
      (r = !r.disabled) || (e = e.type, r = !(e === "button" || e === "input" || e === "select" || e === "textarea")), e = !r;
      break e;
    default:
      e = !1;
  }
  if (e) return null;
  if (n && typeof n != "function") throw Error(y(231, t, typeof n));
  return n;
}
var lo = !1;
if (Qe) try {
  var fn = {};
  Object.defineProperty(fn, "passive", { get: function() {
    lo = !0;
  } }), window.addEventListener("test", fn, fn), window.removeEventListener("test", fn, fn);
} catch {
  lo = !1;
}
function zc(e, t, n, r, l, o, u, i, s) {
  var c = Array.prototype.slice.call(arguments, 3);
  try {
    t.apply(n, c);
  } catch (v) {
    this.onError(v);
  }
}
var xn = !1, Mr = null, Rr = !1, oo = null, Pc = { onError: function(e) {
  xn = !0, Mr = e;
} };
function Lc(e, t, n, r, l, o, u, i, s) {
  xn = !1, Mr = null, zc.apply(Pc, arguments);
}
function Tc(e, t, n, r, l, o, u, i, s) {
  if (Lc.apply(this, arguments), xn) {
    if (xn) {
      var c = Mr;
      xn = !1, Mr = null;
    } else throw Error(y(198));
    Rr || (Rr = !0, oo = c);
  }
}
function Mt(e) {
  var t = e, n = e;
  if (e.alternate) for (; t.return; ) t = t.return;
  else {
    e = t;
    do
      t = e, t.flags & 4098 && (n = t.return), e = t.return;
    while (e);
  }
  return t.tag === 3 ? n : null;
}
function ys(e) {
  if (e.tag === 13) {
    var t = e.memoizedState;
    if (t === null && (e = e.alternate, e !== null && (t = e.memoizedState)), t !== null) return t.dehydrated;
  }
  return null;
}
function Wu(e) {
  if (Mt(e) !== e) throw Error(y(188));
}
function Mc(e) {
  var t = e.alternate;
  if (!t) {
    if (t = Mt(e), t === null) throw Error(y(188));
    return t !== e ? null : e;
  }
  for (var n = e, r = t; ; ) {
    var l = n.return;
    if (l === null) break;
    var o = l.alternate;
    if (o === null) {
      if (r = l.return, r !== null) {
        n = r;
        continue;
      }
      break;
    }
    if (l.child === o.child) {
      for (o = l.child; o; ) {
        if (o === n) return Wu(l), e;
        if (o === r) return Wu(l), t;
        o = o.sibling;
      }
      throw Error(y(188));
    }
    if (n.return !== r.return) n = l, r = o;
    else {
      for (var u = !1, i = l.child; i; ) {
        if (i === n) {
          u = !0, n = l, r = o;
          break;
        }
        if (i === r) {
          u = !0, r = l, n = o;
          break;
        }
        i = i.sibling;
      }
      if (!u) {
        for (i = o.child; i; ) {
          if (i === n) {
            u = !0, n = o, r = l;
            break;
          }
          if (i === r) {
            u = !0, r = o, n = l;
            break;
          }
          i = i.sibling;
        }
        if (!u) throw Error(y(189));
      }
    }
    if (n.alternate !== r) throw Error(y(190));
  }
  if (n.tag !== 3) throw Error(y(188));
  return n.stateNode.current === n ? e : t;
}
function gs(e) {
  return e = Mc(e), e !== null ? ws(e) : null;
}
function ws(e) {
  if (e.tag === 5 || e.tag === 6) return e;
  for (e = e.child; e !== null; ) {
    var t = ws(e);
    if (t !== null) return t;
    e = e.sibling;
  }
  return null;
}
var ks = ge.unstable_scheduleCallback, Qu = ge.unstable_cancelCallback, Rc = ge.unstable_shouldYield, Oc = ge.unstable_requestPaint, Q = ge.unstable_now, Dc = ge.unstable_getCurrentPriorityLevel, Go = ge.unstable_ImmediatePriority, Ss = ge.unstable_UserBlockingPriority, Or = ge.unstable_NormalPriority, Ic = ge.unstable_LowPriority, Es = ge.unstable_IdlePriority, el = null, Ue = null;
function Fc(e) {
  if (Ue && typeof Ue.onCommitFiberRoot == "function") try {
    Ue.onCommitFiberRoot(el, e, void 0, (e.current.flags & 128) === 128);
  } catch {
  }
}
var Re = Math.clz32 ? Math.clz32 : $c, jc = Math.log, Uc = Math.LN2;
function $c(e) {
  return e >>>= 0, e === 0 ? 32 : 31 - (jc(e) / Uc | 0) | 0;
}
var or = 64, ur = 4194304;
function kn(e) {
  switch (e & -e) {
    case 1:
      return 1;
    case 2:
      return 2;
    case 4:
      return 4;
    case 8:
      return 8;
    case 16:
      return 16;
    case 32:
      return 32;
    case 64:
    case 128:
    case 256:
    case 512:
    case 1024:
    case 2048:
    case 4096:
    case 8192:
    case 16384:
    case 32768:
    case 65536:
    case 131072:
    case 262144:
    case 524288:
    case 1048576:
    case 2097152:
      return e & 4194240;
    case 4194304:
    case 8388608:
    case 16777216:
    case 33554432:
    case 67108864:
      return e & 130023424;
    case 134217728:
      return 134217728;
    case 268435456:
      return 268435456;
    case 536870912:
      return 536870912;
    case 1073741824:
      return 1073741824;
    default:
      return e;
  }
}
function Dr(e, t) {
  var n = e.pendingLanes;
  if (n === 0) return 0;
  var r = 0, l = e.suspendedLanes, o = e.pingedLanes, u = n & 268435455;
  if (u !== 0) {
    var i = u & ~l;
    i !== 0 ? r = kn(i) : (o &= u, o !== 0 && (r = kn(o)));
  } else u = n & ~l, u !== 0 ? r = kn(u) : o !== 0 && (r = kn(o));
  if (r === 0) return 0;
  if (t !== 0 && t !== r && !(t & l) && (l = r & -r, o = t & -t, l >= o || l === 16 && (o & 4194240) !== 0)) return t;
  if (r & 4 && (r |= n & 16), t = e.entangledLanes, t !== 0) for (e = e.entanglements, t &= r; 0 < t; ) n = 31 - Re(t), l = 1 << n, r |= e[n], t &= ~l;
  return r;
}
function Bc(e, t) {
  switch (e) {
    case 1:
    case 2:
    case 4:
      return t + 250;
    case 8:
    case 16:
    case 32:
    case 64:
    case 128:
    case 256:
    case 512:
    case 1024:
    case 2048:
    case 4096:
    case 8192:
    case 16384:
    case 32768:
    case 65536:
    case 131072:
    case 262144:
    case 524288:
    case 1048576:
    case 2097152:
      return t + 5e3;
    case 4194304:
    case 8388608:
    case 16777216:
    case 33554432:
    case 67108864:
      return -1;
    case 134217728:
    case 268435456:
    case 536870912:
    case 1073741824:
      return -1;
    default:
      return -1;
  }
}
function Vc(e, t) {
  for (var n = e.suspendedLanes, r = e.pingedLanes, l = e.expirationTimes, o = e.pendingLanes; 0 < o; ) {
    var u = 31 - Re(o), i = 1 << u, s = l[u];
    s === -1 ? (!(i & n) || i & r) && (l[u] = Bc(i, t)) : s <= t && (e.expiredLanes |= i), o &= ~i;
  }
}
function uo(e) {
  return e = e.pendingLanes & -1073741825, e !== 0 ? e : e & 1073741824 ? 1073741824 : 0;
}
function xs() {
  var e = or;
  return or <<= 1, !(or & 4194240) && (or = 64), e;
}
function xl(e) {
  for (var t = [], n = 0; 31 > n; n++) t.push(e);
  return t;
}
function Gn(e, t, n) {
  e.pendingLanes |= t, t !== 536870912 && (e.suspendedLanes = 0, e.pingedLanes = 0), e = e.eventTimes, t = 31 - Re(t), e[t] = n;
}
function Ac(e, t) {
  var n = e.pendingLanes & ~t;
  e.pendingLanes = t, e.suspendedLanes = 0, e.pingedLanes = 0, e.expiredLanes &= t, e.mutableReadLanes &= t, e.entangledLanes &= t, t = e.entanglements;
  var r = e.eventTimes;
  for (e = e.expirationTimes; 0 < n; ) {
    var l = 31 - Re(n), o = 1 << l;
    t[l] = 0, r[l] = -1, e[l] = -1, n &= ~o;
  }
}
function Zo(e, t) {
  var n = e.entangledLanes |= t;
  for (e = e.entanglements; n; ) {
    var r = 31 - Re(n), l = 1 << r;
    l & t | e[r] & t && (e[r] |= t), n &= ~l;
  }
}
var D = 0;
function Cs(e) {
  return e &= -e, 1 < e ? 4 < e ? e & 268435455 ? 16 : 536870912 : 4 : 1;
}
var _s, Jo, Ns, zs, Ps, io = !1, ir = [], rt = null, lt = null, ot = null, Dn = /* @__PURE__ */ new Map(), In = /* @__PURE__ */ new Map(), be = [], Hc = "mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset submit".split(" ");
function Ku(e, t) {
  switch (e) {
    case "focusin":
    case "focusout":
      rt = null;
      break;
    case "dragenter":
    case "dragleave":
      lt = null;
      break;
    case "mouseover":
    case "mouseout":
      ot = null;
      break;
    case "pointerover":
    case "pointerout":
      Dn.delete(t.pointerId);
      break;
    case "gotpointercapture":
    case "lostpointercapture":
      In.delete(t.pointerId);
  }
}
function dn(e, t, n, r, l, o) {
  return e === null || e.nativeEvent !== o ? (e = { blockedOn: t, domEventName: n, eventSystemFlags: r, nativeEvent: o, targetContainers: [l] }, t !== null && (t = Jn(t), t !== null && Jo(t)), e) : (e.eventSystemFlags |= r, t = e.targetContainers, l !== null && t.indexOf(l) === -1 && t.push(l), e);
}
function Wc(e, t, n, r, l) {
  switch (t) {
    case "focusin":
      return rt = dn(rt, e, t, n, r, l), !0;
    case "dragenter":
      return lt = dn(lt, e, t, n, r, l), !0;
    case "mouseover":
      return ot = dn(ot, e, t, n, r, l), !0;
    case "pointerover":
      var o = l.pointerId;
      return Dn.set(o, dn(Dn.get(o) || null, e, t, n, r, l)), !0;
    case "gotpointercapture":
      return o = l.pointerId, In.set(o, dn(In.get(o) || null, e, t, n, r, l)), !0;
  }
  return !1;
}
function Ls(e) {
  var t = kt(e.target);
  if (t !== null) {
    var n = Mt(t);
    if (n !== null) {
      if (t = n.tag, t === 13) {
        if (t = ys(n), t !== null) {
          e.blockedOn = t, Ps(e.priority, function() {
            Ns(n);
          });
          return;
        }
      } else if (t === 3 && n.stateNode.current.memoizedState.isDehydrated) {
        e.blockedOn = n.tag === 3 ? n.stateNode.containerInfo : null;
        return;
      }
    }
  }
  e.blockedOn = null;
}
function kr(e) {
  if (e.blockedOn !== null) return !1;
  for (var t = e.targetContainers; 0 < t.length; ) {
    var n = so(e.domEventName, e.eventSystemFlags, t[0], e.nativeEvent);
    if (n === null) {
      n = e.nativeEvent;
      var r = new n.constructor(n.type, n);
      no = r, n.target.dispatchEvent(r), no = null;
    } else return t = Jn(n), t !== null && Jo(t), e.blockedOn = n, !1;
    t.shift();
  }
  return !0;
}
function Yu(e, t, n) {
  kr(e) && n.delete(t);
}
function Qc() {
  io = !1, rt !== null && kr(rt) && (rt = null), lt !== null && kr(lt) && (lt = null), ot !== null && kr(ot) && (ot = null), Dn.forEach(Yu), In.forEach(Yu);
}
function pn(e, t) {
  e.blockedOn === t && (e.blockedOn = null, io || (io = !0, ge.unstable_scheduleCallback(ge.unstable_NormalPriority, Qc)));
}
function Fn(e) {
  function t(l) {
    return pn(l, e);
  }
  if (0 < ir.length) {
    pn(ir[0], e);
    for (var n = 1; n < ir.length; n++) {
      var r = ir[n];
      r.blockedOn === e && (r.blockedOn = null);
    }
  }
  for (rt !== null && pn(rt, e), lt !== null && pn(lt, e), ot !== null && pn(ot, e), Dn.forEach(t), In.forEach(t), n = 0; n < be.length; n++) r = be[n], r.blockedOn === e && (r.blockedOn = null);
  for (; 0 < be.length && (n = be[0], n.blockedOn === null); ) Ls(n), n.blockedOn === null && be.shift();
}
var Xt = Ge.ReactCurrentBatchConfig, Ir = !0;
function Kc(e, t, n, r) {
  var l = D, o = Xt.transition;
  Xt.transition = null;
  try {
    D = 1, qo(e, t, n, r);
  } finally {
    D = l, Xt.transition = o;
  }
}
function Yc(e, t, n, r) {
  var l = D, o = Xt.transition;
  Xt.transition = null;
  try {
    D = 4, qo(e, t, n, r);
  } finally {
    D = l, Xt.transition = o;
  }
}
function qo(e, t, n, r) {
  if (Ir) {
    var l = so(e, t, n, r);
    if (l === null) Ol(e, t, r, Fr, n), Ku(e, r);
    else if (Wc(l, e, t, n, r)) r.stopPropagation();
    else if (Ku(e, r), t & 4 && -1 < Hc.indexOf(e)) {
      for (; l !== null; ) {
        var o = Jn(l);
        if (o !== null && _s(o), o = so(e, t, n, r), o === null && Ol(e, t, r, Fr, n), o === l) break;
        l = o;
      }
      l !== null && r.stopPropagation();
    } else Ol(e, t, r, null, n);
  }
}
var Fr = null;
function so(e, t, n, r) {
  if (Fr = null, e = Xo(r), e = kt(e), e !== null) if (t = Mt(e), t === null) e = null;
  else if (n = t.tag, n === 13) {
    if (e = ys(t), e !== null) return e;
    e = null;
  } else if (n === 3) {
    if (t.stateNode.current.memoizedState.isDehydrated) return t.tag === 3 ? t.stateNode.containerInfo : null;
    e = null;
  } else t !== e && (e = null);
  return Fr = e, null;
}
function Ts(e) {
  switch (e) {
    case "cancel":
    case "click":
    case "close":
    case "contextmenu":
    case "copy":
    case "cut":
    case "auxclick":
    case "dblclick":
    case "dragend":
    case "dragstart":
    case "drop":
    case "focusin":
    case "focusout":
    case "input":
    case "invalid":
    case "keydown":
    case "keypress":
    case "keyup":
    case "mousedown":
    case "mouseup":
    case "paste":
    case "pause":
    case "play":
    case "pointercancel":
    case "pointerdown":
    case "pointerup":
    case "ratechange":
    case "reset":
    case "resize":
    case "seeked":
    case "submit":
    case "touchcancel":
    case "touchend":
    case "touchstart":
    case "volumechange":
    case "change":
    case "selectionchange":
    case "textInput":
    case "compositionstart":
    case "compositionend":
    case "compositionupdate":
    case "beforeblur":
    case "afterblur":
    case "beforeinput":
    case "blur":
    case "fullscreenchange":
    case "focus":
    case "hashchange":
    case "popstate":
    case "select":
    case "selectstart":
      return 1;
    case "drag":
    case "dragenter":
    case "dragexit":
    case "dragleave":
    case "dragover":
    case "mousemove":
    case "mouseout":
    case "mouseover":
    case "pointermove":
    case "pointerout":
    case "pointerover":
    case "scroll":
    case "toggle":
    case "touchmove":
    case "wheel":
    case "mouseenter":
    case "mouseleave":
    case "pointerenter":
    case "pointerleave":
      return 4;
    case "message":
      switch (Dc()) {
        case Go:
          return 1;
        case Ss:
          return 4;
        case Or:
        case Ic:
          return 16;
        case Es:
          return 536870912;
        default:
          return 16;
      }
    default:
      return 16;
  }
}
var tt = null, bo = null, Sr = null;
function Ms() {
  if (Sr) return Sr;
  var e, t = bo, n = t.length, r, l = "value" in tt ? tt.value : tt.textContent, o = l.length;
  for (e = 0; e < n && t[e] === l[e]; e++) ;
  var u = n - e;
  for (r = 1; r <= u && t[n - r] === l[o - r]; r++) ;
  return Sr = l.slice(e, 1 < r ? 1 - r : void 0);
}
function Er(e) {
  var t = e.keyCode;
  return "charCode" in e ? (e = e.charCode, e === 0 && t === 13 && (e = 13)) : e = t, e === 10 && (e = 13), 32 <= e || e === 13 ? e : 0;
}
function sr() {
  return !0;
}
function Xu() {
  return !1;
}
function ke(e) {
  function t(n, r, l, o, u) {
    this._reactName = n, this._targetInst = l, this.type = r, this.nativeEvent = o, this.target = u, this.currentTarget = null;
    for (var i in e) e.hasOwnProperty(i) && (n = e[i], this[i] = n ? n(o) : o[i]);
    return this.isDefaultPrevented = (o.defaultPrevented != null ? o.defaultPrevented : o.returnValue === !1) ? sr : Xu, this.isPropagationStopped = Xu, this;
  }
  return A(t.prototype, { preventDefault: function() {
    this.defaultPrevented = !0;
    var n = this.nativeEvent;
    n && (n.preventDefault ? n.preventDefault() : typeof n.returnValue != "unknown" && (n.returnValue = !1), this.isDefaultPrevented = sr);
  }, stopPropagation: function() {
    var n = this.nativeEvent;
    n && (n.stopPropagation ? n.stopPropagation() : typeof n.cancelBubble != "unknown" && (n.cancelBubble = !0), this.isPropagationStopped = sr);
  }, persist: function() {
  }, isPersistent: sr }), t;
}
var on = { eventPhase: 0, bubbles: 0, cancelable: 0, timeStamp: function(e) {
  return e.timeStamp || Date.now();
}, defaultPrevented: 0, isTrusted: 0 }, eu = ke(on), Zn = A({}, on, { view: 0, detail: 0 }), Xc = ke(Zn), Cl, _l, mn, tl = A({}, Zn, { screenX: 0, screenY: 0, clientX: 0, clientY: 0, pageX: 0, pageY: 0, ctrlKey: 0, shiftKey: 0, altKey: 0, metaKey: 0, getModifierState: tu, button: 0, buttons: 0, relatedTarget: function(e) {
  return e.relatedTarget === void 0 ? e.fromElement === e.srcElement ? e.toElement : e.fromElement : e.relatedTarget;
}, movementX: function(e) {
  return "movementX" in e ? e.movementX : (e !== mn && (mn && e.type === "mousemove" ? (Cl = e.screenX - mn.screenX, _l = e.screenY - mn.screenY) : _l = Cl = 0, mn = e), Cl);
}, movementY: function(e) {
  return "movementY" in e ? e.movementY : _l;
} }), Gu = ke(tl), Gc = A({}, tl, { dataTransfer: 0 }), Zc = ke(Gc), Jc = A({}, Zn, { relatedTarget: 0 }), Nl = ke(Jc), qc = A({}, on, { animationName: 0, elapsedTime: 0, pseudoElement: 0 }), bc = ke(qc), ef = A({}, on, { clipboardData: function(e) {
  return "clipboardData" in e ? e.clipboardData : window.clipboardData;
} }), tf = ke(ef), nf = A({}, on, { data: 0 }), Zu = ke(nf), rf = {
  Esc: "Escape",
  Spacebar: " ",
  Left: "ArrowLeft",
  Up: "ArrowUp",
  Right: "ArrowRight",
  Down: "ArrowDown",
  Del: "Delete",
  Win: "OS",
  Menu: "ContextMenu",
  Apps: "ContextMenu",
  Scroll: "ScrollLock",
  MozPrintableKey: "Unidentified"
}, lf = {
  8: "Backspace",
  9: "Tab",
  12: "Clear",
  13: "Enter",
  16: "Shift",
  17: "Control",
  18: "Alt",
  19: "Pause",
  20: "CapsLock",
  27: "Escape",
  32: " ",
  33: "PageUp",
  34: "PageDown",
  35: "End",
  36: "Home",
  37: "ArrowLeft",
  38: "ArrowUp",
  39: "ArrowRight",
  40: "ArrowDown",
  45: "Insert",
  46: "Delete",
  112: "F1",
  113: "F2",
  114: "F3",
  115: "F4",
  116: "F5",
  117: "F6",
  118: "F7",
  119: "F8",
  120: "F9",
  121: "F10",
  122: "F11",
  123: "F12",
  144: "NumLock",
  145: "ScrollLock",
  224: "Meta"
}, of = { Alt: "altKey", Control: "ctrlKey", Meta: "metaKey", Shift: "shiftKey" };
function uf(e) {
  var t = this.nativeEvent;
  return t.getModifierState ? t.getModifierState(e) : (e = of[e]) ? !!t[e] : !1;
}
function tu() {
  return uf;
}
var sf = A({}, Zn, { key: function(e) {
  if (e.key) {
    var t = rf[e.key] || e.key;
    if (t !== "Unidentified") return t;
  }
  return e.type === "keypress" ? (e = Er(e), e === 13 ? "Enter" : String.fromCharCode(e)) : e.type === "keydown" || e.type === "keyup" ? lf[e.keyCode] || "Unidentified" : "";
}, code: 0, location: 0, ctrlKey: 0, shiftKey: 0, altKey: 0, metaKey: 0, repeat: 0, locale: 0, getModifierState: tu, charCode: function(e) {
  return e.type === "keypress" ? Er(e) : 0;
}, keyCode: function(e) {
  return e.type === "keydown" || e.type === "keyup" ? e.keyCode : 0;
}, which: function(e) {
  return e.type === "keypress" ? Er(e) : e.type === "keydown" || e.type === "keyup" ? e.keyCode : 0;
} }), af = ke(sf), cf = A({}, tl, { pointerId: 0, width: 0, height: 0, pressure: 0, tangentialPressure: 0, tiltX: 0, tiltY: 0, twist: 0, pointerType: 0, isPrimary: 0 }), Ju = ke(cf), ff = A({}, Zn, { touches: 0, targetTouches: 0, changedTouches: 0, altKey: 0, metaKey: 0, ctrlKey: 0, shiftKey: 0, getModifierState: tu }), df = ke(ff), pf = A({}, on, { propertyName: 0, elapsedTime: 0, pseudoElement: 0 }), mf = ke(pf), vf = A({}, tl, {
  deltaX: function(e) {
    return "deltaX" in e ? e.deltaX : "wheelDeltaX" in e ? -e.wheelDeltaX : 0;
  },
  deltaY: function(e) {
    return "deltaY" in e ? e.deltaY : "wheelDeltaY" in e ? -e.wheelDeltaY : "wheelDelta" in e ? -e.wheelDelta : 0;
  },
  deltaZ: 0,
  deltaMode: 0
}), hf = ke(vf), yf = [9, 13, 27, 32], nu = Qe && "CompositionEvent" in window, Cn = null;
Qe && "documentMode" in document && (Cn = document.documentMode);
var gf = Qe && "TextEvent" in window && !Cn, Rs = Qe && (!nu || Cn && 8 < Cn && 11 >= Cn), qu = " ", bu = !1;
function Os(e, t) {
  switch (e) {
    case "keyup":
      return yf.indexOf(t.keyCode) !== -1;
    case "keydown":
      return t.keyCode !== 229;
    case "keypress":
    case "mousedown":
    case "focusout":
      return !0;
    default:
      return !1;
  }
}
function Ds(e) {
  return e = e.detail, typeof e == "object" && "data" in e ? e.data : null;
}
var It = !1;
function wf(e, t) {
  switch (e) {
    case "compositionend":
      return Ds(t);
    case "keypress":
      return t.which !== 32 ? null : (bu = !0, qu);
    case "textInput":
      return e = t.data, e === qu && bu ? null : e;
    default:
      return null;
  }
}
function kf(e, t) {
  if (It) return e === "compositionend" || !nu && Os(e, t) ? (e = Ms(), Sr = bo = tt = null, It = !1, e) : null;
  switch (e) {
    case "paste":
      return null;
    case "keypress":
      if (!(t.ctrlKey || t.altKey || t.metaKey) || t.ctrlKey && t.altKey) {
        if (t.char && 1 < t.char.length) return t.char;
        if (t.which) return String.fromCharCode(t.which);
      }
      return null;
    case "compositionend":
      return Rs && t.locale !== "ko" ? null : t.data;
    default:
      return null;
  }
}
var Sf = { color: !0, date: !0, datetime: !0, "datetime-local": !0, email: !0, month: !0, number: !0, password: !0, range: !0, search: !0, tel: !0, text: !0, time: !0, url: !0, week: !0 };
function ei(e) {
  var t = e && e.nodeName && e.nodeName.toLowerCase();
  return t === "input" ? !!Sf[e.type] : t === "textarea";
}
function Is(e, t, n, r) {
  ds(r), t = jr(t, "onChange"), 0 < t.length && (n = new eu("onChange", "change", null, n, r), e.push({ event: n, listeners: t }));
}
var _n = null, jn = null;
function Ef(e) {
  Ks(e, 0);
}
function nl(e) {
  var t = Ut(e);
  if (os(t)) return e;
}
function xf(e, t) {
  if (e === "change") return t;
}
var Fs = !1;
if (Qe) {
  var zl;
  if (Qe) {
    var Pl = "oninput" in document;
    if (!Pl) {
      var ti = document.createElement("div");
      ti.setAttribute("oninput", "return;"), Pl = typeof ti.oninput == "function";
    }
    zl = Pl;
  } else zl = !1;
  Fs = zl && (!document.documentMode || 9 < document.documentMode);
}
function ni() {
  _n && (_n.detachEvent("onpropertychange", js), jn = _n = null);
}
function js(e) {
  if (e.propertyName === "value" && nl(jn)) {
    var t = [];
    Is(t, jn, e, Xo(e)), hs(Ef, t);
  }
}
function Cf(e, t, n) {
  e === "focusin" ? (ni(), _n = t, jn = n, _n.attachEvent("onpropertychange", js)) : e === "focusout" && ni();
}
function _f(e) {
  if (e === "selectionchange" || e === "keyup" || e === "keydown") return nl(jn);
}
function Nf(e, t) {
  if (e === "click") return nl(t);
}
function zf(e, t) {
  if (e === "input" || e === "change") return nl(t);
}
function Pf(e, t) {
  return e === t && (e !== 0 || 1 / e === 1 / t) || e !== e && t !== t;
}
var De = typeof Object.is == "function" ? Object.is : Pf;
function Un(e, t) {
  if (De(e, t)) return !0;
  if (typeof e != "object" || e === null || typeof t != "object" || t === null) return !1;
  var n = Object.keys(e), r = Object.keys(t);
  if (n.length !== r.length) return !1;
  for (r = 0; r < n.length; r++) {
    var l = n[r];
    if (!Wl.call(t, l) || !De(e[l], t[l])) return !1;
  }
  return !0;
}
function ri(e) {
  for (; e && e.firstChild; ) e = e.firstChild;
  return e;
}
function li(e, t) {
  var n = ri(e);
  e = 0;
  for (var r; n; ) {
    if (n.nodeType === 3) {
      if (r = e + n.textContent.length, e <= t && r >= t) return { node: n, offset: t - e };
      e = r;
    }
    e: {
      for (; n; ) {
        if (n.nextSibling) {
          n = n.nextSibling;
          break e;
        }
        n = n.parentNode;
      }
      n = void 0;
    }
    n = ri(n);
  }
}
function Us(e, t) {
  return e && t ? e === t ? !0 : e && e.nodeType === 3 ? !1 : t && t.nodeType === 3 ? Us(e, t.parentNode) : "contains" in e ? e.contains(t) : e.compareDocumentPosition ? !!(e.compareDocumentPosition(t) & 16) : !1 : !1;
}
function $s() {
  for (var e = window, t = Tr(); t instanceof e.HTMLIFrameElement; ) {
    try {
      var n = typeof t.contentWindow.location.href == "string";
    } catch {
      n = !1;
    }
    if (n) e = t.contentWindow;
    else break;
    t = Tr(e.document);
  }
  return t;
}
function ru(e) {
  var t = e && e.nodeName && e.nodeName.toLowerCase();
  return t && (t === "input" && (e.type === "text" || e.type === "search" || e.type === "tel" || e.type === "url" || e.type === "password") || t === "textarea" || e.contentEditable === "true");
}
function Lf(e) {
  var t = $s(), n = e.focusedElem, r = e.selectionRange;
  if (t !== n && n && n.ownerDocument && Us(n.ownerDocument.documentElement, n)) {
    if (r !== null && ru(n)) {
      if (t = r.start, e = r.end, e === void 0 && (e = t), "selectionStart" in n) n.selectionStart = t, n.selectionEnd = Math.min(e, n.value.length);
      else if (e = (t = n.ownerDocument || document) && t.defaultView || window, e.getSelection) {
        e = e.getSelection();
        var l = n.textContent.length, o = Math.min(r.start, l);
        r = r.end === void 0 ? o : Math.min(r.end, l), !e.extend && o > r && (l = r, r = o, o = l), l = li(n, o);
        var u = li(
          n,
          r
        );
        l && u && (e.rangeCount !== 1 || e.anchorNode !== l.node || e.anchorOffset !== l.offset || e.focusNode !== u.node || e.focusOffset !== u.offset) && (t = t.createRange(), t.setStart(l.node, l.offset), e.removeAllRanges(), o > r ? (e.addRange(t), e.extend(u.node, u.offset)) : (t.setEnd(u.node, u.offset), e.addRange(t)));
      }
    }
    for (t = [], e = n; e = e.parentNode; ) e.nodeType === 1 && t.push({ element: e, left: e.scrollLeft, top: e.scrollTop });
    for (typeof n.focus == "function" && n.focus(), n = 0; n < t.length; n++) e = t[n], e.element.scrollLeft = e.left, e.element.scrollTop = e.top;
  }
}
var Tf = Qe && "documentMode" in document && 11 >= document.documentMode, Ft = null, ao = null, Nn = null, co = !1;
function oi(e, t, n) {
  var r = n.window === n ? n.document : n.nodeType === 9 ? n : n.ownerDocument;
  co || Ft == null || Ft !== Tr(r) || (r = Ft, "selectionStart" in r && ru(r) ? r = { start: r.selectionStart, end: r.selectionEnd } : (r = (r.ownerDocument && r.ownerDocument.defaultView || window).getSelection(), r = { anchorNode: r.anchorNode, anchorOffset: r.anchorOffset, focusNode: r.focusNode, focusOffset: r.focusOffset }), Nn && Un(Nn, r) || (Nn = r, r = jr(ao, "onSelect"), 0 < r.length && (t = new eu("onSelect", "select", null, t, n), e.push({ event: t, listeners: r }), t.target = Ft)));
}
function ar(e, t) {
  var n = {};
  return n[e.toLowerCase()] = t.toLowerCase(), n["Webkit" + e] = "webkit" + t, n["Moz" + e] = "moz" + t, n;
}
var jt = { animationend: ar("Animation", "AnimationEnd"), animationiteration: ar("Animation", "AnimationIteration"), animationstart: ar("Animation", "AnimationStart"), transitionend: ar("Transition", "TransitionEnd") }, Ll = {}, Bs = {};
Qe && (Bs = document.createElement("div").style, "AnimationEvent" in window || (delete jt.animationend.animation, delete jt.animationiteration.animation, delete jt.animationstart.animation), "TransitionEvent" in window || delete jt.transitionend.transition);
function rl(e) {
  if (Ll[e]) return Ll[e];
  if (!jt[e]) return e;
  var t = jt[e], n;
  for (n in t) if (t.hasOwnProperty(n) && n in Bs) return Ll[e] = t[n];
  return e;
}
var Vs = rl("animationend"), As = rl("animationiteration"), Hs = rl("animationstart"), Ws = rl("transitionend"), Qs = /* @__PURE__ */ new Map(), ui = "abort auxClick cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");
function pt(e, t) {
  Qs.set(e, t), Tt(t, [e]);
}
for (var Tl = 0; Tl < ui.length; Tl++) {
  var Ml = ui[Tl], Mf = Ml.toLowerCase(), Rf = Ml[0].toUpperCase() + Ml.slice(1);
  pt(Mf, "on" + Rf);
}
pt(Vs, "onAnimationEnd");
pt(As, "onAnimationIteration");
pt(Hs, "onAnimationStart");
pt("dblclick", "onDoubleClick");
pt("focusin", "onFocus");
pt("focusout", "onBlur");
pt(Ws, "onTransitionEnd");
Jt("onMouseEnter", ["mouseout", "mouseover"]);
Jt("onMouseLeave", ["mouseout", "mouseover"]);
Jt("onPointerEnter", ["pointerout", "pointerover"]);
Jt("onPointerLeave", ["pointerout", "pointerover"]);
Tt("onChange", "change click focusin focusout input keydown keyup selectionchange".split(" "));
Tt("onSelect", "focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" "));
Tt("onBeforeInput", ["compositionend", "keypress", "textInput", "paste"]);
Tt("onCompositionEnd", "compositionend focusout keydown keypress keyup mousedown".split(" "));
Tt("onCompositionStart", "compositionstart focusout keydown keypress keyup mousedown".split(" "));
Tt("onCompositionUpdate", "compositionupdate focusout keydown keypress keyup mousedown".split(" "));
var Sn = "abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "), Of = new Set("cancel close invalid load scroll toggle".split(" ").concat(Sn));
function ii(e, t, n) {
  var r = e.type || "unknown-event";
  e.currentTarget = n, Tc(r, t, void 0, e), e.currentTarget = null;
}
function Ks(e, t) {
  t = (t & 4) !== 0;
  for (var n = 0; n < e.length; n++) {
    var r = e[n], l = r.event;
    r = r.listeners;
    e: {
      var o = void 0;
      if (t) for (var u = r.length - 1; 0 <= u; u--) {
        var i = r[u], s = i.instance, c = i.currentTarget;
        if (i = i.listener, s !== o && l.isPropagationStopped()) break e;
        ii(l, i, c), o = s;
      }
      else for (u = 0; u < r.length; u++) {
        if (i = r[u], s = i.instance, c = i.currentTarget, i = i.listener, s !== o && l.isPropagationStopped()) break e;
        ii(l, i, c), o = s;
      }
    }
  }
  if (Rr) throw e = oo, Rr = !1, oo = null, e;
}
function j(e, t) {
  var n = t[ho];
  n === void 0 && (n = t[ho] = /* @__PURE__ */ new Set());
  var r = e + "__bubble";
  n.has(r) || (Ys(t, e, 2, !1), n.add(r));
}
function Rl(e, t, n) {
  var r = 0;
  t && (r |= 4), Ys(n, e, r, t);
}
var cr = "_reactListening" + Math.random().toString(36).slice(2);
function $n(e) {
  if (!e[cr]) {
    e[cr] = !0, es.forEach(function(n) {
      n !== "selectionchange" && (Of.has(n) || Rl(n, !1, e), Rl(n, !0, e));
    });
    var t = e.nodeType === 9 ? e : e.ownerDocument;
    t === null || t[cr] || (t[cr] = !0, Rl("selectionchange", !1, t));
  }
}
function Ys(e, t, n, r) {
  switch (Ts(t)) {
    case 1:
      var l = Kc;
      break;
    case 4:
      l = Yc;
      break;
    default:
      l = qo;
  }
  n = l.bind(null, t, n, e), l = void 0, !lo || t !== "touchstart" && t !== "touchmove" && t !== "wheel" || (l = !0), r ? l !== void 0 ? e.addEventListener(t, n, { capture: !0, passive: l }) : e.addEventListener(t, n, !0) : l !== void 0 ? e.addEventListener(t, n, { passive: l }) : e.addEventListener(t, n, !1);
}
function Ol(e, t, n, r, l) {
  var o = r;
  if (!(t & 1) && !(t & 2) && r !== null) e: for (; ; ) {
    if (r === null) return;
    var u = r.tag;
    if (u === 3 || u === 4) {
      var i = r.stateNode.containerInfo;
      if (i === l || i.nodeType === 8 && i.parentNode === l) break;
      if (u === 4) for (u = r.return; u !== null; ) {
        var s = u.tag;
        if ((s === 3 || s === 4) && (s = u.stateNode.containerInfo, s === l || s.nodeType === 8 && s.parentNode === l)) return;
        u = u.return;
      }
      for (; i !== null; ) {
        if (u = kt(i), u === null) return;
        if (s = u.tag, s === 5 || s === 6) {
          r = o = u;
          continue e;
        }
        i = i.parentNode;
      }
    }
    r = r.return;
  }
  hs(function() {
    var c = o, v = Xo(n), m = [];
    e: {
      var p = Qs.get(e);
      if (p !== void 0) {
        var g = eu, k = e;
        switch (e) {
          case "keypress":
            if (Er(n) === 0) break e;
          case "keydown":
          case "keyup":
            g = af;
            break;
          case "focusin":
            k = "focus", g = Nl;
            break;
          case "focusout":
            k = "blur", g = Nl;
            break;
          case "beforeblur":
          case "afterblur":
            g = Nl;
            break;
          case "click":
            if (n.button === 2) break e;
          case "auxclick":
          case "dblclick":
          case "mousedown":
          case "mousemove":
          case "mouseup":
          case "mouseout":
          case "mouseover":
          case "contextmenu":
            g = Gu;
            break;
          case "drag":
          case "dragend":
          case "dragenter":
          case "dragexit":
          case "dragleave":
          case "dragover":
          case "dragstart":
          case "drop":
            g = Zc;
            break;
          case "touchcancel":
          case "touchend":
          case "touchmove":
          case "touchstart":
            g = df;
            break;
          case Vs:
          case As:
          case Hs:
            g = bc;
            break;
          case Ws:
            g = mf;
            break;
          case "scroll":
            g = Xc;
            break;
          case "wheel":
            g = hf;
            break;
          case "copy":
          case "cut":
          case "paste":
            g = tf;
            break;
          case "gotpointercapture":
          case "lostpointercapture":
          case "pointercancel":
          case "pointerdown":
          case "pointermove":
          case "pointerout":
          case "pointerover":
          case "pointerup":
            g = Ju;
        }
        var S = (t & 4) !== 0, O = !S && e === "scroll", f = S ? p !== null ? p + "Capture" : null : p;
        S = [];
        for (var a = c, d; a !== null; ) {
          d = a;
          var h = d.stateNode;
          if (d.tag === 5 && h !== null && (d = h, f !== null && (h = On(a, f), h != null && S.push(Bn(a, h, d)))), O) break;
          a = a.return;
        }
        0 < S.length && (p = new g(p, k, null, n, v), m.push({ event: p, listeners: S }));
      }
    }
    if (!(t & 7)) {
      e: {
        if (p = e === "mouseover" || e === "pointerover", g = e === "mouseout" || e === "pointerout", p && n !== no && (k = n.relatedTarget || n.fromElement) && (kt(k) || k[Ke])) break e;
        if ((g || p) && (p = v.window === v ? v : (p = v.ownerDocument) ? p.defaultView || p.parentWindow : window, g ? (k = n.relatedTarget || n.toElement, g = c, k = k ? kt(k) : null, k !== null && (O = Mt(k), k !== O || k.tag !== 5 && k.tag !== 6) && (k = null)) : (g = null, k = c), g !== k)) {
          if (S = Gu, h = "onMouseLeave", f = "onMouseEnter", a = "mouse", (e === "pointerout" || e === "pointerover") && (S = Ju, h = "onPointerLeave", f = "onPointerEnter", a = "pointer"), O = g == null ? p : Ut(g), d = k == null ? p : Ut(k), p = new S(h, a + "leave", g, n, v), p.target = O, p.relatedTarget = d, h = null, kt(v) === c && (S = new S(f, a + "enter", k, n, v), S.target = d, S.relatedTarget = O, h = S), O = h, g && k) t: {
            for (S = g, f = k, a = 0, d = S; d; d = Rt(d)) a++;
            for (d = 0, h = f; h; h = Rt(h)) d++;
            for (; 0 < a - d; ) S = Rt(S), a--;
            for (; 0 < d - a; ) f = Rt(f), d--;
            for (; a--; ) {
              if (S === f || f !== null && S === f.alternate) break t;
              S = Rt(S), f = Rt(f);
            }
            S = null;
          }
          else S = null;
          g !== null && si(m, p, g, S, !1), k !== null && O !== null && si(m, O, k, S, !0);
        }
      }
      e: {
        if (p = c ? Ut(c) : window, g = p.nodeName && p.nodeName.toLowerCase(), g === "select" || g === "input" && p.type === "file") var E = xf;
        else if (ei(p)) if (Fs) E = zf;
        else {
          E = _f;
          var _ = Cf;
        }
        else (g = p.nodeName) && g.toLowerCase() === "input" && (p.type === "checkbox" || p.type === "radio") && (E = Nf);
        if (E && (E = E(e, c))) {
          Is(m, E, n, v);
          break e;
        }
        _ && _(e, p, c), e === "focusout" && (_ = p._wrapperState) && _.controlled && p.type === "number" && Jl(p, "number", p.value);
      }
      switch (_ = c ? Ut(c) : window, e) {
        case "focusin":
          (ei(_) || _.contentEditable === "true") && (Ft = _, ao = c, Nn = null);
          break;
        case "focusout":
          Nn = ao = Ft = null;
          break;
        case "mousedown":
          co = !0;
          break;
        case "contextmenu":
        case "mouseup":
        case "dragend":
          co = !1, oi(m, n, v);
          break;
        case "selectionchange":
          if (Tf) break;
        case "keydown":
        case "keyup":
          oi(m, n, v);
      }
      var N;
      if (nu) e: {
        switch (e) {
          case "compositionstart":
            var z = "onCompositionStart";
            break e;
          case "compositionend":
            z = "onCompositionEnd";
            break e;
          case "compositionupdate":
            z = "onCompositionUpdate";
            break e;
        }
        z = void 0;
      }
      else It ? Os(e, n) && (z = "onCompositionEnd") : e === "keydown" && n.keyCode === 229 && (z = "onCompositionStart");
      z && (Rs && n.locale !== "ko" && (It || z !== "onCompositionStart" ? z === "onCompositionEnd" && It && (N = Ms()) : (tt = v, bo = "value" in tt ? tt.value : tt.textContent, It = !0)), _ = jr(c, z), 0 < _.length && (z = new Zu(z, e, null, n, v), m.push({ event: z, listeners: _ }), N ? z.data = N : (N = Ds(n), N !== null && (z.data = N)))), (N = gf ? wf(e, n) : kf(e, n)) && (c = jr(c, "onBeforeInput"), 0 < c.length && (v = new Zu("onBeforeInput", "beforeinput", null, n, v), m.push({ event: v, listeners: c }), v.data = N));
    }
    Ks(m, t);
  });
}
function Bn(e, t, n) {
  return { instance: e, listener: t, currentTarget: n };
}
function jr(e, t) {
  for (var n = t + "Capture", r = []; e !== null; ) {
    var l = e, o = l.stateNode;
    l.tag === 5 && o !== null && (l = o, o = On(e, n), o != null && r.unshift(Bn(e, o, l)), o = On(e, t), o != null && r.push(Bn(e, o, l))), e = e.return;
  }
  return r;
}
function Rt(e) {
  if (e === null) return null;
  do
    e = e.return;
  while (e && e.tag !== 5);
  return e || null;
}
function si(e, t, n, r, l) {
  for (var o = t._reactName, u = []; n !== null && n !== r; ) {
    var i = n, s = i.alternate, c = i.stateNode;
    if (s !== null && s === r) break;
    i.tag === 5 && c !== null && (i = c, l ? (s = On(n, o), s != null && u.unshift(Bn(n, s, i))) : l || (s = On(n, o), s != null && u.push(Bn(n, s, i)))), n = n.return;
  }
  u.length !== 0 && e.push({ event: t, listeners: u });
}
var Df = /\r\n?/g, If = /\u0000|\uFFFD/g;
function ai(e) {
  return (typeof e == "string" ? e : "" + e).replace(Df, `
`).replace(If, "");
}
function fr(e, t, n) {
  if (t = ai(t), ai(e) !== t && n) throw Error(y(425));
}
function Ur() {
}
var fo = null, po = null;
function mo(e, t) {
  return e === "textarea" || e === "noscript" || typeof t.children == "string" || typeof t.children == "number" || typeof t.dangerouslySetInnerHTML == "object" && t.dangerouslySetInnerHTML !== null && t.dangerouslySetInnerHTML.__html != null;
}
var vo = typeof setTimeout == "function" ? setTimeout : void 0, Ff = typeof clearTimeout == "function" ? clearTimeout : void 0, ci = typeof Promise == "function" ? Promise : void 0, jf = typeof queueMicrotask == "function" ? queueMicrotask : typeof ci < "u" ? function(e) {
  return ci.resolve(null).then(e).catch(Uf);
} : vo;
function Uf(e) {
  setTimeout(function() {
    throw e;
  });
}
function Dl(e, t) {
  var n = t, r = 0;
  do {
    var l = n.nextSibling;
    if (e.removeChild(n), l && l.nodeType === 8) if (n = l.data, n === "/$") {
      if (r === 0) {
        e.removeChild(l), Fn(t);
        return;
      }
      r--;
    } else n !== "$" && n !== "$?" && n !== "$!" || r++;
    n = l;
  } while (n);
  Fn(t);
}
function ut(e) {
  for (; e != null; e = e.nextSibling) {
    var t = e.nodeType;
    if (t === 1 || t === 3) break;
    if (t === 8) {
      if (t = e.data, t === "$" || t === "$!" || t === "$?") break;
      if (t === "/$") return null;
    }
  }
  return e;
}
function fi(e) {
  e = e.previousSibling;
  for (var t = 0; e; ) {
    if (e.nodeType === 8) {
      var n = e.data;
      if (n === "$" || n === "$!" || n === "$?") {
        if (t === 0) return e;
        t--;
      } else n === "/$" && t++;
    }
    e = e.previousSibling;
  }
  return null;
}
var un = Math.random().toString(36).slice(2), je = "__reactFiber$" + un, Vn = "__reactProps$" + un, Ke = "__reactContainer$" + un, ho = "__reactEvents$" + un, $f = "__reactListeners$" + un, Bf = "__reactHandles$" + un;
function kt(e) {
  var t = e[je];
  if (t) return t;
  for (var n = e.parentNode; n; ) {
    if (t = n[Ke] || n[je]) {
      if (n = t.alternate, t.child !== null || n !== null && n.child !== null) for (e = fi(e); e !== null; ) {
        if (n = e[je]) return n;
        e = fi(e);
      }
      return t;
    }
    e = n, n = e.parentNode;
  }
  return null;
}
function Jn(e) {
  return e = e[je] || e[Ke], !e || e.tag !== 5 && e.tag !== 6 && e.tag !== 13 && e.tag !== 3 ? null : e;
}
function Ut(e) {
  if (e.tag === 5 || e.tag === 6) return e.stateNode;
  throw Error(y(33));
}
function ll(e) {
  return e[Vn] || null;
}
var yo = [], $t = -1;
function mt(e) {
  return { current: e };
}
function U(e) {
  0 > $t || (e.current = yo[$t], yo[$t] = null, $t--);
}
function I(e, t) {
  $t++, yo[$t] = e.current, e.current = t;
}
var dt = {}, le = mt(dt), fe = mt(!1), _t = dt;
function qt(e, t) {
  var n = e.type.contextTypes;
  if (!n) return dt;
  var r = e.stateNode;
  if (r && r.__reactInternalMemoizedUnmaskedChildContext === t) return r.__reactInternalMemoizedMaskedChildContext;
  var l = {}, o;
  for (o in n) l[o] = t[o];
  return r && (e = e.stateNode, e.__reactInternalMemoizedUnmaskedChildContext = t, e.__reactInternalMemoizedMaskedChildContext = l), l;
}
function de(e) {
  return e = e.childContextTypes, e != null;
}
function $r() {
  U(fe), U(le);
}
function di(e, t, n) {
  if (le.current !== dt) throw Error(y(168));
  I(le, t), I(fe, n);
}
function Xs(e, t, n) {
  var r = e.stateNode;
  if (t = t.childContextTypes, typeof r.getChildContext != "function") return n;
  r = r.getChildContext();
  for (var l in r) if (!(l in t)) throw Error(y(108, xc(e) || "Unknown", l));
  return A({}, n, r);
}
function Br(e) {
  return e = (e = e.stateNode) && e.__reactInternalMemoizedMergedChildContext || dt, _t = le.current, I(le, e), I(fe, fe.current), !0;
}
function pi(e, t, n) {
  var r = e.stateNode;
  if (!r) throw Error(y(169));
  n ? (e = Xs(e, t, _t), r.__reactInternalMemoizedMergedChildContext = e, U(fe), U(le), I(le, e)) : U(fe), I(fe, n);
}
var Ve = null, ol = !1, Il = !1;
function Gs(e) {
  Ve === null ? Ve = [e] : Ve.push(e);
}
function Vf(e) {
  ol = !0, Gs(e);
}
function vt() {
  if (!Il && Ve !== null) {
    Il = !0;
    var e = 0, t = D;
    try {
      var n = Ve;
      for (D = 1; e < n.length; e++) {
        var r = n[e];
        do
          r = r(!0);
        while (r !== null);
      }
      Ve = null, ol = !1;
    } catch (l) {
      throw Ve !== null && (Ve = Ve.slice(e + 1)), ks(Go, vt), l;
    } finally {
      D = t, Il = !1;
    }
  }
  return null;
}
var Bt = [], Vt = 0, Vr = null, Ar = 0, Se = [], Ee = 0, Nt = null, Ae = 1, He = "";
function gt(e, t) {
  Bt[Vt++] = Ar, Bt[Vt++] = Vr, Vr = e, Ar = t;
}
function Zs(e, t, n) {
  Se[Ee++] = Ae, Se[Ee++] = He, Se[Ee++] = Nt, Nt = e;
  var r = Ae;
  e = He;
  var l = 32 - Re(r) - 1;
  r &= ~(1 << l), n += 1;
  var o = 32 - Re(t) + l;
  if (30 < o) {
    var u = l - l % 5;
    o = (r & (1 << u) - 1).toString(32), r >>= u, l -= u, Ae = 1 << 32 - Re(t) + l | n << l | r, He = o + e;
  } else Ae = 1 << o | n << l | r, He = e;
}
function lu(e) {
  e.return !== null && (gt(e, 1), Zs(e, 1, 0));
}
function ou(e) {
  for (; e === Vr; ) Vr = Bt[--Vt], Bt[Vt] = null, Ar = Bt[--Vt], Bt[Vt] = null;
  for (; e === Nt; ) Nt = Se[--Ee], Se[Ee] = null, He = Se[--Ee], Se[Ee] = null, Ae = Se[--Ee], Se[Ee] = null;
}
var ye = null, he = null, $ = !1, Me = null;
function Js(e, t) {
  var n = xe(5, null, null, 0);
  n.elementType = "DELETED", n.stateNode = t, n.return = e, t = e.deletions, t === null ? (e.deletions = [n], e.flags |= 16) : t.push(n);
}
function mi(e, t) {
  switch (e.tag) {
    case 5:
      var n = e.type;
      return t = t.nodeType !== 1 || n.toLowerCase() !== t.nodeName.toLowerCase() ? null : t, t !== null ? (e.stateNode = t, ye = e, he = ut(t.firstChild), !0) : !1;
    case 6:
      return t = e.pendingProps === "" || t.nodeType !== 3 ? null : t, t !== null ? (e.stateNode = t, ye = e, he = null, !0) : !1;
    case 13:
      return t = t.nodeType !== 8 ? null : t, t !== null ? (n = Nt !== null ? { id: Ae, overflow: He } : null, e.memoizedState = { dehydrated: t, treeContext: n, retryLane: 1073741824 }, n = xe(18, null, null, 0), n.stateNode = t, n.return = e, e.child = n, ye = e, he = null, !0) : !1;
    default:
      return !1;
  }
}
function go(e) {
  return (e.mode & 1) !== 0 && (e.flags & 128) === 0;
}
function wo(e) {
  if ($) {
    var t = he;
    if (t) {
      var n = t;
      if (!mi(e, t)) {
        if (go(e)) throw Error(y(418));
        t = ut(n.nextSibling);
        var r = ye;
        t && mi(e, t) ? Js(r, n) : (e.flags = e.flags & -4097 | 2, $ = !1, ye = e);
      }
    } else {
      if (go(e)) throw Error(y(418));
      e.flags = e.flags & -4097 | 2, $ = !1, ye = e;
    }
  }
}
function vi(e) {
  for (e = e.return; e !== null && e.tag !== 5 && e.tag !== 3 && e.tag !== 13; ) e = e.return;
  ye = e;
}
function dr(e) {
  if (e !== ye) return !1;
  if (!$) return vi(e), $ = !0, !1;
  var t;
  if ((t = e.tag !== 3) && !(t = e.tag !== 5) && (t = e.type, t = t !== "head" && t !== "body" && !mo(e.type, e.memoizedProps)), t && (t = he)) {
    if (go(e)) throw qs(), Error(y(418));
    for (; t; ) Js(e, t), t = ut(t.nextSibling);
  }
  if (vi(e), e.tag === 13) {
    if (e = e.memoizedState, e = e !== null ? e.dehydrated : null, !e) throw Error(y(317));
    e: {
      for (e = e.nextSibling, t = 0; e; ) {
        if (e.nodeType === 8) {
          var n = e.data;
          if (n === "/$") {
            if (t === 0) {
              he = ut(e.nextSibling);
              break e;
            }
            t--;
          } else n !== "$" && n !== "$!" && n !== "$?" || t++;
        }
        e = e.nextSibling;
      }
      he = null;
    }
  } else he = ye ? ut(e.stateNode.nextSibling) : null;
  return !0;
}
function qs() {
  for (var e = he; e; ) e = ut(e.nextSibling);
}
function bt() {
  he = ye = null, $ = !1;
}
function uu(e) {
  Me === null ? Me = [e] : Me.push(e);
}
var Af = Ge.ReactCurrentBatchConfig;
function vn(e, t, n) {
  if (e = n.ref, e !== null && typeof e != "function" && typeof e != "object") {
    if (n._owner) {
      if (n = n._owner, n) {
        if (n.tag !== 1) throw Error(y(309));
        var r = n.stateNode;
      }
      if (!r) throw Error(y(147, e));
      var l = r, o = "" + e;
      return t !== null && t.ref !== null && typeof t.ref == "function" && t.ref._stringRef === o ? t.ref : (t = function(u) {
        var i = l.refs;
        u === null ? delete i[o] : i[o] = u;
      }, t._stringRef = o, t);
    }
    if (typeof e != "string") throw Error(y(284));
    if (!n._owner) throw Error(y(290, e));
  }
  return e;
}
function pr(e, t) {
  throw e = Object.prototype.toString.call(t), Error(y(31, e === "[object Object]" ? "object with keys {" + Object.keys(t).join(", ") + "}" : e));
}
function hi(e) {
  var t = e._init;
  return t(e._payload);
}
function bs(e) {
  function t(f, a) {
    if (e) {
      var d = f.deletions;
      d === null ? (f.deletions = [a], f.flags |= 16) : d.push(a);
    }
  }
  function n(f, a) {
    if (!e) return null;
    for (; a !== null; ) t(f, a), a = a.sibling;
    return null;
  }
  function r(f, a) {
    for (f = /* @__PURE__ */ new Map(); a !== null; ) a.key !== null ? f.set(a.key, a) : f.set(a.index, a), a = a.sibling;
    return f;
  }
  function l(f, a) {
    return f = ct(f, a), f.index = 0, f.sibling = null, f;
  }
  function o(f, a, d) {
    return f.index = d, e ? (d = f.alternate, d !== null ? (d = d.index, d < a ? (f.flags |= 2, a) : d) : (f.flags |= 2, a)) : (f.flags |= 1048576, a);
  }
  function u(f) {
    return e && f.alternate === null && (f.flags |= 2), f;
  }
  function i(f, a, d, h) {
    return a === null || a.tag !== 6 ? (a = Al(d, f.mode, h), a.return = f, a) : (a = l(a, d), a.return = f, a);
  }
  function s(f, a, d, h) {
    var E = d.type;
    return E === Dt ? v(f, a, d.props.children, h, d.key) : a !== null && (a.elementType === E || typeof E == "object" && E !== null && E.$$typeof === Je && hi(E) === a.type) ? (h = l(a, d.props), h.ref = vn(f, a, d), h.return = f, h) : (h = Lr(d.type, d.key, d.props, null, f.mode, h), h.ref = vn(f, a, d), h.return = f, h);
  }
  function c(f, a, d, h) {
    return a === null || a.tag !== 4 || a.stateNode.containerInfo !== d.containerInfo || a.stateNode.implementation !== d.implementation ? (a = Hl(d, f.mode, h), a.return = f, a) : (a = l(a, d.children || []), a.return = f, a);
  }
  function v(f, a, d, h, E) {
    return a === null || a.tag !== 7 ? (a = Ct(d, f.mode, h, E), a.return = f, a) : (a = l(a, d), a.return = f, a);
  }
  function m(f, a, d) {
    if (typeof a == "string" && a !== "" || typeof a == "number") return a = Al("" + a, f.mode, d), a.return = f, a;
    if (typeof a == "object" && a !== null) {
      switch (a.$$typeof) {
        case nr:
          return d = Lr(a.type, a.key, a.props, null, f.mode, d), d.ref = vn(f, null, a), d.return = f, d;
        case Ot:
          return a = Hl(a, f.mode, d), a.return = f, a;
        case Je:
          var h = a._init;
          return m(f, h(a._payload), d);
      }
      if (wn(a) || cn(a)) return a = Ct(a, f.mode, d, null), a.return = f, a;
      pr(f, a);
    }
    return null;
  }
  function p(f, a, d, h) {
    var E = a !== null ? a.key : null;
    if (typeof d == "string" && d !== "" || typeof d == "number") return E !== null ? null : i(f, a, "" + d, h);
    if (typeof d == "object" && d !== null) {
      switch (d.$$typeof) {
        case nr:
          return d.key === E ? s(f, a, d, h) : null;
        case Ot:
          return d.key === E ? c(f, a, d, h) : null;
        case Je:
          return E = d._init, p(
            f,
            a,
            E(d._payload),
            h
          );
      }
      if (wn(d) || cn(d)) return E !== null ? null : v(f, a, d, h, null);
      pr(f, d);
    }
    return null;
  }
  function g(f, a, d, h, E) {
    if (typeof h == "string" && h !== "" || typeof h == "number") return f = f.get(d) || null, i(a, f, "" + h, E);
    if (typeof h == "object" && h !== null) {
      switch (h.$$typeof) {
        case nr:
          return f = f.get(h.key === null ? d : h.key) || null, s(a, f, h, E);
        case Ot:
          return f = f.get(h.key === null ? d : h.key) || null, c(a, f, h, E);
        case Je:
          var _ = h._init;
          return g(f, a, d, _(h._payload), E);
      }
      if (wn(h) || cn(h)) return f = f.get(d) || null, v(a, f, h, E, null);
      pr(a, h);
    }
    return null;
  }
  function k(f, a, d, h) {
    for (var E = null, _ = null, N = a, z = a = 0, F = null; N !== null && z < d.length; z++) {
      N.index > z ? (F = N, N = null) : F = N.sibling;
      var T = p(f, N, d[z], h);
      if (T === null) {
        N === null && (N = F);
        break;
      }
      e && N && T.alternate === null && t(f, N), a = o(T, a, z), _ === null ? E = T : _.sibling = T, _ = T, N = F;
    }
    if (z === d.length) return n(f, N), $ && gt(f, z), E;
    if (N === null) {
      for (; z < d.length; z++) N = m(f, d[z], h), N !== null && (a = o(N, a, z), _ === null ? E = N : _.sibling = N, _ = N);
      return $ && gt(f, z), E;
    }
    for (N = r(f, N); z < d.length; z++) F = g(N, f, z, d[z], h), F !== null && (e && F.alternate !== null && N.delete(F.key === null ? z : F.key), a = o(F, a, z), _ === null ? E = F : _.sibling = F, _ = F);
    return e && N.forEach(function(ze) {
      return t(f, ze);
    }), $ && gt(f, z), E;
  }
  function S(f, a, d, h) {
    var E = cn(d);
    if (typeof E != "function") throw Error(y(150));
    if (d = E.call(d), d == null) throw Error(y(151));
    for (var _ = E = null, N = a, z = a = 0, F = null, T = d.next(); N !== null && !T.done; z++, T = d.next()) {
      N.index > z ? (F = N, N = null) : F = N.sibling;
      var ze = p(f, N, T.value, h);
      if (ze === null) {
        N === null && (N = F);
        break;
      }
      e && N && ze.alternate === null && t(f, N), a = o(ze, a, z), _ === null ? E = ze : _.sibling = ze, _ = ze, N = F;
    }
    if (T.done) return n(
      f,
      N
    ), $ && gt(f, z), E;
    if (N === null) {
      for (; !T.done; z++, T = d.next()) T = m(f, T.value, h), T !== null && (a = o(T, a, z), _ === null ? E = T : _.sibling = T, _ = T);
      return $ && gt(f, z), E;
    }
    for (N = r(f, N); !T.done; z++, T = d.next()) T = g(N, f, z, T.value, h), T !== null && (e && T.alternate !== null && N.delete(T.key === null ? z : T.key), a = o(T, a, z), _ === null ? E = T : _.sibling = T, _ = T);
    return e && N.forEach(function(sn) {
      return t(f, sn);
    }), $ && gt(f, z), E;
  }
  function O(f, a, d, h) {
    if (typeof d == "object" && d !== null && d.type === Dt && d.key === null && (d = d.props.children), typeof d == "object" && d !== null) {
      switch (d.$$typeof) {
        case nr:
          e: {
            for (var E = d.key, _ = a; _ !== null; ) {
              if (_.key === E) {
                if (E = d.type, E === Dt) {
                  if (_.tag === 7) {
                    n(f, _.sibling), a = l(_, d.props.children), a.return = f, f = a;
                    break e;
                  }
                } else if (_.elementType === E || typeof E == "object" && E !== null && E.$$typeof === Je && hi(E) === _.type) {
                  n(f, _.sibling), a = l(_, d.props), a.ref = vn(f, _, d), a.return = f, f = a;
                  break e;
                }
                n(f, _);
                break;
              } else t(f, _);
              _ = _.sibling;
            }
            d.type === Dt ? (a = Ct(d.props.children, f.mode, h, d.key), a.return = f, f = a) : (h = Lr(d.type, d.key, d.props, null, f.mode, h), h.ref = vn(f, a, d), h.return = f, f = h);
          }
          return u(f);
        case Ot:
          e: {
            for (_ = d.key; a !== null; ) {
              if (a.key === _) if (a.tag === 4 && a.stateNode.containerInfo === d.containerInfo && a.stateNode.implementation === d.implementation) {
                n(f, a.sibling), a = l(a, d.children || []), a.return = f, f = a;
                break e;
              } else {
                n(f, a);
                break;
              }
              else t(f, a);
              a = a.sibling;
            }
            a = Hl(d, f.mode, h), a.return = f, f = a;
          }
          return u(f);
        case Je:
          return _ = d._init, O(f, a, _(d._payload), h);
      }
      if (wn(d)) return k(f, a, d, h);
      if (cn(d)) return S(f, a, d, h);
      pr(f, d);
    }
    return typeof d == "string" && d !== "" || typeof d == "number" ? (d = "" + d, a !== null && a.tag === 6 ? (n(f, a.sibling), a = l(a, d), a.return = f, f = a) : (n(f, a), a = Al(d, f.mode, h), a.return = f, f = a), u(f)) : n(f, a);
  }
  return O;
}
var en = bs(!0), ea = bs(!1), Hr = mt(null), Wr = null, At = null, iu = null;
function su() {
  iu = At = Wr = null;
}
function au(e) {
  var t = Hr.current;
  U(Hr), e._currentValue = t;
}
function ko(e, t, n) {
  for (; e !== null; ) {
    var r = e.alternate;
    if ((e.childLanes & t) !== t ? (e.childLanes |= t, r !== null && (r.childLanes |= t)) : r !== null && (r.childLanes & t) !== t && (r.childLanes |= t), e === n) break;
    e = e.return;
  }
}
function Gt(e, t) {
  Wr = e, iu = At = null, e = e.dependencies, e !== null && e.firstContext !== null && (e.lanes & t && (ce = !0), e.firstContext = null);
}
function _e(e) {
  var t = e._currentValue;
  if (iu !== e) if (e = { context: e, memoizedValue: t, next: null }, At === null) {
    if (Wr === null) throw Error(y(308));
    At = e, Wr.dependencies = { lanes: 0, firstContext: e };
  } else At = At.next = e;
  return t;
}
var St = null;
function cu(e) {
  St === null ? St = [e] : St.push(e);
}
function ta(e, t, n, r) {
  var l = t.interleaved;
  return l === null ? (n.next = n, cu(t)) : (n.next = l.next, l.next = n), t.interleaved = n, Ye(e, r);
}
function Ye(e, t) {
  e.lanes |= t;
  var n = e.alternate;
  for (n !== null && (n.lanes |= t), n = e, e = e.return; e !== null; ) e.childLanes |= t, n = e.alternate, n !== null && (n.childLanes |= t), n = e, e = e.return;
  return n.tag === 3 ? n.stateNode : null;
}
var qe = !1;
function fu(e) {
  e.updateQueue = { baseState: e.memoizedState, firstBaseUpdate: null, lastBaseUpdate: null, shared: { pending: null, interleaved: null, lanes: 0 }, effects: null };
}
function na(e, t) {
  e = e.updateQueue, t.updateQueue === e && (t.updateQueue = { baseState: e.baseState, firstBaseUpdate: e.firstBaseUpdate, lastBaseUpdate: e.lastBaseUpdate, shared: e.shared, effects: e.effects });
}
function We(e, t) {
  return { eventTime: e, lane: t, tag: 0, payload: null, callback: null, next: null };
}
function it(e, t, n) {
  var r = e.updateQueue;
  if (r === null) return null;
  if (r = r.shared, R & 2) {
    var l = r.pending;
    return l === null ? t.next = t : (t.next = l.next, l.next = t), r.pending = t, Ye(e, n);
  }
  return l = r.interleaved, l === null ? (t.next = t, cu(r)) : (t.next = l.next, l.next = t), r.interleaved = t, Ye(e, n);
}
function xr(e, t, n) {
  if (t = t.updateQueue, t !== null && (t = t.shared, (n & 4194240) !== 0)) {
    var r = t.lanes;
    r &= e.pendingLanes, n |= r, t.lanes = n, Zo(e, n);
  }
}
function yi(e, t) {
  var n = e.updateQueue, r = e.alternate;
  if (r !== null && (r = r.updateQueue, n === r)) {
    var l = null, o = null;
    if (n = n.firstBaseUpdate, n !== null) {
      do {
        var u = { eventTime: n.eventTime, lane: n.lane, tag: n.tag, payload: n.payload, callback: n.callback, next: null };
        o === null ? l = o = u : o = o.next = u, n = n.next;
      } while (n !== null);
      o === null ? l = o = t : o = o.next = t;
    } else l = o = t;
    n = { baseState: r.baseState, firstBaseUpdate: l, lastBaseUpdate: o, shared: r.shared, effects: r.effects }, e.updateQueue = n;
    return;
  }
  e = n.lastBaseUpdate, e === null ? n.firstBaseUpdate = t : e.next = t, n.lastBaseUpdate = t;
}
function Qr(e, t, n, r) {
  var l = e.updateQueue;
  qe = !1;
  var o = l.firstBaseUpdate, u = l.lastBaseUpdate, i = l.shared.pending;
  if (i !== null) {
    l.shared.pending = null;
    var s = i, c = s.next;
    s.next = null, u === null ? o = c : u.next = c, u = s;
    var v = e.alternate;
    v !== null && (v = v.updateQueue, i = v.lastBaseUpdate, i !== u && (i === null ? v.firstBaseUpdate = c : i.next = c, v.lastBaseUpdate = s));
  }
  if (o !== null) {
    var m = l.baseState;
    u = 0, v = c = s = null, i = o;
    do {
      var p = i.lane, g = i.eventTime;
      if ((r & p) === p) {
        v !== null && (v = v.next = {
          eventTime: g,
          lane: 0,
          tag: i.tag,
          payload: i.payload,
          callback: i.callback,
          next: null
        });
        e: {
          var k = e, S = i;
          switch (p = t, g = n, S.tag) {
            case 1:
              if (k = S.payload, typeof k == "function") {
                m = k.call(g, m, p);
                break e;
              }
              m = k;
              break e;
            case 3:
              k.flags = k.flags & -65537 | 128;
            case 0:
              if (k = S.payload, p = typeof k == "function" ? k.call(g, m, p) : k, p == null) break e;
              m = A({}, m, p);
              break e;
            case 2:
              qe = !0;
          }
        }
        i.callback !== null && i.lane !== 0 && (e.flags |= 64, p = l.effects, p === null ? l.effects = [i] : p.push(i));
      } else g = { eventTime: g, lane: p, tag: i.tag, payload: i.payload, callback: i.callback, next: null }, v === null ? (c = v = g, s = m) : v = v.next = g, u |= p;
      if (i = i.next, i === null) {
        if (i = l.shared.pending, i === null) break;
        p = i, i = p.next, p.next = null, l.lastBaseUpdate = p, l.shared.pending = null;
      }
    } while (!0);
    if (v === null && (s = m), l.baseState = s, l.firstBaseUpdate = c, l.lastBaseUpdate = v, t = l.shared.interleaved, t !== null) {
      l = t;
      do
        u |= l.lane, l = l.next;
      while (l !== t);
    } else o === null && (l.shared.lanes = 0);
    Pt |= u, e.lanes = u, e.memoizedState = m;
  }
}
function gi(e, t, n) {
  if (e = t.effects, t.effects = null, e !== null) for (t = 0; t < e.length; t++) {
    var r = e[t], l = r.callback;
    if (l !== null) {
      if (r.callback = null, r = n, typeof l != "function") throw Error(y(191, l));
      l.call(r);
    }
  }
}
var qn = {}, $e = mt(qn), An = mt(qn), Hn = mt(qn);
function Et(e) {
  if (e === qn) throw Error(y(174));
  return e;
}
function du(e, t) {
  switch (I(Hn, t), I(An, e), I($e, qn), e = t.nodeType, e) {
    case 9:
    case 11:
      t = (t = t.documentElement) ? t.namespaceURI : bl(null, "");
      break;
    default:
      e = e === 8 ? t.parentNode : t, t = e.namespaceURI || null, e = e.tagName, t = bl(t, e);
  }
  U($e), I($e, t);
}
function tn() {
  U($e), U(An), U(Hn);
}
function ra(e) {
  Et(Hn.current);
  var t = Et($e.current), n = bl(t, e.type);
  t !== n && (I(An, e), I($e, n));
}
function pu(e) {
  An.current === e && (U($e), U(An));
}
var B = mt(0);
function Kr(e) {
  for (var t = e; t !== null; ) {
    if (t.tag === 13) {
      var n = t.memoizedState;
      if (n !== null && (n = n.dehydrated, n === null || n.data === "$?" || n.data === "$!")) return t;
    } else if (t.tag === 19 && t.memoizedProps.revealOrder !== void 0) {
      if (t.flags & 128) return t;
    } else if (t.child !== null) {
      t.child.return = t, t = t.child;
      continue;
    }
    if (t === e) break;
    for (; t.sibling === null; ) {
      if (t.return === null || t.return === e) return null;
      t = t.return;
    }
    t.sibling.return = t.return, t = t.sibling;
  }
  return null;
}
var Fl = [];
function mu() {
  for (var e = 0; e < Fl.length; e++) Fl[e]._workInProgressVersionPrimary = null;
  Fl.length = 0;
}
var Cr = Ge.ReactCurrentDispatcher, jl = Ge.ReactCurrentBatchConfig, zt = 0, V = null, Y = null, Z = null, Yr = !1, zn = !1, Wn = 0, Hf = 0;
function te() {
  throw Error(y(321));
}
function vu(e, t) {
  if (t === null) return !1;
  for (var n = 0; n < t.length && n < e.length; n++) if (!De(e[n], t[n])) return !1;
  return !0;
}
function hu(e, t, n, r, l, o) {
  if (zt = o, V = t, t.memoizedState = null, t.updateQueue = null, t.lanes = 0, Cr.current = e === null || e.memoizedState === null ? Yf : Xf, e = n(r, l), zn) {
    o = 0;
    do {
      if (zn = !1, Wn = 0, 25 <= o) throw Error(y(301));
      o += 1, Z = Y = null, t.updateQueue = null, Cr.current = Gf, e = n(r, l);
    } while (zn);
  }
  if (Cr.current = Xr, t = Y !== null && Y.next !== null, zt = 0, Z = Y = V = null, Yr = !1, t) throw Error(y(300));
  return e;
}
function yu() {
  var e = Wn !== 0;
  return Wn = 0, e;
}
function Fe() {
  var e = { memoizedState: null, baseState: null, baseQueue: null, queue: null, next: null };
  return Z === null ? V.memoizedState = Z = e : Z = Z.next = e, Z;
}
function Ne() {
  if (Y === null) {
    var e = V.alternate;
    e = e !== null ? e.memoizedState : null;
  } else e = Y.next;
  var t = Z === null ? V.memoizedState : Z.next;
  if (t !== null) Z = t, Y = e;
  else {
    if (e === null) throw Error(y(310));
    Y = e, e = { memoizedState: Y.memoizedState, baseState: Y.baseState, baseQueue: Y.baseQueue, queue: Y.queue, next: null }, Z === null ? V.memoizedState = Z = e : Z = Z.next = e;
  }
  return Z;
}
function Qn(e, t) {
  return typeof t == "function" ? t(e) : t;
}
function Ul(e) {
  var t = Ne(), n = t.queue;
  if (n === null) throw Error(y(311));
  n.lastRenderedReducer = e;
  var r = Y, l = r.baseQueue, o = n.pending;
  if (o !== null) {
    if (l !== null) {
      var u = l.next;
      l.next = o.next, o.next = u;
    }
    r.baseQueue = l = o, n.pending = null;
  }
  if (l !== null) {
    o = l.next, r = r.baseState;
    var i = u = null, s = null, c = o;
    do {
      var v = c.lane;
      if ((zt & v) === v) s !== null && (s = s.next = { lane: 0, action: c.action, hasEagerState: c.hasEagerState, eagerState: c.eagerState, next: null }), r = c.hasEagerState ? c.eagerState : e(r, c.action);
      else {
        var m = {
          lane: v,
          action: c.action,
          hasEagerState: c.hasEagerState,
          eagerState: c.eagerState,
          next: null
        };
        s === null ? (i = s = m, u = r) : s = s.next = m, V.lanes |= v, Pt |= v;
      }
      c = c.next;
    } while (c !== null && c !== o);
    s === null ? u = r : s.next = i, De(r, t.memoizedState) || (ce = !0), t.memoizedState = r, t.baseState = u, t.baseQueue = s, n.lastRenderedState = r;
  }
  if (e = n.interleaved, e !== null) {
    l = e;
    do
      o = l.lane, V.lanes |= o, Pt |= o, l = l.next;
    while (l !== e);
  } else l === null && (n.lanes = 0);
  return [t.memoizedState, n.dispatch];
}
function $l(e) {
  var t = Ne(), n = t.queue;
  if (n === null) throw Error(y(311));
  n.lastRenderedReducer = e;
  var r = n.dispatch, l = n.pending, o = t.memoizedState;
  if (l !== null) {
    n.pending = null;
    var u = l = l.next;
    do
      o = e(o, u.action), u = u.next;
    while (u !== l);
    De(o, t.memoizedState) || (ce = !0), t.memoizedState = o, t.baseQueue === null && (t.baseState = o), n.lastRenderedState = o;
  }
  return [o, r];
}
function la() {
}
function oa(e, t) {
  var n = V, r = Ne(), l = t(), o = !De(r.memoizedState, l);
  if (o && (r.memoizedState = l, ce = !0), r = r.queue, gu(sa.bind(null, n, r, e), [e]), r.getSnapshot !== t || o || Z !== null && Z.memoizedState.tag & 1) {
    if (n.flags |= 2048, Kn(9, ia.bind(null, n, r, l, t), void 0, null), J === null) throw Error(y(349));
    zt & 30 || ua(n, t, l);
  }
  return l;
}
function ua(e, t, n) {
  e.flags |= 16384, e = { getSnapshot: t, value: n }, t = V.updateQueue, t === null ? (t = { lastEffect: null, stores: null }, V.updateQueue = t, t.stores = [e]) : (n = t.stores, n === null ? t.stores = [e] : n.push(e));
}
function ia(e, t, n, r) {
  t.value = n, t.getSnapshot = r, aa(t) && ca(e);
}
function sa(e, t, n) {
  return n(function() {
    aa(t) && ca(e);
  });
}
function aa(e) {
  var t = e.getSnapshot;
  e = e.value;
  try {
    var n = t();
    return !De(e, n);
  } catch {
    return !0;
  }
}
function ca(e) {
  var t = Ye(e, 1);
  t !== null && Oe(t, e, 1, -1);
}
function wi(e) {
  var t = Fe();
  return typeof e == "function" && (e = e()), t.memoizedState = t.baseState = e, e = { pending: null, interleaved: null, lanes: 0, dispatch: null, lastRenderedReducer: Qn, lastRenderedState: e }, t.queue = e, e = e.dispatch = Kf.bind(null, V, e), [t.memoizedState, e];
}
function Kn(e, t, n, r) {
  return e = { tag: e, create: t, destroy: n, deps: r, next: null }, t = V.updateQueue, t === null ? (t = { lastEffect: null, stores: null }, V.updateQueue = t, t.lastEffect = e.next = e) : (n = t.lastEffect, n === null ? t.lastEffect = e.next = e : (r = n.next, n.next = e, e.next = r, t.lastEffect = e)), e;
}
function fa() {
  return Ne().memoizedState;
}
function _r(e, t, n, r) {
  var l = Fe();
  V.flags |= e, l.memoizedState = Kn(1 | t, n, void 0, r === void 0 ? null : r);
}
function ul(e, t, n, r) {
  var l = Ne();
  r = r === void 0 ? null : r;
  var o = void 0;
  if (Y !== null) {
    var u = Y.memoizedState;
    if (o = u.destroy, r !== null && vu(r, u.deps)) {
      l.memoizedState = Kn(t, n, o, r);
      return;
    }
  }
  V.flags |= e, l.memoizedState = Kn(1 | t, n, o, r);
}
function ki(e, t) {
  return _r(8390656, 8, e, t);
}
function gu(e, t) {
  return ul(2048, 8, e, t);
}
function da(e, t) {
  return ul(4, 2, e, t);
}
function pa(e, t) {
  return ul(4, 4, e, t);
}
function ma(e, t) {
  if (typeof t == "function") return e = e(), t(e), function() {
    t(null);
  };
  if (t != null) return e = e(), t.current = e, function() {
    t.current = null;
  };
}
function va(e, t, n) {
  return n = n != null ? n.concat([e]) : null, ul(4, 4, ma.bind(null, t, e), n);
}
function wu() {
}
function ha(e, t) {
  var n = Ne();
  t = t === void 0 ? null : t;
  var r = n.memoizedState;
  return r !== null && t !== null && vu(t, r[1]) ? r[0] : (n.memoizedState = [e, t], e);
}
function ya(e, t) {
  var n = Ne();
  t = t === void 0 ? null : t;
  var r = n.memoizedState;
  return r !== null && t !== null && vu(t, r[1]) ? r[0] : (e = e(), n.memoizedState = [e, t], e);
}
function ga(e, t, n) {
  return zt & 21 ? (De(n, t) || (n = xs(), V.lanes |= n, Pt |= n, e.baseState = !0), t) : (e.baseState && (e.baseState = !1, ce = !0), e.memoizedState = n);
}
function Wf(e, t) {
  var n = D;
  D = n !== 0 && 4 > n ? n : 4, e(!0);
  var r = jl.transition;
  jl.transition = {};
  try {
    e(!1), t();
  } finally {
    D = n, jl.transition = r;
  }
}
function wa() {
  return Ne().memoizedState;
}
function Qf(e, t, n) {
  var r = at(e);
  if (n = { lane: r, action: n, hasEagerState: !1, eagerState: null, next: null }, ka(e)) Sa(t, n);
  else if (n = ta(e, t, n, r), n !== null) {
    var l = ue();
    Oe(n, e, r, l), Ea(n, t, r);
  }
}
function Kf(e, t, n) {
  var r = at(e), l = { lane: r, action: n, hasEagerState: !1, eagerState: null, next: null };
  if (ka(e)) Sa(t, l);
  else {
    var o = e.alternate;
    if (e.lanes === 0 && (o === null || o.lanes === 0) && (o = t.lastRenderedReducer, o !== null)) try {
      var u = t.lastRenderedState, i = o(u, n);
      if (l.hasEagerState = !0, l.eagerState = i, De(i, u)) {
        var s = t.interleaved;
        s === null ? (l.next = l, cu(t)) : (l.next = s.next, s.next = l), t.interleaved = l;
        return;
      }
    } catch {
    } finally {
    }
    n = ta(e, t, l, r), n !== null && (l = ue(), Oe(n, e, r, l), Ea(n, t, r));
  }
}
function ka(e) {
  var t = e.alternate;
  return e === V || t !== null && t === V;
}
function Sa(e, t) {
  zn = Yr = !0;
  var n = e.pending;
  n === null ? t.next = t : (t.next = n.next, n.next = t), e.pending = t;
}
function Ea(e, t, n) {
  if (n & 4194240) {
    var r = t.lanes;
    r &= e.pendingLanes, n |= r, t.lanes = n, Zo(e, n);
  }
}
var Xr = { readContext: _e, useCallback: te, useContext: te, useEffect: te, useImperativeHandle: te, useInsertionEffect: te, useLayoutEffect: te, useMemo: te, useReducer: te, useRef: te, useState: te, useDebugValue: te, useDeferredValue: te, useTransition: te, useMutableSource: te, useSyncExternalStore: te, useId: te, unstable_isNewReconciler: !1 }, Yf = { readContext: _e, useCallback: function(e, t) {
  return Fe().memoizedState = [e, t === void 0 ? null : t], e;
}, useContext: _e, useEffect: ki, useImperativeHandle: function(e, t, n) {
  return n = n != null ? n.concat([e]) : null, _r(
    4194308,
    4,
    ma.bind(null, t, e),
    n
  );
}, useLayoutEffect: function(e, t) {
  return _r(4194308, 4, e, t);
}, useInsertionEffect: function(e, t) {
  return _r(4, 2, e, t);
}, useMemo: function(e, t) {
  var n = Fe();
  return t = t === void 0 ? null : t, e = e(), n.memoizedState = [e, t], e;
}, useReducer: function(e, t, n) {
  var r = Fe();
  return t = n !== void 0 ? n(t) : t, r.memoizedState = r.baseState = t, e = { pending: null, interleaved: null, lanes: 0, dispatch: null, lastRenderedReducer: e, lastRenderedState: t }, r.queue = e, e = e.dispatch = Qf.bind(null, V, e), [r.memoizedState, e];
}, useRef: function(e) {
  var t = Fe();
  return e = { current: e }, t.memoizedState = e;
}, useState: wi, useDebugValue: wu, useDeferredValue: function(e) {
  return Fe().memoizedState = e;
}, useTransition: function() {
  var e = wi(!1), t = e[0];
  return e = Wf.bind(null, e[1]), Fe().memoizedState = e, [t, e];
}, useMutableSource: function() {
}, useSyncExternalStore: function(e, t, n) {
  var r = V, l = Fe();
  if ($) {
    if (n === void 0) throw Error(y(407));
    n = n();
  } else {
    if (n = t(), J === null) throw Error(y(349));
    zt & 30 || ua(r, t, n);
  }
  l.memoizedState = n;
  var o = { value: n, getSnapshot: t };
  return l.queue = o, ki(sa.bind(
    null,
    r,
    o,
    e
  ), [e]), r.flags |= 2048, Kn(9, ia.bind(null, r, o, n, t), void 0, null), n;
}, useId: function() {
  var e = Fe(), t = J.identifierPrefix;
  if ($) {
    var n = He, r = Ae;
    n = (r & ~(1 << 32 - Re(r) - 1)).toString(32) + n, t = ":" + t + "R" + n, n = Wn++, 0 < n && (t += "H" + n.toString(32)), t += ":";
  } else n = Hf++, t = ":" + t + "r" + n.toString(32) + ":";
  return e.memoizedState = t;
}, unstable_isNewReconciler: !1 }, Xf = {
  readContext: _e,
  useCallback: ha,
  useContext: _e,
  useEffect: gu,
  useImperativeHandle: va,
  useInsertionEffect: da,
  useLayoutEffect: pa,
  useMemo: ya,
  useReducer: Ul,
  useRef: fa,
  useState: function() {
    return Ul(Qn);
  },
  useDebugValue: wu,
  useDeferredValue: function(e) {
    var t = Ne();
    return ga(t, Y.memoizedState, e);
  },
  useTransition: function() {
    var e = Ul(Qn)[0], t = Ne().memoizedState;
    return [e, t];
  },
  useMutableSource: la,
  useSyncExternalStore: oa,
  useId: wa,
  unstable_isNewReconciler: !1
}, Gf = { readContext: _e, useCallback: ha, useContext: _e, useEffect: gu, useImperativeHandle: va, useInsertionEffect: da, useLayoutEffect: pa, useMemo: ya, useReducer: $l, useRef: fa, useState: function() {
  return $l(Qn);
}, useDebugValue: wu, useDeferredValue: function(e) {
  var t = Ne();
  return Y === null ? t.memoizedState = e : ga(t, Y.memoizedState, e);
}, useTransition: function() {
  var e = $l(Qn)[0], t = Ne().memoizedState;
  return [e, t];
}, useMutableSource: la, useSyncExternalStore: oa, useId: wa, unstable_isNewReconciler: !1 };
function Le(e, t) {
  if (e && e.defaultProps) {
    t = A({}, t), e = e.defaultProps;
    for (var n in e) t[n] === void 0 && (t[n] = e[n]);
    return t;
  }
  return t;
}
function So(e, t, n, r) {
  t = e.memoizedState, n = n(r, t), n = n == null ? t : A({}, t, n), e.memoizedState = n, e.lanes === 0 && (e.updateQueue.baseState = n);
}
var il = { isMounted: function(e) {
  return (e = e._reactInternals) ? Mt(e) === e : !1;
}, enqueueSetState: function(e, t, n) {
  e = e._reactInternals;
  var r = ue(), l = at(e), o = We(r, l);
  o.payload = t, n != null && (o.callback = n), t = it(e, o, l), t !== null && (Oe(t, e, l, r), xr(t, e, l));
}, enqueueReplaceState: function(e, t, n) {
  e = e._reactInternals;
  var r = ue(), l = at(e), o = We(r, l);
  o.tag = 1, o.payload = t, n != null && (o.callback = n), t = it(e, o, l), t !== null && (Oe(t, e, l, r), xr(t, e, l));
}, enqueueForceUpdate: function(e, t) {
  e = e._reactInternals;
  var n = ue(), r = at(e), l = We(n, r);
  l.tag = 2, t != null && (l.callback = t), t = it(e, l, r), t !== null && (Oe(t, e, r, n), xr(t, e, r));
} };
function Si(e, t, n, r, l, o, u) {
  return e = e.stateNode, typeof e.shouldComponentUpdate == "function" ? e.shouldComponentUpdate(r, o, u) : t.prototype && t.prototype.isPureReactComponent ? !Un(n, r) || !Un(l, o) : !0;
}
function xa(e, t, n) {
  var r = !1, l = dt, o = t.contextType;
  return typeof o == "object" && o !== null ? o = _e(o) : (l = de(t) ? _t : le.current, r = t.contextTypes, o = (r = r != null) ? qt(e, l) : dt), t = new t(n, o), e.memoizedState = t.state !== null && t.state !== void 0 ? t.state : null, t.updater = il, e.stateNode = t, t._reactInternals = e, r && (e = e.stateNode, e.__reactInternalMemoizedUnmaskedChildContext = l, e.__reactInternalMemoizedMaskedChildContext = o), t;
}
function Ei(e, t, n, r) {
  e = t.state, typeof t.componentWillReceiveProps == "function" && t.componentWillReceiveProps(n, r), typeof t.UNSAFE_componentWillReceiveProps == "function" && t.UNSAFE_componentWillReceiveProps(n, r), t.state !== e && il.enqueueReplaceState(t, t.state, null);
}
function Eo(e, t, n, r) {
  var l = e.stateNode;
  l.props = n, l.state = e.memoizedState, l.refs = {}, fu(e);
  var o = t.contextType;
  typeof o == "object" && o !== null ? l.context = _e(o) : (o = de(t) ? _t : le.current, l.context = qt(e, o)), l.state = e.memoizedState, o = t.getDerivedStateFromProps, typeof o == "function" && (So(e, t, o, n), l.state = e.memoizedState), typeof t.getDerivedStateFromProps == "function" || typeof l.getSnapshotBeforeUpdate == "function" || typeof l.UNSAFE_componentWillMount != "function" && typeof l.componentWillMount != "function" || (t = l.state, typeof l.componentWillMount == "function" && l.componentWillMount(), typeof l.UNSAFE_componentWillMount == "function" && l.UNSAFE_componentWillMount(), t !== l.state && il.enqueueReplaceState(l, l.state, null), Qr(e, n, l, r), l.state = e.memoizedState), typeof l.componentDidMount == "function" && (e.flags |= 4194308);
}
function nn(e, t) {
  try {
    var n = "", r = t;
    do
      n += Ec(r), r = r.return;
    while (r);
    var l = n;
  } catch (o) {
    l = `
Error generating stack: ` + o.message + `
` + o.stack;
  }
  return { value: e, source: t, stack: l, digest: null };
}
function Bl(e, t, n) {
  return { value: e, source: null, stack: n ?? null, digest: t ?? null };
}
function xo(e, t) {
  try {
    console.error(t.value);
  } catch (n) {
    setTimeout(function() {
      throw n;
    });
  }
}
var Zf = typeof WeakMap == "function" ? WeakMap : Map;
function Ca(e, t, n) {
  n = We(-1, n), n.tag = 3, n.payload = { element: null };
  var r = t.value;
  return n.callback = function() {
    Zr || (Zr = !0, Oo = r), xo(e, t);
  }, n;
}
function _a(e, t, n) {
  n = We(-1, n), n.tag = 3;
  var r = e.type.getDerivedStateFromError;
  if (typeof r == "function") {
    var l = t.value;
    n.payload = function() {
      return r(l);
    }, n.callback = function() {
      xo(e, t);
    };
  }
  var o = e.stateNode;
  return o !== null && typeof o.componentDidCatch == "function" && (n.callback = function() {
    xo(e, t), typeof r != "function" && (st === null ? st = /* @__PURE__ */ new Set([this]) : st.add(this));
    var u = t.stack;
    this.componentDidCatch(t.value, { componentStack: u !== null ? u : "" });
  }), n;
}
function xi(e, t, n) {
  var r = e.pingCache;
  if (r === null) {
    r = e.pingCache = new Zf();
    var l = /* @__PURE__ */ new Set();
    r.set(t, l);
  } else l = r.get(t), l === void 0 && (l = /* @__PURE__ */ new Set(), r.set(t, l));
  l.has(n) || (l.add(n), e = cd.bind(null, e, t, n), t.then(e, e));
}
function Ci(e) {
  do {
    var t;
    if ((t = e.tag === 13) && (t = e.memoizedState, t = t !== null ? t.dehydrated !== null : !0), t) return e;
    e = e.return;
  } while (e !== null);
  return null;
}
function _i(e, t, n, r, l) {
  return e.mode & 1 ? (e.flags |= 65536, e.lanes = l, e) : (e === t ? e.flags |= 65536 : (e.flags |= 128, n.flags |= 131072, n.flags &= -52805, n.tag === 1 && (n.alternate === null ? n.tag = 17 : (t = We(-1, 1), t.tag = 2, it(n, t, 1))), n.lanes |= 1), e);
}
var Jf = Ge.ReactCurrentOwner, ce = !1;
function oe(e, t, n, r) {
  t.child = e === null ? ea(t, null, n, r) : en(t, e.child, n, r);
}
function Ni(e, t, n, r, l) {
  n = n.render;
  var o = t.ref;
  return Gt(t, l), r = hu(e, t, n, r, o, l), n = yu(), e !== null && !ce ? (t.updateQueue = e.updateQueue, t.flags &= -2053, e.lanes &= ~l, Xe(e, t, l)) : ($ && n && lu(t), t.flags |= 1, oe(e, t, r, l), t.child);
}
function zi(e, t, n, r, l) {
  if (e === null) {
    var o = n.type;
    return typeof o == "function" && !zu(o) && o.defaultProps === void 0 && n.compare === null && n.defaultProps === void 0 ? (t.tag = 15, t.type = o, Na(e, t, o, r, l)) : (e = Lr(n.type, null, r, t, t.mode, l), e.ref = t.ref, e.return = t, t.child = e);
  }
  if (o = e.child, !(e.lanes & l)) {
    var u = o.memoizedProps;
    if (n = n.compare, n = n !== null ? n : Un, n(u, r) && e.ref === t.ref) return Xe(e, t, l);
  }
  return t.flags |= 1, e = ct(o, r), e.ref = t.ref, e.return = t, t.child = e;
}
function Na(e, t, n, r, l) {
  if (e !== null) {
    var o = e.memoizedProps;
    if (Un(o, r) && e.ref === t.ref) if (ce = !1, t.pendingProps = r = o, (e.lanes & l) !== 0) e.flags & 131072 && (ce = !0);
    else return t.lanes = e.lanes, Xe(e, t, l);
  }
  return Co(e, t, n, r, l);
}
function za(e, t, n) {
  var r = t.pendingProps, l = r.children, o = e !== null ? e.memoizedState : null;
  if (r.mode === "hidden") if (!(t.mode & 1)) t.memoizedState = { baseLanes: 0, cachePool: null, transitions: null }, I(Wt, ve), ve |= n;
  else {
    if (!(n & 1073741824)) return e = o !== null ? o.baseLanes | n : n, t.lanes = t.childLanes = 1073741824, t.memoizedState = { baseLanes: e, cachePool: null, transitions: null }, t.updateQueue = null, I(Wt, ve), ve |= e, null;
    t.memoizedState = { baseLanes: 0, cachePool: null, transitions: null }, r = o !== null ? o.baseLanes : n, I(Wt, ve), ve |= r;
  }
  else o !== null ? (r = o.baseLanes | n, t.memoizedState = null) : r = n, I(Wt, ve), ve |= r;
  return oe(e, t, l, n), t.child;
}
function Pa(e, t) {
  var n = t.ref;
  (e === null && n !== null || e !== null && e.ref !== n) && (t.flags |= 512, t.flags |= 2097152);
}
function Co(e, t, n, r, l) {
  var o = de(n) ? _t : le.current;
  return o = qt(t, o), Gt(t, l), n = hu(e, t, n, r, o, l), r = yu(), e !== null && !ce ? (t.updateQueue = e.updateQueue, t.flags &= -2053, e.lanes &= ~l, Xe(e, t, l)) : ($ && r && lu(t), t.flags |= 1, oe(e, t, n, l), t.child);
}
function Pi(e, t, n, r, l) {
  if (de(n)) {
    var o = !0;
    Br(t);
  } else o = !1;
  if (Gt(t, l), t.stateNode === null) Nr(e, t), xa(t, n, r), Eo(t, n, r, l), r = !0;
  else if (e === null) {
    var u = t.stateNode, i = t.memoizedProps;
    u.props = i;
    var s = u.context, c = n.contextType;
    typeof c == "object" && c !== null ? c = _e(c) : (c = de(n) ? _t : le.current, c = qt(t, c));
    var v = n.getDerivedStateFromProps, m = typeof v == "function" || typeof u.getSnapshotBeforeUpdate == "function";
    m || typeof u.UNSAFE_componentWillReceiveProps != "function" && typeof u.componentWillReceiveProps != "function" || (i !== r || s !== c) && Ei(t, u, r, c), qe = !1;
    var p = t.memoizedState;
    u.state = p, Qr(t, r, u, l), s = t.memoizedState, i !== r || p !== s || fe.current || qe ? (typeof v == "function" && (So(t, n, v, r), s = t.memoizedState), (i = qe || Si(t, n, i, r, p, s, c)) ? (m || typeof u.UNSAFE_componentWillMount != "function" && typeof u.componentWillMount != "function" || (typeof u.componentWillMount == "function" && u.componentWillMount(), typeof u.UNSAFE_componentWillMount == "function" && u.UNSAFE_componentWillMount()), typeof u.componentDidMount == "function" && (t.flags |= 4194308)) : (typeof u.componentDidMount == "function" && (t.flags |= 4194308), t.memoizedProps = r, t.memoizedState = s), u.props = r, u.state = s, u.context = c, r = i) : (typeof u.componentDidMount == "function" && (t.flags |= 4194308), r = !1);
  } else {
    u = t.stateNode, na(e, t), i = t.memoizedProps, c = t.type === t.elementType ? i : Le(t.type, i), u.props = c, m = t.pendingProps, p = u.context, s = n.contextType, typeof s == "object" && s !== null ? s = _e(s) : (s = de(n) ? _t : le.current, s = qt(t, s));
    var g = n.getDerivedStateFromProps;
    (v = typeof g == "function" || typeof u.getSnapshotBeforeUpdate == "function") || typeof u.UNSAFE_componentWillReceiveProps != "function" && typeof u.componentWillReceiveProps != "function" || (i !== m || p !== s) && Ei(t, u, r, s), qe = !1, p = t.memoizedState, u.state = p, Qr(t, r, u, l);
    var k = t.memoizedState;
    i !== m || p !== k || fe.current || qe ? (typeof g == "function" && (So(t, n, g, r), k = t.memoizedState), (c = qe || Si(t, n, c, r, p, k, s) || !1) ? (v || typeof u.UNSAFE_componentWillUpdate != "function" && typeof u.componentWillUpdate != "function" || (typeof u.componentWillUpdate == "function" && u.componentWillUpdate(r, k, s), typeof u.UNSAFE_componentWillUpdate == "function" && u.UNSAFE_componentWillUpdate(r, k, s)), typeof u.componentDidUpdate == "function" && (t.flags |= 4), typeof u.getSnapshotBeforeUpdate == "function" && (t.flags |= 1024)) : (typeof u.componentDidUpdate != "function" || i === e.memoizedProps && p === e.memoizedState || (t.flags |= 4), typeof u.getSnapshotBeforeUpdate != "function" || i === e.memoizedProps && p === e.memoizedState || (t.flags |= 1024), t.memoizedProps = r, t.memoizedState = k), u.props = r, u.state = k, u.context = s, r = c) : (typeof u.componentDidUpdate != "function" || i === e.memoizedProps && p === e.memoizedState || (t.flags |= 4), typeof u.getSnapshotBeforeUpdate != "function" || i === e.memoizedProps && p === e.memoizedState || (t.flags |= 1024), r = !1);
  }
  return _o(e, t, n, r, o, l);
}
function _o(e, t, n, r, l, o) {
  Pa(e, t);
  var u = (t.flags & 128) !== 0;
  if (!r && !u) return l && pi(t, n, !1), Xe(e, t, o);
  r = t.stateNode, Jf.current = t;
  var i = u && typeof n.getDerivedStateFromError != "function" ? null : r.render();
  return t.flags |= 1, e !== null && u ? (t.child = en(t, e.child, null, o), t.child = en(t, null, i, o)) : oe(e, t, i, o), t.memoizedState = r.state, l && pi(t, n, !0), t.child;
}
function La(e) {
  var t = e.stateNode;
  t.pendingContext ? di(e, t.pendingContext, t.pendingContext !== t.context) : t.context && di(e, t.context, !1), du(e, t.containerInfo);
}
function Li(e, t, n, r, l) {
  return bt(), uu(l), t.flags |= 256, oe(e, t, n, r), t.child;
}
var No = { dehydrated: null, treeContext: null, retryLane: 0 };
function zo(e) {
  return { baseLanes: e, cachePool: null, transitions: null };
}
function Ta(e, t, n) {
  var r = t.pendingProps, l = B.current, o = !1, u = (t.flags & 128) !== 0, i;
  if ((i = u) || (i = e !== null && e.memoizedState === null ? !1 : (l & 2) !== 0), i ? (o = !0, t.flags &= -129) : (e === null || e.memoizedState !== null) && (l |= 1), I(B, l & 1), e === null)
    return wo(t), e = t.memoizedState, e !== null && (e = e.dehydrated, e !== null) ? (t.mode & 1 ? e.data === "$!" ? t.lanes = 8 : t.lanes = 1073741824 : t.lanes = 1, null) : (u = r.children, e = r.fallback, o ? (r = t.mode, o = t.child, u = { mode: "hidden", children: u }, !(r & 1) && o !== null ? (o.childLanes = 0, o.pendingProps = u) : o = cl(u, r, 0, null), e = Ct(e, r, n, null), o.return = t, e.return = t, o.sibling = e, t.child = o, t.child.memoizedState = zo(n), t.memoizedState = No, e) : ku(t, u));
  if (l = e.memoizedState, l !== null && (i = l.dehydrated, i !== null)) return qf(e, t, u, r, i, l, n);
  if (o) {
    o = r.fallback, u = t.mode, l = e.child, i = l.sibling;
    var s = { mode: "hidden", children: r.children };
    return !(u & 1) && t.child !== l ? (r = t.child, r.childLanes = 0, r.pendingProps = s, t.deletions = null) : (r = ct(l, s), r.subtreeFlags = l.subtreeFlags & 14680064), i !== null ? o = ct(i, o) : (o = Ct(o, u, n, null), o.flags |= 2), o.return = t, r.return = t, r.sibling = o, t.child = r, r = o, o = t.child, u = e.child.memoizedState, u = u === null ? zo(n) : { baseLanes: u.baseLanes | n, cachePool: null, transitions: u.transitions }, o.memoizedState = u, o.childLanes = e.childLanes & ~n, t.memoizedState = No, r;
  }
  return o = e.child, e = o.sibling, r = ct(o, { mode: "visible", children: r.children }), !(t.mode & 1) && (r.lanes = n), r.return = t, r.sibling = null, e !== null && (n = t.deletions, n === null ? (t.deletions = [e], t.flags |= 16) : n.push(e)), t.child = r, t.memoizedState = null, r;
}
function ku(e, t) {
  return t = cl({ mode: "visible", children: t }, e.mode, 0, null), t.return = e, e.child = t;
}
function mr(e, t, n, r) {
  return r !== null && uu(r), en(t, e.child, null, n), e = ku(t, t.pendingProps.children), e.flags |= 2, t.memoizedState = null, e;
}
function qf(e, t, n, r, l, o, u) {
  if (n)
    return t.flags & 256 ? (t.flags &= -257, r = Bl(Error(y(422))), mr(e, t, u, r)) : t.memoizedState !== null ? (t.child = e.child, t.flags |= 128, null) : (o = r.fallback, l = t.mode, r = cl({ mode: "visible", children: r.children }, l, 0, null), o = Ct(o, l, u, null), o.flags |= 2, r.return = t, o.return = t, r.sibling = o, t.child = r, t.mode & 1 && en(t, e.child, null, u), t.child.memoizedState = zo(u), t.memoizedState = No, o);
  if (!(t.mode & 1)) return mr(e, t, u, null);
  if (l.data === "$!") {
    if (r = l.nextSibling && l.nextSibling.dataset, r) var i = r.dgst;
    return r = i, o = Error(y(419)), r = Bl(o, r, void 0), mr(e, t, u, r);
  }
  if (i = (u & e.childLanes) !== 0, ce || i) {
    if (r = J, r !== null) {
      switch (u & -u) {
        case 4:
          l = 2;
          break;
        case 16:
          l = 8;
          break;
        case 64:
        case 128:
        case 256:
        case 512:
        case 1024:
        case 2048:
        case 4096:
        case 8192:
        case 16384:
        case 32768:
        case 65536:
        case 131072:
        case 262144:
        case 524288:
        case 1048576:
        case 2097152:
        case 4194304:
        case 8388608:
        case 16777216:
        case 33554432:
        case 67108864:
          l = 32;
          break;
        case 536870912:
          l = 268435456;
          break;
        default:
          l = 0;
      }
      l = l & (r.suspendedLanes | u) ? 0 : l, l !== 0 && l !== o.retryLane && (o.retryLane = l, Ye(e, l), Oe(r, e, l, -1));
    }
    return Nu(), r = Bl(Error(y(421))), mr(e, t, u, r);
  }
  return l.data === "$?" ? (t.flags |= 128, t.child = e.child, t = fd.bind(null, e), l._reactRetry = t, null) : (e = o.treeContext, he = ut(l.nextSibling), ye = t, $ = !0, Me = null, e !== null && (Se[Ee++] = Ae, Se[Ee++] = He, Se[Ee++] = Nt, Ae = e.id, He = e.overflow, Nt = t), t = ku(t, r.children), t.flags |= 4096, t);
}
function Ti(e, t, n) {
  e.lanes |= t;
  var r = e.alternate;
  r !== null && (r.lanes |= t), ko(e.return, t, n);
}
function Vl(e, t, n, r, l) {
  var o = e.memoizedState;
  o === null ? e.memoizedState = { isBackwards: t, rendering: null, renderingStartTime: 0, last: r, tail: n, tailMode: l } : (o.isBackwards = t, o.rendering = null, o.renderingStartTime = 0, o.last = r, o.tail = n, o.tailMode = l);
}
function Ma(e, t, n) {
  var r = t.pendingProps, l = r.revealOrder, o = r.tail;
  if (oe(e, t, r.children, n), r = B.current, r & 2) r = r & 1 | 2, t.flags |= 128;
  else {
    if (e !== null && e.flags & 128) e: for (e = t.child; e !== null; ) {
      if (e.tag === 13) e.memoizedState !== null && Ti(e, n, t);
      else if (e.tag === 19) Ti(e, n, t);
      else if (e.child !== null) {
        e.child.return = e, e = e.child;
        continue;
      }
      if (e === t) break e;
      for (; e.sibling === null; ) {
        if (e.return === null || e.return === t) break e;
        e = e.return;
      }
      e.sibling.return = e.return, e = e.sibling;
    }
    r &= 1;
  }
  if (I(B, r), !(t.mode & 1)) t.memoizedState = null;
  else switch (l) {
    case "forwards":
      for (n = t.child, l = null; n !== null; ) e = n.alternate, e !== null && Kr(e) === null && (l = n), n = n.sibling;
      n = l, n === null ? (l = t.child, t.child = null) : (l = n.sibling, n.sibling = null), Vl(t, !1, l, n, o);
      break;
    case "backwards":
      for (n = null, l = t.child, t.child = null; l !== null; ) {
        if (e = l.alternate, e !== null && Kr(e) === null) {
          t.child = l;
          break;
        }
        e = l.sibling, l.sibling = n, n = l, l = e;
      }
      Vl(t, !0, n, null, o);
      break;
    case "together":
      Vl(t, !1, null, null, void 0);
      break;
    default:
      t.memoizedState = null;
  }
  return t.child;
}
function Nr(e, t) {
  !(t.mode & 1) && e !== null && (e.alternate = null, t.alternate = null, t.flags |= 2);
}
function Xe(e, t, n) {
  if (e !== null && (t.dependencies = e.dependencies), Pt |= t.lanes, !(n & t.childLanes)) return null;
  if (e !== null && t.child !== e.child) throw Error(y(153));
  if (t.child !== null) {
    for (e = t.child, n = ct(e, e.pendingProps), t.child = n, n.return = t; e.sibling !== null; ) e = e.sibling, n = n.sibling = ct(e, e.pendingProps), n.return = t;
    n.sibling = null;
  }
  return t.child;
}
function bf(e, t, n) {
  switch (t.tag) {
    case 3:
      La(t), bt();
      break;
    case 5:
      ra(t);
      break;
    case 1:
      de(t.type) && Br(t);
      break;
    case 4:
      du(t, t.stateNode.containerInfo);
      break;
    case 10:
      var r = t.type._context, l = t.memoizedProps.value;
      I(Hr, r._currentValue), r._currentValue = l;
      break;
    case 13:
      if (r = t.memoizedState, r !== null)
        return r.dehydrated !== null ? (I(B, B.current & 1), t.flags |= 128, null) : n & t.child.childLanes ? Ta(e, t, n) : (I(B, B.current & 1), e = Xe(e, t, n), e !== null ? e.sibling : null);
      I(B, B.current & 1);
      break;
    case 19:
      if (r = (n & t.childLanes) !== 0, e.flags & 128) {
        if (r) return Ma(e, t, n);
        t.flags |= 128;
      }
      if (l = t.memoizedState, l !== null && (l.rendering = null, l.tail = null, l.lastEffect = null), I(B, B.current), r) break;
      return null;
    case 22:
    case 23:
      return t.lanes = 0, za(e, t, n);
  }
  return Xe(e, t, n);
}
var Ra, Po, Oa, Da;
Ra = function(e, t) {
  for (var n = t.child; n !== null; ) {
    if (n.tag === 5 || n.tag === 6) e.appendChild(n.stateNode);
    else if (n.tag !== 4 && n.child !== null) {
      n.child.return = n, n = n.child;
      continue;
    }
    if (n === t) break;
    for (; n.sibling === null; ) {
      if (n.return === null || n.return === t) return;
      n = n.return;
    }
    n.sibling.return = n.return, n = n.sibling;
  }
};
Po = function() {
};
Oa = function(e, t, n, r) {
  var l = e.memoizedProps;
  if (l !== r) {
    e = t.stateNode, Et($e.current);
    var o = null;
    switch (n) {
      case "input":
        l = Gl(e, l), r = Gl(e, r), o = [];
        break;
      case "select":
        l = A({}, l, { value: void 0 }), r = A({}, r, { value: void 0 }), o = [];
        break;
      case "textarea":
        l = ql(e, l), r = ql(e, r), o = [];
        break;
      default:
        typeof l.onClick != "function" && typeof r.onClick == "function" && (e.onclick = Ur);
    }
    eo(n, r);
    var u;
    n = null;
    for (c in l) if (!r.hasOwnProperty(c) && l.hasOwnProperty(c) && l[c] != null) if (c === "style") {
      var i = l[c];
      for (u in i) i.hasOwnProperty(u) && (n || (n = {}), n[u] = "");
    } else c !== "dangerouslySetInnerHTML" && c !== "children" && c !== "suppressContentEditableWarning" && c !== "suppressHydrationWarning" && c !== "autoFocus" && (Mn.hasOwnProperty(c) ? o || (o = []) : (o = o || []).push(c, null));
    for (c in r) {
      var s = r[c];
      if (i = l != null ? l[c] : void 0, r.hasOwnProperty(c) && s !== i && (s != null || i != null)) if (c === "style") if (i) {
        for (u in i) !i.hasOwnProperty(u) || s && s.hasOwnProperty(u) || (n || (n = {}), n[u] = "");
        for (u in s) s.hasOwnProperty(u) && i[u] !== s[u] && (n || (n = {}), n[u] = s[u]);
      } else n || (o || (o = []), o.push(
        c,
        n
      )), n = s;
      else c === "dangerouslySetInnerHTML" ? (s = s ? s.__html : void 0, i = i ? i.__html : void 0, s != null && i !== s && (o = o || []).push(c, s)) : c === "children" ? typeof s != "string" && typeof s != "number" || (o = o || []).push(c, "" + s) : c !== "suppressContentEditableWarning" && c !== "suppressHydrationWarning" && (Mn.hasOwnProperty(c) ? (s != null && c === "onScroll" && j("scroll", e), o || i === s || (o = [])) : (o = o || []).push(c, s));
    }
    n && (o = o || []).push("style", n);
    var c = o;
    (t.updateQueue = c) && (t.flags |= 4);
  }
};
Da = function(e, t, n, r) {
  n !== r && (t.flags |= 4);
};
function hn(e, t) {
  if (!$) switch (e.tailMode) {
    case "hidden":
      t = e.tail;
      for (var n = null; t !== null; ) t.alternate !== null && (n = t), t = t.sibling;
      n === null ? e.tail = null : n.sibling = null;
      break;
    case "collapsed":
      n = e.tail;
      for (var r = null; n !== null; ) n.alternate !== null && (r = n), n = n.sibling;
      r === null ? t || e.tail === null ? e.tail = null : e.tail.sibling = null : r.sibling = null;
  }
}
function ne(e) {
  var t = e.alternate !== null && e.alternate.child === e.child, n = 0, r = 0;
  if (t) for (var l = e.child; l !== null; ) n |= l.lanes | l.childLanes, r |= l.subtreeFlags & 14680064, r |= l.flags & 14680064, l.return = e, l = l.sibling;
  else for (l = e.child; l !== null; ) n |= l.lanes | l.childLanes, r |= l.subtreeFlags, r |= l.flags, l.return = e, l = l.sibling;
  return e.subtreeFlags |= r, e.childLanes = n, t;
}
function ed(e, t, n) {
  var r = t.pendingProps;
  switch (ou(t), t.tag) {
    case 2:
    case 16:
    case 15:
    case 0:
    case 11:
    case 7:
    case 8:
    case 12:
    case 9:
    case 14:
      return ne(t), null;
    case 1:
      return de(t.type) && $r(), ne(t), null;
    case 3:
      return r = t.stateNode, tn(), U(fe), U(le), mu(), r.pendingContext && (r.context = r.pendingContext, r.pendingContext = null), (e === null || e.child === null) && (dr(t) ? t.flags |= 4 : e === null || e.memoizedState.isDehydrated && !(t.flags & 256) || (t.flags |= 1024, Me !== null && (Fo(Me), Me = null))), Po(e, t), ne(t), null;
    case 5:
      pu(t);
      var l = Et(Hn.current);
      if (n = t.type, e !== null && t.stateNode != null) Oa(e, t, n, r, l), e.ref !== t.ref && (t.flags |= 512, t.flags |= 2097152);
      else {
        if (!r) {
          if (t.stateNode === null) throw Error(y(166));
          return ne(t), null;
        }
        if (e = Et($e.current), dr(t)) {
          r = t.stateNode, n = t.type;
          var o = t.memoizedProps;
          switch (r[je] = t, r[Vn] = o, e = (t.mode & 1) !== 0, n) {
            case "dialog":
              j("cancel", r), j("close", r);
              break;
            case "iframe":
            case "object":
            case "embed":
              j("load", r);
              break;
            case "video":
            case "audio":
              for (l = 0; l < Sn.length; l++) j(Sn[l], r);
              break;
            case "source":
              j("error", r);
              break;
            case "img":
            case "image":
            case "link":
              j(
                "error",
                r
              ), j("load", r);
              break;
            case "details":
              j("toggle", r);
              break;
            case "input":
              $u(r, o), j("invalid", r);
              break;
            case "select":
              r._wrapperState = { wasMultiple: !!o.multiple }, j("invalid", r);
              break;
            case "textarea":
              Vu(r, o), j("invalid", r);
          }
          eo(n, o), l = null;
          for (var u in o) if (o.hasOwnProperty(u)) {
            var i = o[u];
            u === "children" ? typeof i == "string" ? r.textContent !== i && (o.suppressHydrationWarning !== !0 && fr(r.textContent, i, e), l = ["children", i]) : typeof i == "number" && r.textContent !== "" + i && (o.suppressHydrationWarning !== !0 && fr(
              r.textContent,
              i,
              e
            ), l = ["children", "" + i]) : Mn.hasOwnProperty(u) && i != null && u === "onScroll" && j("scroll", r);
          }
          switch (n) {
            case "input":
              rr(r), Bu(r, o, !0);
              break;
            case "textarea":
              rr(r), Au(r);
              break;
            case "select":
            case "option":
              break;
            default:
              typeof o.onClick == "function" && (r.onclick = Ur);
          }
          r = l, t.updateQueue = r, r !== null && (t.flags |= 4);
        } else {
          u = l.nodeType === 9 ? l : l.ownerDocument, e === "http://www.w3.org/1999/xhtml" && (e = ss(n)), e === "http://www.w3.org/1999/xhtml" ? n === "script" ? (e = u.createElement("div"), e.innerHTML = "<script><\/script>", e = e.removeChild(e.firstChild)) : typeof r.is == "string" ? e = u.createElement(n, { is: r.is }) : (e = u.createElement(n), n === "select" && (u = e, r.multiple ? u.multiple = !0 : r.size && (u.size = r.size))) : e = u.createElementNS(e, n), e[je] = t, e[Vn] = r, Ra(e, t, !1, !1), t.stateNode = e;
          e: {
            switch (u = to(n, r), n) {
              case "dialog":
                j("cancel", e), j("close", e), l = r;
                break;
              case "iframe":
              case "object":
              case "embed":
                j("load", e), l = r;
                break;
              case "video":
              case "audio":
                for (l = 0; l < Sn.length; l++) j(Sn[l], e);
                l = r;
                break;
              case "source":
                j("error", e), l = r;
                break;
              case "img":
              case "image":
              case "link":
                j(
                  "error",
                  e
                ), j("load", e), l = r;
                break;
              case "details":
                j("toggle", e), l = r;
                break;
              case "input":
                $u(e, r), l = Gl(e, r), j("invalid", e);
                break;
              case "option":
                l = r;
                break;
              case "select":
                e._wrapperState = { wasMultiple: !!r.multiple }, l = A({}, r, { value: void 0 }), j("invalid", e);
                break;
              case "textarea":
                Vu(e, r), l = ql(e, r), j("invalid", e);
                break;
              default:
                l = r;
            }
            eo(n, l), i = l;
            for (o in i) if (i.hasOwnProperty(o)) {
              var s = i[o];
              o === "style" ? fs(e, s) : o === "dangerouslySetInnerHTML" ? (s = s ? s.__html : void 0, s != null && as(e, s)) : o === "children" ? typeof s == "string" ? (n !== "textarea" || s !== "") && Rn(e, s) : typeof s == "number" && Rn(e, "" + s) : o !== "suppressContentEditableWarning" && o !== "suppressHydrationWarning" && o !== "autoFocus" && (Mn.hasOwnProperty(o) ? s != null && o === "onScroll" && j("scroll", e) : s != null && Wo(e, o, s, u));
            }
            switch (n) {
              case "input":
                rr(e), Bu(e, r, !1);
                break;
              case "textarea":
                rr(e), Au(e);
                break;
              case "option":
                r.value != null && e.setAttribute("value", "" + ft(r.value));
                break;
              case "select":
                e.multiple = !!r.multiple, o = r.value, o != null ? Qt(e, !!r.multiple, o, !1) : r.defaultValue != null && Qt(
                  e,
                  !!r.multiple,
                  r.defaultValue,
                  !0
                );
                break;
              default:
                typeof l.onClick == "function" && (e.onclick = Ur);
            }
            switch (n) {
              case "button":
              case "input":
              case "select":
              case "textarea":
                r = !!r.autoFocus;
                break e;
              case "img":
                r = !0;
                break e;
              default:
                r = !1;
            }
          }
          r && (t.flags |= 4);
        }
        t.ref !== null && (t.flags |= 512, t.flags |= 2097152);
      }
      return ne(t), null;
    case 6:
      if (e && t.stateNode != null) Da(e, t, e.memoizedProps, r);
      else {
        if (typeof r != "string" && t.stateNode === null) throw Error(y(166));
        if (n = Et(Hn.current), Et($e.current), dr(t)) {
          if (r = t.stateNode, n = t.memoizedProps, r[je] = t, (o = r.nodeValue !== n) && (e = ye, e !== null)) switch (e.tag) {
            case 3:
              fr(r.nodeValue, n, (e.mode & 1) !== 0);
              break;
            case 5:
              e.memoizedProps.suppressHydrationWarning !== !0 && fr(r.nodeValue, n, (e.mode & 1) !== 0);
          }
          o && (t.flags |= 4);
        } else r = (n.nodeType === 9 ? n : n.ownerDocument).createTextNode(r), r[je] = t, t.stateNode = r;
      }
      return ne(t), null;
    case 13:
      if (U(B), r = t.memoizedState, e === null || e.memoizedState !== null && e.memoizedState.dehydrated !== null) {
        if ($ && he !== null && t.mode & 1 && !(t.flags & 128)) qs(), bt(), t.flags |= 98560, o = !1;
        else if (o = dr(t), r !== null && r.dehydrated !== null) {
          if (e === null) {
            if (!o) throw Error(y(318));
            if (o = t.memoizedState, o = o !== null ? o.dehydrated : null, !o) throw Error(y(317));
            o[je] = t;
          } else bt(), !(t.flags & 128) && (t.memoizedState = null), t.flags |= 4;
          ne(t), o = !1;
        } else Me !== null && (Fo(Me), Me = null), o = !0;
        if (!o) return t.flags & 65536 ? t : null;
      }
      return t.flags & 128 ? (t.lanes = n, t) : (r = r !== null, r !== (e !== null && e.memoizedState !== null) && r && (t.child.flags |= 8192, t.mode & 1 && (e === null || B.current & 1 ? X === 0 && (X = 3) : Nu())), t.updateQueue !== null && (t.flags |= 4), ne(t), null);
    case 4:
      return tn(), Po(e, t), e === null && $n(t.stateNode.containerInfo), ne(t), null;
    case 10:
      return au(t.type._context), ne(t), null;
    case 17:
      return de(t.type) && $r(), ne(t), null;
    case 19:
      if (U(B), o = t.memoizedState, o === null) return ne(t), null;
      if (r = (t.flags & 128) !== 0, u = o.rendering, u === null) if (r) hn(o, !1);
      else {
        if (X !== 0 || e !== null && e.flags & 128) for (e = t.child; e !== null; ) {
          if (u = Kr(e), u !== null) {
            for (t.flags |= 128, hn(o, !1), r = u.updateQueue, r !== null && (t.updateQueue = r, t.flags |= 4), t.subtreeFlags = 0, r = n, n = t.child; n !== null; ) o = n, e = r, o.flags &= 14680066, u = o.alternate, u === null ? (o.childLanes = 0, o.lanes = e, o.child = null, o.subtreeFlags = 0, o.memoizedProps = null, o.memoizedState = null, o.updateQueue = null, o.dependencies = null, o.stateNode = null) : (o.childLanes = u.childLanes, o.lanes = u.lanes, o.child = u.child, o.subtreeFlags = 0, o.deletions = null, o.memoizedProps = u.memoizedProps, o.memoizedState = u.memoizedState, o.updateQueue = u.updateQueue, o.type = u.type, e = u.dependencies, o.dependencies = e === null ? null : { lanes: e.lanes, firstContext: e.firstContext }), n = n.sibling;
            return I(B, B.current & 1 | 2), t.child;
          }
          e = e.sibling;
        }
        o.tail !== null && Q() > rn && (t.flags |= 128, r = !0, hn(o, !1), t.lanes = 4194304);
      }
      else {
        if (!r) if (e = Kr(u), e !== null) {
          if (t.flags |= 128, r = !0, n = e.updateQueue, n !== null && (t.updateQueue = n, t.flags |= 4), hn(o, !0), o.tail === null && o.tailMode === "hidden" && !u.alternate && !$) return ne(t), null;
        } else 2 * Q() - o.renderingStartTime > rn && n !== 1073741824 && (t.flags |= 128, r = !0, hn(o, !1), t.lanes = 4194304);
        o.isBackwards ? (u.sibling = t.child, t.child = u) : (n = o.last, n !== null ? n.sibling = u : t.child = u, o.last = u);
      }
      return o.tail !== null ? (t = o.tail, o.rendering = t, o.tail = t.sibling, o.renderingStartTime = Q(), t.sibling = null, n = B.current, I(B, r ? n & 1 | 2 : n & 1), t) : (ne(t), null);
    case 22:
    case 23:
      return _u(), r = t.memoizedState !== null, e !== null && e.memoizedState !== null !== r && (t.flags |= 8192), r && t.mode & 1 ? ve & 1073741824 && (ne(t), t.subtreeFlags & 6 && (t.flags |= 8192)) : ne(t), null;
    case 24:
      return null;
    case 25:
      return null;
  }
  throw Error(y(156, t.tag));
}
function td(e, t) {
  switch (ou(t), t.tag) {
    case 1:
      return de(t.type) && $r(), e = t.flags, e & 65536 ? (t.flags = e & -65537 | 128, t) : null;
    case 3:
      return tn(), U(fe), U(le), mu(), e = t.flags, e & 65536 && !(e & 128) ? (t.flags = e & -65537 | 128, t) : null;
    case 5:
      return pu(t), null;
    case 13:
      if (U(B), e = t.memoizedState, e !== null && e.dehydrated !== null) {
        if (t.alternate === null) throw Error(y(340));
        bt();
      }
      return e = t.flags, e & 65536 ? (t.flags = e & -65537 | 128, t) : null;
    case 19:
      return U(B), null;
    case 4:
      return tn(), null;
    case 10:
      return au(t.type._context), null;
    case 22:
    case 23:
      return _u(), null;
    case 24:
      return null;
    default:
      return null;
  }
}
var vr = !1, re = !1, nd = typeof WeakSet == "function" ? WeakSet : Set, x = null;
function Ht(e, t) {
  var n = e.ref;
  if (n !== null) if (typeof n == "function") try {
    n(null);
  } catch (r) {
    H(e, t, r);
  }
  else n.current = null;
}
function Lo(e, t, n) {
  try {
    n();
  } catch (r) {
    H(e, t, r);
  }
}
var Mi = !1;
function rd(e, t) {
  if (fo = Ir, e = $s(), ru(e)) {
    if ("selectionStart" in e) var n = { start: e.selectionStart, end: e.selectionEnd };
    else e: {
      n = (n = e.ownerDocument) && n.defaultView || window;
      var r = n.getSelection && n.getSelection();
      if (r && r.rangeCount !== 0) {
        n = r.anchorNode;
        var l = r.anchorOffset, o = r.focusNode;
        r = r.focusOffset;
        try {
          n.nodeType, o.nodeType;
        } catch {
          n = null;
          break e;
        }
        var u = 0, i = -1, s = -1, c = 0, v = 0, m = e, p = null;
        t: for (; ; ) {
          for (var g; m !== n || l !== 0 && m.nodeType !== 3 || (i = u + l), m !== o || r !== 0 && m.nodeType !== 3 || (s = u + r), m.nodeType === 3 && (u += m.nodeValue.length), (g = m.firstChild) !== null; )
            p = m, m = g;
          for (; ; ) {
            if (m === e) break t;
            if (p === n && ++c === l && (i = u), p === o && ++v === r && (s = u), (g = m.nextSibling) !== null) break;
            m = p, p = m.parentNode;
          }
          m = g;
        }
        n = i === -1 || s === -1 ? null : { start: i, end: s };
      } else n = null;
    }
    n = n || { start: 0, end: 0 };
  } else n = null;
  for (po = { focusedElem: e, selectionRange: n }, Ir = !1, x = t; x !== null; ) if (t = x, e = t.child, (t.subtreeFlags & 1028) !== 0 && e !== null) e.return = t, x = e;
  else for (; x !== null; ) {
    t = x;
    try {
      var k = t.alternate;
      if (t.flags & 1024) switch (t.tag) {
        case 0:
        case 11:
        case 15:
          break;
        case 1:
          if (k !== null) {
            var S = k.memoizedProps, O = k.memoizedState, f = t.stateNode, a = f.getSnapshotBeforeUpdate(t.elementType === t.type ? S : Le(t.type, S), O);
            f.__reactInternalSnapshotBeforeUpdate = a;
          }
          break;
        case 3:
          var d = t.stateNode.containerInfo;
          d.nodeType === 1 ? d.textContent = "" : d.nodeType === 9 && d.documentElement && d.removeChild(d.documentElement);
          break;
        case 5:
        case 6:
        case 4:
        case 17:
          break;
        default:
          throw Error(y(163));
      }
    } catch (h) {
      H(t, t.return, h);
    }
    if (e = t.sibling, e !== null) {
      e.return = t.return, x = e;
      break;
    }
    x = t.return;
  }
  return k = Mi, Mi = !1, k;
}
function Pn(e, t, n) {
  var r = t.updateQueue;
  if (r = r !== null ? r.lastEffect : null, r !== null) {
    var l = r = r.next;
    do {
      if ((l.tag & e) === e) {
        var o = l.destroy;
        l.destroy = void 0, o !== void 0 && Lo(t, n, o);
      }
      l = l.next;
    } while (l !== r);
  }
}
function sl(e, t) {
  if (t = t.updateQueue, t = t !== null ? t.lastEffect : null, t !== null) {
    var n = t = t.next;
    do {
      if ((n.tag & e) === e) {
        var r = n.create;
        n.destroy = r();
      }
      n = n.next;
    } while (n !== t);
  }
}
function To(e) {
  var t = e.ref;
  if (t !== null) {
    var n = e.stateNode;
    switch (e.tag) {
      case 5:
        e = n;
        break;
      default:
        e = n;
    }
    typeof t == "function" ? t(e) : t.current = e;
  }
}
function Ia(e) {
  var t = e.alternate;
  t !== null && (e.alternate = null, Ia(t)), e.child = null, e.deletions = null, e.sibling = null, e.tag === 5 && (t = e.stateNode, t !== null && (delete t[je], delete t[Vn], delete t[ho], delete t[$f], delete t[Bf])), e.stateNode = null, e.return = null, e.dependencies = null, e.memoizedProps = null, e.memoizedState = null, e.pendingProps = null, e.stateNode = null, e.updateQueue = null;
}
function Fa(e) {
  return e.tag === 5 || e.tag === 3 || e.tag === 4;
}
function Ri(e) {
  e: for (; ; ) {
    for (; e.sibling === null; ) {
      if (e.return === null || Fa(e.return)) return null;
      e = e.return;
    }
    for (e.sibling.return = e.return, e = e.sibling; e.tag !== 5 && e.tag !== 6 && e.tag !== 18; ) {
      if (e.flags & 2 || e.child === null || e.tag === 4) continue e;
      e.child.return = e, e = e.child;
    }
    if (!(e.flags & 2)) return e.stateNode;
  }
}
function Mo(e, t, n) {
  var r = e.tag;
  if (r === 5 || r === 6) e = e.stateNode, t ? n.nodeType === 8 ? n.parentNode.insertBefore(e, t) : n.insertBefore(e, t) : (n.nodeType === 8 ? (t = n.parentNode, t.insertBefore(e, n)) : (t = n, t.appendChild(e)), n = n._reactRootContainer, n != null || t.onclick !== null || (t.onclick = Ur));
  else if (r !== 4 && (e = e.child, e !== null)) for (Mo(e, t, n), e = e.sibling; e !== null; ) Mo(e, t, n), e = e.sibling;
}
function Ro(e, t, n) {
  var r = e.tag;
  if (r === 5 || r === 6) e = e.stateNode, t ? n.insertBefore(e, t) : n.appendChild(e);
  else if (r !== 4 && (e = e.child, e !== null)) for (Ro(e, t, n), e = e.sibling; e !== null; ) Ro(e, t, n), e = e.sibling;
}
var q = null, Te = !1;
function Ze(e, t, n) {
  for (n = n.child; n !== null; ) ja(e, t, n), n = n.sibling;
}
function ja(e, t, n) {
  if (Ue && typeof Ue.onCommitFiberUnmount == "function") try {
    Ue.onCommitFiberUnmount(el, n);
  } catch {
  }
  switch (n.tag) {
    case 5:
      re || Ht(n, t);
    case 6:
      var r = q, l = Te;
      q = null, Ze(e, t, n), q = r, Te = l, q !== null && (Te ? (e = q, n = n.stateNode, e.nodeType === 8 ? e.parentNode.removeChild(n) : e.removeChild(n)) : q.removeChild(n.stateNode));
      break;
    case 18:
      q !== null && (Te ? (e = q, n = n.stateNode, e.nodeType === 8 ? Dl(e.parentNode, n) : e.nodeType === 1 && Dl(e, n), Fn(e)) : Dl(q, n.stateNode));
      break;
    case 4:
      r = q, l = Te, q = n.stateNode.containerInfo, Te = !0, Ze(e, t, n), q = r, Te = l;
      break;
    case 0:
    case 11:
    case 14:
    case 15:
      if (!re && (r = n.updateQueue, r !== null && (r = r.lastEffect, r !== null))) {
        l = r = r.next;
        do {
          var o = l, u = o.destroy;
          o = o.tag, u !== void 0 && (o & 2 || o & 4) && Lo(n, t, u), l = l.next;
        } while (l !== r);
      }
      Ze(e, t, n);
      break;
    case 1:
      if (!re && (Ht(n, t), r = n.stateNode, typeof r.componentWillUnmount == "function")) try {
        r.props = n.memoizedProps, r.state = n.memoizedState, r.componentWillUnmount();
      } catch (i) {
        H(n, t, i);
      }
      Ze(e, t, n);
      break;
    case 21:
      Ze(e, t, n);
      break;
    case 22:
      n.mode & 1 ? (re = (r = re) || n.memoizedState !== null, Ze(e, t, n), re = r) : Ze(e, t, n);
      break;
    default:
      Ze(e, t, n);
  }
}
function Oi(e) {
  var t = e.updateQueue;
  if (t !== null) {
    e.updateQueue = null;
    var n = e.stateNode;
    n === null && (n = e.stateNode = new nd()), t.forEach(function(r) {
      var l = dd.bind(null, e, r);
      n.has(r) || (n.add(r), r.then(l, l));
    });
  }
}
function Pe(e, t) {
  var n = t.deletions;
  if (n !== null) for (var r = 0; r < n.length; r++) {
    var l = n[r];
    try {
      var o = e, u = t, i = u;
      e: for (; i !== null; ) {
        switch (i.tag) {
          case 5:
            q = i.stateNode, Te = !1;
            break e;
          case 3:
            q = i.stateNode.containerInfo, Te = !0;
            break e;
          case 4:
            q = i.stateNode.containerInfo, Te = !0;
            break e;
        }
        i = i.return;
      }
      if (q === null) throw Error(y(160));
      ja(o, u, l), q = null, Te = !1;
      var s = l.alternate;
      s !== null && (s.return = null), l.return = null;
    } catch (c) {
      H(l, t, c);
    }
  }
  if (t.subtreeFlags & 12854) for (t = t.child; t !== null; ) Ua(t, e), t = t.sibling;
}
function Ua(e, t) {
  var n = e.alternate, r = e.flags;
  switch (e.tag) {
    case 0:
    case 11:
    case 14:
    case 15:
      if (Pe(t, e), Ie(e), r & 4) {
        try {
          Pn(3, e, e.return), sl(3, e);
        } catch (S) {
          H(e, e.return, S);
        }
        try {
          Pn(5, e, e.return);
        } catch (S) {
          H(e, e.return, S);
        }
      }
      break;
    case 1:
      Pe(t, e), Ie(e), r & 512 && n !== null && Ht(n, n.return);
      break;
    case 5:
      if (Pe(t, e), Ie(e), r & 512 && n !== null && Ht(n, n.return), e.flags & 32) {
        var l = e.stateNode;
        try {
          Rn(l, "");
        } catch (S) {
          H(e, e.return, S);
        }
      }
      if (r & 4 && (l = e.stateNode, l != null)) {
        var o = e.memoizedProps, u = n !== null ? n.memoizedProps : o, i = e.type, s = e.updateQueue;
        if (e.updateQueue = null, s !== null) try {
          i === "input" && o.type === "radio" && o.name != null && us(l, o), to(i, u);
          var c = to(i, o);
          for (u = 0; u < s.length; u += 2) {
            var v = s[u], m = s[u + 1];
            v === "style" ? fs(l, m) : v === "dangerouslySetInnerHTML" ? as(l, m) : v === "children" ? Rn(l, m) : Wo(l, v, m, c);
          }
          switch (i) {
            case "input":
              Zl(l, o);
              break;
            case "textarea":
              is(l, o);
              break;
            case "select":
              var p = l._wrapperState.wasMultiple;
              l._wrapperState.wasMultiple = !!o.multiple;
              var g = o.value;
              g != null ? Qt(l, !!o.multiple, g, !1) : p !== !!o.multiple && (o.defaultValue != null ? Qt(
                l,
                !!o.multiple,
                o.defaultValue,
                !0
              ) : Qt(l, !!o.multiple, o.multiple ? [] : "", !1));
          }
          l[Vn] = o;
        } catch (S) {
          H(e, e.return, S);
        }
      }
      break;
    case 6:
      if (Pe(t, e), Ie(e), r & 4) {
        if (e.stateNode === null) throw Error(y(162));
        l = e.stateNode, o = e.memoizedProps;
        try {
          l.nodeValue = o;
        } catch (S) {
          H(e, e.return, S);
        }
      }
      break;
    case 3:
      if (Pe(t, e), Ie(e), r & 4 && n !== null && n.memoizedState.isDehydrated) try {
        Fn(t.containerInfo);
      } catch (S) {
        H(e, e.return, S);
      }
      break;
    case 4:
      Pe(t, e), Ie(e);
      break;
    case 13:
      Pe(t, e), Ie(e), l = e.child, l.flags & 8192 && (o = l.memoizedState !== null, l.stateNode.isHidden = o, !o || l.alternate !== null && l.alternate.memoizedState !== null || (xu = Q())), r & 4 && Oi(e);
      break;
    case 22:
      if (v = n !== null && n.memoizedState !== null, e.mode & 1 ? (re = (c = re) || v, Pe(t, e), re = c) : Pe(t, e), Ie(e), r & 8192) {
        if (c = e.memoizedState !== null, (e.stateNode.isHidden = c) && !v && e.mode & 1) for (x = e, v = e.child; v !== null; ) {
          for (m = x = v; x !== null; ) {
            switch (p = x, g = p.child, p.tag) {
              case 0:
              case 11:
              case 14:
              case 15:
                Pn(4, p, p.return);
                break;
              case 1:
                Ht(p, p.return);
                var k = p.stateNode;
                if (typeof k.componentWillUnmount == "function") {
                  r = p, n = p.return;
                  try {
                    t = r, k.props = t.memoizedProps, k.state = t.memoizedState, k.componentWillUnmount();
                  } catch (S) {
                    H(r, n, S);
                  }
                }
                break;
              case 5:
                Ht(p, p.return);
                break;
              case 22:
                if (p.memoizedState !== null) {
                  Ii(m);
                  continue;
                }
            }
            g !== null ? (g.return = p, x = g) : Ii(m);
          }
          v = v.sibling;
        }
        e: for (v = null, m = e; ; ) {
          if (m.tag === 5) {
            if (v === null) {
              v = m;
              try {
                l = m.stateNode, c ? (o = l.style, typeof o.setProperty == "function" ? o.setProperty("display", "none", "important") : o.display = "none") : (i = m.stateNode, s = m.memoizedProps.style, u = s != null && s.hasOwnProperty("display") ? s.display : null, i.style.display = cs("display", u));
              } catch (S) {
                H(e, e.return, S);
              }
            }
          } else if (m.tag === 6) {
            if (v === null) try {
              m.stateNode.nodeValue = c ? "" : m.memoizedProps;
            } catch (S) {
              H(e, e.return, S);
            }
          } else if ((m.tag !== 22 && m.tag !== 23 || m.memoizedState === null || m === e) && m.child !== null) {
            m.child.return = m, m = m.child;
            continue;
          }
          if (m === e) break e;
          for (; m.sibling === null; ) {
            if (m.return === null || m.return === e) break e;
            v === m && (v = null), m = m.return;
          }
          v === m && (v = null), m.sibling.return = m.return, m = m.sibling;
        }
      }
      break;
    case 19:
      Pe(t, e), Ie(e), r & 4 && Oi(e);
      break;
    case 21:
      break;
    default:
      Pe(
        t,
        e
      ), Ie(e);
  }
}
function Ie(e) {
  var t = e.flags;
  if (t & 2) {
    try {
      e: {
        for (var n = e.return; n !== null; ) {
          if (Fa(n)) {
            var r = n;
            break e;
          }
          n = n.return;
        }
        throw Error(y(160));
      }
      switch (r.tag) {
        case 5:
          var l = r.stateNode;
          r.flags & 32 && (Rn(l, ""), r.flags &= -33);
          var o = Ri(e);
          Ro(e, o, l);
          break;
        case 3:
        case 4:
          var u = r.stateNode.containerInfo, i = Ri(e);
          Mo(e, i, u);
          break;
        default:
          throw Error(y(161));
      }
    } catch (s) {
      H(e, e.return, s);
    }
    e.flags &= -3;
  }
  t & 4096 && (e.flags &= -4097);
}
function ld(e, t, n) {
  x = e, $a(e);
}
function $a(e, t, n) {
  for (var r = (e.mode & 1) !== 0; x !== null; ) {
    var l = x, o = l.child;
    if (l.tag === 22 && r) {
      var u = l.memoizedState !== null || vr;
      if (!u) {
        var i = l.alternate, s = i !== null && i.memoizedState !== null || re;
        i = vr;
        var c = re;
        if (vr = u, (re = s) && !c) for (x = l; x !== null; ) u = x, s = u.child, u.tag === 22 && u.memoizedState !== null ? Fi(l) : s !== null ? (s.return = u, x = s) : Fi(l);
        for (; o !== null; ) x = o, $a(o), o = o.sibling;
        x = l, vr = i, re = c;
      }
      Di(e);
    } else l.subtreeFlags & 8772 && o !== null ? (o.return = l, x = o) : Di(e);
  }
}
function Di(e) {
  for (; x !== null; ) {
    var t = x;
    if (t.flags & 8772) {
      var n = t.alternate;
      try {
        if (t.flags & 8772) switch (t.tag) {
          case 0:
          case 11:
          case 15:
            re || sl(5, t);
            break;
          case 1:
            var r = t.stateNode;
            if (t.flags & 4 && !re) if (n === null) r.componentDidMount();
            else {
              var l = t.elementType === t.type ? n.memoizedProps : Le(t.type, n.memoizedProps);
              r.componentDidUpdate(l, n.memoizedState, r.__reactInternalSnapshotBeforeUpdate);
            }
            var o = t.updateQueue;
            o !== null && gi(t, o, r);
            break;
          case 3:
            var u = t.updateQueue;
            if (u !== null) {
              if (n = null, t.child !== null) switch (t.child.tag) {
                case 5:
                  n = t.child.stateNode;
                  break;
                case 1:
                  n = t.child.stateNode;
              }
              gi(t, u, n);
            }
            break;
          case 5:
            var i = t.stateNode;
            if (n === null && t.flags & 4) {
              n = i;
              var s = t.memoizedProps;
              switch (t.type) {
                case "button":
                case "input":
                case "select":
                case "textarea":
                  s.autoFocus && n.focus();
                  break;
                case "img":
                  s.src && (n.src = s.src);
              }
            }
            break;
          case 6:
            break;
          case 4:
            break;
          case 12:
            break;
          case 13:
            if (t.memoizedState === null) {
              var c = t.alternate;
              if (c !== null) {
                var v = c.memoizedState;
                if (v !== null) {
                  var m = v.dehydrated;
                  m !== null && Fn(m);
                }
              }
            }
            break;
          case 19:
          case 17:
          case 21:
          case 22:
          case 23:
          case 25:
            break;
          default:
            throw Error(y(163));
        }
        re || t.flags & 512 && To(t);
      } catch (p) {
        H(t, t.return, p);
      }
    }
    if (t === e) {
      x = null;
      break;
    }
    if (n = t.sibling, n !== null) {
      n.return = t.return, x = n;
      break;
    }
    x = t.return;
  }
}
function Ii(e) {
  for (; x !== null; ) {
    var t = x;
    if (t === e) {
      x = null;
      break;
    }
    var n = t.sibling;
    if (n !== null) {
      n.return = t.return, x = n;
      break;
    }
    x = t.return;
  }
}
function Fi(e) {
  for (; x !== null; ) {
    var t = x;
    try {
      switch (t.tag) {
        case 0:
        case 11:
        case 15:
          var n = t.return;
          try {
            sl(4, t);
          } catch (s) {
            H(t, n, s);
          }
          break;
        case 1:
          var r = t.stateNode;
          if (typeof r.componentDidMount == "function") {
            var l = t.return;
            try {
              r.componentDidMount();
            } catch (s) {
              H(t, l, s);
            }
          }
          var o = t.return;
          try {
            To(t);
          } catch (s) {
            H(t, o, s);
          }
          break;
        case 5:
          var u = t.return;
          try {
            To(t);
          } catch (s) {
            H(t, u, s);
          }
      }
    } catch (s) {
      H(t, t.return, s);
    }
    if (t === e) {
      x = null;
      break;
    }
    var i = t.sibling;
    if (i !== null) {
      i.return = t.return, x = i;
      break;
    }
    x = t.return;
  }
}
var od = Math.ceil, Gr = Ge.ReactCurrentDispatcher, Su = Ge.ReactCurrentOwner, Ce = Ge.ReactCurrentBatchConfig, R = 0, J = null, K = null, b = 0, ve = 0, Wt = mt(0), X = 0, Yn = null, Pt = 0, al = 0, Eu = 0, Ln = null, ae = null, xu = 0, rn = 1 / 0, Be = null, Zr = !1, Oo = null, st = null, hr = !1, nt = null, Jr = 0, Tn = 0, Do = null, zr = -1, Pr = 0;
function ue() {
  return R & 6 ? Q() : zr !== -1 ? zr : zr = Q();
}
function at(e) {
  return e.mode & 1 ? R & 2 && b !== 0 ? b & -b : Af.transition !== null ? (Pr === 0 && (Pr = xs()), Pr) : (e = D, e !== 0 || (e = window.event, e = e === void 0 ? 16 : Ts(e.type)), e) : 1;
}
function Oe(e, t, n, r) {
  if (50 < Tn) throw Tn = 0, Do = null, Error(y(185));
  Gn(e, n, r), (!(R & 2) || e !== J) && (e === J && (!(R & 2) && (al |= n), X === 4 && et(e, b)), pe(e, r), n === 1 && R === 0 && !(t.mode & 1) && (rn = Q() + 500, ol && vt()));
}
function pe(e, t) {
  var n = e.callbackNode;
  Vc(e, t);
  var r = Dr(e, e === J ? b : 0);
  if (r === 0) n !== null && Qu(n), e.callbackNode = null, e.callbackPriority = 0;
  else if (t = r & -r, e.callbackPriority !== t) {
    if (n != null && Qu(n), t === 1) e.tag === 0 ? Vf(ji.bind(null, e)) : Gs(ji.bind(null, e)), jf(function() {
      !(R & 6) && vt();
    }), n = null;
    else {
      switch (Cs(r)) {
        case 1:
          n = Go;
          break;
        case 4:
          n = Ss;
          break;
        case 16:
          n = Or;
          break;
        case 536870912:
          n = Es;
          break;
        default:
          n = Or;
      }
      n = Ya(n, Ba.bind(null, e));
    }
    e.callbackPriority = t, e.callbackNode = n;
  }
}
function Ba(e, t) {
  if (zr = -1, Pr = 0, R & 6) throw Error(y(327));
  var n = e.callbackNode;
  if (Zt() && e.callbackNode !== n) return null;
  var r = Dr(e, e === J ? b : 0);
  if (r === 0) return null;
  if (r & 30 || r & e.expiredLanes || t) t = qr(e, r);
  else {
    t = r;
    var l = R;
    R |= 2;
    var o = Aa();
    (J !== e || b !== t) && (Be = null, rn = Q() + 500, xt(e, t));
    do
      try {
        sd();
        break;
      } catch (i) {
        Va(e, i);
      }
    while (!0);
    su(), Gr.current = o, R = l, K !== null ? t = 0 : (J = null, b = 0, t = X);
  }
  if (t !== 0) {
    if (t === 2 && (l = uo(e), l !== 0 && (r = l, t = Io(e, l))), t === 1) throw n = Yn, xt(e, 0), et(e, r), pe(e, Q()), n;
    if (t === 6) et(e, r);
    else {
      if (l = e.current.alternate, !(r & 30) && !ud(l) && (t = qr(e, r), t === 2 && (o = uo(e), o !== 0 && (r = o, t = Io(e, o))), t === 1)) throw n = Yn, xt(e, 0), et(e, r), pe(e, Q()), n;
      switch (e.finishedWork = l, e.finishedLanes = r, t) {
        case 0:
        case 1:
          throw Error(y(345));
        case 2:
          wt(e, ae, Be);
          break;
        case 3:
          if (et(e, r), (r & 130023424) === r && (t = xu + 500 - Q(), 10 < t)) {
            if (Dr(e, 0) !== 0) break;
            if (l = e.suspendedLanes, (l & r) !== r) {
              ue(), e.pingedLanes |= e.suspendedLanes & l;
              break;
            }
            e.timeoutHandle = vo(wt.bind(null, e, ae, Be), t);
            break;
          }
          wt(e, ae, Be);
          break;
        case 4:
          if (et(e, r), (r & 4194240) === r) break;
          for (t = e.eventTimes, l = -1; 0 < r; ) {
            var u = 31 - Re(r);
            o = 1 << u, u = t[u], u > l && (l = u), r &= ~o;
          }
          if (r = l, r = Q() - r, r = (120 > r ? 120 : 480 > r ? 480 : 1080 > r ? 1080 : 1920 > r ? 1920 : 3e3 > r ? 3e3 : 4320 > r ? 4320 : 1960 * od(r / 1960)) - r, 10 < r) {
            e.timeoutHandle = vo(wt.bind(null, e, ae, Be), r);
            break;
          }
          wt(e, ae, Be);
          break;
        case 5:
          wt(e, ae, Be);
          break;
        default:
          throw Error(y(329));
      }
    }
  }
  return pe(e, Q()), e.callbackNode === n ? Ba.bind(null, e) : null;
}
function Io(e, t) {
  var n = Ln;
  return e.current.memoizedState.isDehydrated && (xt(e, t).flags |= 256), e = qr(e, t), e !== 2 && (t = ae, ae = n, t !== null && Fo(t)), e;
}
function Fo(e) {
  ae === null ? ae = e : ae.push.apply(ae, e);
}
function ud(e) {
  for (var t = e; ; ) {
    if (t.flags & 16384) {
      var n = t.updateQueue;
      if (n !== null && (n = n.stores, n !== null)) for (var r = 0; r < n.length; r++) {
        var l = n[r], o = l.getSnapshot;
        l = l.value;
        try {
          if (!De(o(), l)) return !1;
        } catch {
          return !1;
        }
      }
    }
    if (n = t.child, t.subtreeFlags & 16384 && n !== null) n.return = t, t = n;
    else {
      if (t === e) break;
      for (; t.sibling === null; ) {
        if (t.return === null || t.return === e) return !0;
        t = t.return;
      }
      t.sibling.return = t.return, t = t.sibling;
    }
  }
  return !0;
}
function et(e, t) {
  for (t &= ~Eu, t &= ~al, e.suspendedLanes |= t, e.pingedLanes &= ~t, e = e.expirationTimes; 0 < t; ) {
    var n = 31 - Re(t), r = 1 << n;
    e[n] = -1, t &= ~r;
  }
}
function ji(e) {
  if (R & 6) throw Error(y(327));
  Zt();
  var t = Dr(e, 0);
  if (!(t & 1)) return pe(e, Q()), null;
  var n = qr(e, t);
  if (e.tag !== 0 && n === 2) {
    var r = uo(e);
    r !== 0 && (t = r, n = Io(e, r));
  }
  if (n === 1) throw n = Yn, xt(e, 0), et(e, t), pe(e, Q()), n;
  if (n === 6) throw Error(y(345));
  return e.finishedWork = e.current.alternate, e.finishedLanes = t, wt(e, ae, Be), pe(e, Q()), null;
}
function Cu(e, t) {
  var n = R;
  R |= 1;
  try {
    return e(t);
  } finally {
    R = n, R === 0 && (rn = Q() + 500, ol && vt());
  }
}
function Lt(e) {
  nt !== null && nt.tag === 0 && !(R & 6) && Zt();
  var t = R;
  R |= 1;
  var n = Ce.transition, r = D;
  try {
    if (Ce.transition = null, D = 1, e) return e();
  } finally {
    D = r, Ce.transition = n, R = t, !(R & 6) && vt();
  }
}
function _u() {
  ve = Wt.current, U(Wt);
}
function xt(e, t) {
  e.finishedWork = null, e.finishedLanes = 0;
  var n = e.timeoutHandle;
  if (n !== -1 && (e.timeoutHandle = -1, Ff(n)), K !== null) for (n = K.return; n !== null; ) {
    var r = n;
    switch (ou(r), r.tag) {
      case 1:
        r = r.type.childContextTypes, r != null && $r();
        break;
      case 3:
        tn(), U(fe), U(le), mu();
        break;
      case 5:
        pu(r);
        break;
      case 4:
        tn();
        break;
      case 13:
        U(B);
        break;
      case 19:
        U(B);
        break;
      case 10:
        au(r.type._context);
        break;
      case 22:
      case 23:
        _u();
    }
    n = n.return;
  }
  if (J = e, K = e = ct(e.current, null), b = ve = t, X = 0, Yn = null, Eu = al = Pt = 0, ae = Ln = null, St !== null) {
    for (t = 0; t < St.length; t++) if (n = St[t], r = n.interleaved, r !== null) {
      n.interleaved = null;
      var l = r.next, o = n.pending;
      if (o !== null) {
        var u = o.next;
        o.next = l, r.next = u;
      }
      n.pending = r;
    }
    St = null;
  }
  return e;
}
function Va(e, t) {
  do {
    var n = K;
    try {
      if (su(), Cr.current = Xr, Yr) {
        for (var r = V.memoizedState; r !== null; ) {
          var l = r.queue;
          l !== null && (l.pending = null), r = r.next;
        }
        Yr = !1;
      }
      if (zt = 0, Z = Y = V = null, zn = !1, Wn = 0, Su.current = null, n === null || n.return === null) {
        X = 1, Yn = t, K = null;
        break;
      }
      e: {
        var o = e, u = n.return, i = n, s = t;
        if (t = b, i.flags |= 32768, s !== null && typeof s == "object" && typeof s.then == "function") {
          var c = s, v = i, m = v.tag;
          if (!(v.mode & 1) && (m === 0 || m === 11 || m === 15)) {
            var p = v.alternate;
            p ? (v.updateQueue = p.updateQueue, v.memoizedState = p.memoizedState, v.lanes = p.lanes) : (v.updateQueue = null, v.memoizedState = null);
          }
          var g = Ci(u);
          if (g !== null) {
            g.flags &= -257, _i(g, u, i, o, t), g.mode & 1 && xi(o, c, t), t = g, s = c;
            var k = t.updateQueue;
            if (k === null) {
              var S = /* @__PURE__ */ new Set();
              S.add(s), t.updateQueue = S;
            } else k.add(s);
            break e;
          } else {
            if (!(t & 1)) {
              xi(o, c, t), Nu();
              break e;
            }
            s = Error(y(426));
          }
        } else if ($ && i.mode & 1) {
          var O = Ci(u);
          if (O !== null) {
            !(O.flags & 65536) && (O.flags |= 256), _i(O, u, i, o, t), uu(nn(s, i));
            break e;
          }
        }
        o = s = nn(s, i), X !== 4 && (X = 2), Ln === null ? Ln = [o] : Ln.push(o), o = u;
        do {
          switch (o.tag) {
            case 3:
              o.flags |= 65536, t &= -t, o.lanes |= t;
              var f = Ca(o, s, t);
              yi(o, f);
              break e;
            case 1:
              i = s;
              var a = o.type, d = o.stateNode;
              if (!(o.flags & 128) && (typeof a.getDerivedStateFromError == "function" || d !== null && typeof d.componentDidCatch == "function" && (st === null || !st.has(d)))) {
                o.flags |= 65536, t &= -t, o.lanes |= t;
                var h = _a(o, i, t);
                yi(o, h);
                break e;
              }
          }
          o = o.return;
        } while (o !== null);
      }
      Wa(n);
    } catch (E) {
      t = E, K === n && n !== null && (K = n = n.return);
      continue;
    }
    break;
  } while (!0);
}
function Aa() {
  var e = Gr.current;
  return Gr.current = Xr, e === null ? Xr : e;
}
function Nu() {
  (X === 0 || X === 3 || X === 2) && (X = 4), J === null || !(Pt & 268435455) && !(al & 268435455) || et(J, b);
}
function qr(e, t) {
  var n = R;
  R |= 2;
  var r = Aa();
  (J !== e || b !== t) && (Be = null, xt(e, t));
  do
    try {
      id();
      break;
    } catch (l) {
      Va(e, l);
    }
  while (!0);
  if (su(), R = n, Gr.current = r, K !== null) throw Error(y(261));
  return J = null, b = 0, X;
}
function id() {
  for (; K !== null; ) Ha(K);
}
function sd() {
  for (; K !== null && !Rc(); ) Ha(K);
}
function Ha(e) {
  var t = Ka(e.alternate, e, ve);
  e.memoizedProps = e.pendingProps, t === null ? Wa(e) : K = t, Su.current = null;
}
function Wa(e) {
  var t = e;
  do {
    var n = t.alternate;
    if (e = t.return, t.flags & 32768) {
      if (n = td(n, t), n !== null) {
        n.flags &= 32767, K = n;
        return;
      }
      if (e !== null) e.flags |= 32768, e.subtreeFlags = 0, e.deletions = null;
      else {
        X = 6, K = null;
        return;
      }
    } else if (n = ed(n, t, ve), n !== null) {
      K = n;
      return;
    }
    if (t = t.sibling, t !== null) {
      K = t;
      return;
    }
    K = t = e;
  } while (t !== null);
  X === 0 && (X = 5);
}
function wt(e, t, n) {
  var r = D, l = Ce.transition;
  try {
    Ce.transition = null, D = 1, ad(e, t, n, r);
  } finally {
    Ce.transition = l, D = r;
  }
  return null;
}
function ad(e, t, n, r) {
  do
    Zt();
  while (nt !== null);
  if (R & 6) throw Error(y(327));
  n = e.finishedWork;
  var l = e.finishedLanes;
  if (n === null) return null;
  if (e.finishedWork = null, e.finishedLanes = 0, n === e.current) throw Error(y(177));
  e.callbackNode = null, e.callbackPriority = 0;
  var o = n.lanes | n.childLanes;
  if (Ac(e, o), e === J && (K = J = null, b = 0), !(n.subtreeFlags & 2064) && !(n.flags & 2064) || hr || (hr = !0, Ya(Or, function() {
    return Zt(), null;
  })), o = (n.flags & 15990) !== 0, n.subtreeFlags & 15990 || o) {
    o = Ce.transition, Ce.transition = null;
    var u = D;
    D = 1;
    var i = R;
    R |= 4, Su.current = null, rd(e, n), Ua(n, e), Lf(po), Ir = !!fo, po = fo = null, e.current = n, ld(n), Oc(), R = i, D = u, Ce.transition = o;
  } else e.current = n;
  if (hr && (hr = !1, nt = e, Jr = l), o = e.pendingLanes, o === 0 && (st = null), Fc(n.stateNode), pe(e, Q()), t !== null) for (r = e.onRecoverableError, n = 0; n < t.length; n++) l = t[n], r(l.value, { componentStack: l.stack, digest: l.digest });
  if (Zr) throw Zr = !1, e = Oo, Oo = null, e;
  return Jr & 1 && e.tag !== 0 && Zt(), o = e.pendingLanes, o & 1 ? e === Do ? Tn++ : (Tn = 0, Do = e) : Tn = 0, vt(), null;
}
function Zt() {
  if (nt !== null) {
    var e = Cs(Jr), t = Ce.transition, n = D;
    try {
      if (Ce.transition = null, D = 16 > e ? 16 : e, nt === null) var r = !1;
      else {
        if (e = nt, nt = null, Jr = 0, R & 6) throw Error(y(331));
        var l = R;
        for (R |= 4, x = e.current; x !== null; ) {
          var o = x, u = o.child;
          if (x.flags & 16) {
            var i = o.deletions;
            if (i !== null) {
              for (var s = 0; s < i.length; s++) {
                var c = i[s];
                for (x = c; x !== null; ) {
                  var v = x;
                  switch (v.tag) {
                    case 0:
                    case 11:
                    case 15:
                      Pn(8, v, o);
                  }
                  var m = v.child;
                  if (m !== null) m.return = v, x = m;
                  else for (; x !== null; ) {
                    v = x;
                    var p = v.sibling, g = v.return;
                    if (Ia(v), v === c) {
                      x = null;
                      break;
                    }
                    if (p !== null) {
                      p.return = g, x = p;
                      break;
                    }
                    x = g;
                  }
                }
              }
              var k = o.alternate;
              if (k !== null) {
                var S = k.child;
                if (S !== null) {
                  k.child = null;
                  do {
                    var O = S.sibling;
                    S.sibling = null, S = O;
                  } while (S !== null);
                }
              }
              x = o;
            }
          }
          if (o.subtreeFlags & 2064 && u !== null) u.return = o, x = u;
          else e: for (; x !== null; ) {
            if (o = x, o.flags & 2048) switch (o.tag) {
              case 0:
              case 11:
              case 15:
                Pn(9, o, o.return);
            }
            var f = o.sibling;
            if (f !== null) {
              f.return = o.return, x = f;
              break e;
            }
            x = o.return;
          }
        }
        var a = e.current;
        for (x = a; x !== null; ) {
          u = x;
          var d = u.child;
          if (u.subtreeFlags & 2064 && d !== null) d.return = u, x = d;
          else e: for (u = a; x !== null; ) {
            if (i = x, i.flags & 2048) try {
              switch (i.tag) {
                case 0:
                case 11:
                case 15:
                  sl(9, i);
              }
            } catch (E) {
              H(i, i.return, E);
            }
            if (i === u) {
              x = null;
              break e;
            }
            var h = i.sibling;
            if (h !== null) {
              h.return = i.return, x = h;
              break e;
            }
            x = i.return;
          }
        }
        if (R = l, vt(), Ue && typeof Ue.onPostCommitFiberRoot == "function") try {
          Ue.onPostCommitFiberRoot(el, e);
        } catch {
        }
        r = !0;
      }
      return r;
    } finally {
      D = n, Ce.transition = t;
    }
  }
  return !1;
}
function Ui(e, t, n) {
  t = nn(n, t), t = Ca(e, t, 1), e = it(e, t, 1), t = ue(), e !== null && (Gn(e, 1, t), pe(e, t));
}
function H(e, t, n) {
  if (e.tag === 3) Ui(e, e, n);
  else for (; t !== null; ) {
    if (t.tag === 3) {
      Ui(t, e, n);
      break;
    } else if (t.tag === 1) {
      var r = t.stateNode;
      if (typeof t.type.getDerivedStateFromError == "function" || typeof r.componentDidCatch == "function" && (st === null || !st.has(r))) {
        e = nn(n, e), e = _a(t, e, 1), t = it(t, e, 1), e = ue(), t !== null && (Gn(t, 1, e), pe(t, e));
        break;
      }
    }
    t = t.return;
  }
}
function cd(e, t, n) {
  var r = e.pingCache;
  r !== null && r.delete(t), t = ue(), e.pingedLanes |= e.suspendedLanes & n, J === e && (b & n) === n && (X === 4 || X === 3 && (b & 130023424) === b && 500 > Q() - xu ? xt(e, 0) : Eu |= n), pe(e, t);
}
function Qa(e, t) {
  t === 0 && (e.mode & 1 ? (t = ur, ur <<= 1, !(ur & 130023424) && (ur = 4194304)) : t = 1);
  var n = ue();
  e = Ye(e, t), e !== null && (Gn(e, t, n), pe(e, n));
}
function fd(e) {
  var t = e.memoizedState, n = 0;
  t !== null && (n = t.retryLane), Qa(e, n);
}
function dd(e, t) {
  var n = 0;
  switch (e.tag) {
    case 13:
      var r = e.stateNode, l = e.memoizedState;
      l !== null && (n = l.retryLane);
      break;
    case 19:
      r = e.stateNode;
      break;
    default:
      throw Error(y(314));
  }
  r !== null && r.delete(t), Qa(e, n);
}
var Ka;
Ka = function(e, t, n) {
  if (e !== null) if (e.memoizedProps !== t.pendingProps || fe.current) ce = !0;
  else {
    if (!(e.lanes & n) && !(t.flags & 128)) return ce = !1, bf(e, t, n);
    ce = !!(e.flags & 131072);
  }
  else ce = !1, $ && t.flags & 1048576 && Zs(t, Ar, t.index);
  switch (t.lanes = 0, t.tag) {
    case 2:
      var r = t.type;
      Nr(e, t), e = t.pendingProps;
      var l = qt(t, le.current);
      Gt(t, n), l = hu(null, t, r, e, l, n);
      var o = yu();
      return t.flags |= 1, typeof l == "object" && l !== null && typeof l.render == "function" && l.$$typeof === void 0 ? (t.tag = 1, t.memoizedState = null, t.updateQueue = null, de(r) ? (o = !0, Br(t)) : o = !1, t.memoizedState = l.state !== null && l.state !== void 0 ? l.state : null, fu(t), l.updater = il, t.stateNode = l, l._reactInternals = t, Eo(t, r, e, n), t = _o(null, t, r, !0, o, n)) : (t.tag = 0, $ && o && lu(t), oe(null, t, l, n), t = t.child), t;
    case 16:
      r = t.elementType;
      e: {
        switch (Nr(e, t), e = t.pendingProps, l = r._init, r = l(r._payload), t.type = r, l = t.tag = md(r), e = Le(r, e), l) {
          case 0:
            t = Co(null, t, r, e, n);
            break e;
          case 1:
            t = Pi(null, t, r, e, n);
            break e;
          case 11:
            t = Ni(null, t, r, e, n);
            break e;
          case 14:
            t = zi(null, t, r, Le(r.type, e), n);
            break e;
        }
        throw Error(y(
          306,
          r,
          ""
        ));
      }
      return t;
    case 0:
      return r = t.type, l = t.pendingProps, l = t.elementType === r ? l : Le(r, l), Co(e, t, r, l, n);
    case 1:
      return r = t.type, l = t.pendingProps, l = t.elementType === r ? l : Le(r, l), Pi(e, t, r, l, n);
    case 3:
      e: {
        if (La(t), e === null) throw Error(y(387));
        r = t.pendingProps, o = t.memoizedState, l = o.element, na(e, t), Qr(t, r, null, n);
        var u = t.memoizedState;
        if (r = u.element, o.isDehydrated) if (o = { element: r, isDehydrated: !1, cache: u.cache, pendingSuspenseBoundaries: u.pendingSuspenseBoundaries, transitions: u.transitions }, t.updateQueue.baseState = o, t.memoizedState = o, t.flags & 256) {
          l = nn(Error(y(423)), t), t = Li(e, t, r, n, l);
          break e;
        } else if (r !== l) {
          l = nn(Error(y(424)), t), t = Li(e, t, r, n, l);
          break e;
        } else for (he = ut(t.stateNode.containerInfo.firstChild), ye = t, $ = !0, Me = null, n = ea(t, null, r, n), t.child = n; n; ) n.flags = n.flags & -3 | 4096, n = n.sibling;
        else {
          if (bt(), r === l) {
            t = Xe(e, t, n);
            break e;
          }
          oe(e, t, r, n);
        }
        t = t.child;
      }
      return t;
    case 5:
      return ra(t), e === null && wo(t), r = t.type, l = t.pendingProps, o = e !== null ? e.memoizedProps : null, u = l.children, mo(r, l) ? u = null : o !== null && mo(r, o) && (t.flags |= 32), Pa(e, t), oe(e, t, u, n), t.child;
    case 6:
      return e === null && wo(t), null;
    case 13:
      return Ta(e, t, n);
    case 4:
      return du(t, t.stateNode.containerInfo), r = t.pendingProps, e === null ? t.child = en(t, null, r, n) : oe(e, t, r, n), t.child;
    case 11:
      return r = t.type, l = t.pendingProps, l = t.elementType === r ? l : Le(r, l), Ni(e, t, r, l, n);
    case 7:
      return oe(e, t, t.pendingProps, n), t.child;
    case 8:
      return oe(e, t, t.pendingProps.children, n), t.child;
    case 12:
      return oe(e, t, t.pendingProps.children, n), t.child;
    case 10:
      e: {
        if (r = t.type._context, l = t.pendingProps, o = t.memoizedProps, u = l.value, I(Hr, r._currentValue), r._currentValue = u, o !== null) if (De(o.value, u)) {
          if (o.children === l.children && !fe.current) {
            t = Xe(e, t, n);
            break e;
          }
        } else for (o = t.child, o !== null && (o.return = t); o !== null; ) {
          var i = o.dependencies;
          if (i !== null) {
            u = o.child;
            for (var s = i.firstContext; s !== null; ) {
              if (s.context === r) {
                if (o.tag === 1) {
                  s = We(-1, n & -n), s.tag = 2;
                  var c = o.updateQueue;
                  if (c !== null) {
                    c = c.shared;
                    var v = c.pending;
                    v === null ? s.next = s : (s.next = v.next, v.next = s), c.pending = s;
                  }
                }
                o.lanes |= n, s = o.alternate, s !== null && (s.lanes |= n), ko(
                  o.return,
                  n,
                  t
                ), i.lanes |= n;
                break;
              }
              s = s.next;
            }
          } else if (o.tag === 10) u = o.type === t.type ? null : o.child;
          else if (o.tag === 18) {
            if (u = o.return, u === null) throw Error(y(341));
            u.lanes |= n, i = u.alternate, i !== null && (i.lanes |= n), ko(u, n, t), u = o.sibling;
          } else u = o.child;
          if (u !== null) u.return = o;
          else for (u = o; u !== null; ) {
            if (u === t) {
              u = null;
              break;
            }
            if (o = u.sibling, o !== null) {
              o.return = u.return, u = o;
              break;
            }
            u = u.return;
          }
          o = u;
        }
        oe(e, t, l.children, n), t = t.child;
      }
      return t;
    case 9:
      return l = t.type, r = t.pendingProps.children, Gt(t, n), l = _e(l), r = r(l), t.flags |= 1, oe(e, t, r, n), t.child;
    case 14:
      return r = t.type, l = Le(r, t.pendingProps), l = Le(r.type, l), zi(e, t, r, l, n);
    case 15:
      return Na(e, t, t.type, t.pendingProps, n);
    case 17:
      return r = t.type, l = t.pendingProps, l = t.elementType === r ? l : Le(r, l), Nr(e, t), t.tag = 1, de(r) ? (e = !0, Br(t)) : e = !1, Gt(t, n), xa(t, r, l), Eo(t, r, l, n), _o(null, t, r, !0, e, n);
    case 19:
      return Ma(e, t, n);
    case 22:
      return za(e, t, n);
  }
  throw Error(y(156, t.tag));
};
function Ya(e, t) {
  return ks(e, t);
}
function pd(e, t, n, r) {
  this.tag = e, this.key = n, this.sibling = this.child = this.return = this.stateNode = this.type = this.elementType = null, this.index = 0, this.ref = null, this.pendingProps = t, this.dependencies = this.memoizedState = this.updateQueue = this.memoizedProps = null, this.mode = r, this.subtreeFlags = this.flags = 0, this.deletions = null, this.childLanes = this.lanes = 0, this.alternate = null;
}
function xe(e, t, n, r) {
  return new pd(e, t, n, r);
}
function zu(e) {
  return e = e.prototype, !(!e || !e.isReactComponent);
}
function md(e) {
  if (typeof e == "function") return zu(e) ? 1 : 0;
  if (e != null) {
    if (e = e.$$typeof, e === Ko) return 11;
    if (e === Yo) return 14;
  }
  return 2;
}
function ct(e, t) {
  var n = e.alternate;
  return n === null ? (n = xe(e.tag, t, e.key, e.mode), n.elementType = e.elementType, n.type = e.type, n.stateNode = e.stateNode, n.alternate = e, e.alternate = n) : (n.pendingProps = t, n.type = e.type, n.flags = 0, n.subtreeFlags = 0, n.deletions = null), n.flags = e.flags & 14680064, n.childLanes = e.childLanes, n.lanes = e.lanes, n.child = e.child, n.memoizedProps = e.memoizedProps, n.memoizedState = e.memoizedState, n.updateQueue = e.updateQueue, t = e.dependencies, n.dependencies = t === null ? null : { lanes: t.lanes, firstContext: t.firstContext }, n.sibling = e.sibling, n.index = e.index, n.ref = e.ref, n;
}
function Lr(e, t, n, r, l, o) {
  var u = 2;
  if (r = e, typeof e == "function") zu(e) && (u = 1);
  else if (typeof e == "string") u = 5;
  else e: switch (e) {
    case Dt:
      return Ct(n.children, l, o, t);
    case Qo:
      u = 8, l |= 8;
      break;
    case Ql:
      return e = xe(12, n, t, l | 2), e.elementType = Ql, e.lanes = o, e;
    case Kl:
      return e = xe(13, n, t, l), e.elementType = Kl, e.lanes = o, e;
    case Yl:
      return e = xe(19, n, t, l), e.elementType = Yl, e.lanes = o, e;
    case rs:
      return cl(n, l, o, t);
    default:
      if (typeof e == "object" && e !== null) switch (e.$$typeof) {
        case ts:
          u = 10;
          break e;
        case ns:
          u = 9;
          break e;
        case Ko:
          u = 11;
          break e;
        case Yo:
          u = 14;
          break e;
        case Je:
          u = 16, r = null;
          break e;
      }
      throw Error(y(130, e == null ? e : typeof e, ""));
  }
  return t = xe(u, n, t, l), t.elementType = e, t.type = r, t.lanes = o, t;
}
function Ct(e, t, n, r) {
  return e = xe(7, e, r, t), e.lanes = n, e;
}
function cl(e, t, n, r) {
  return e = xe(22, e, r, t), e.elementType = rs, e.lanes = n, e.stateNode = { isHidden: !1 }, e;
}
function Al(e, t, n) {
  return e = xe(6, e, null, t), e.lanes = n, e;
}
function Hl(e, t, n) {
  return t = xe(4, e.children !== null ? e.children : [], e.key, t), t.lanes = n, t.stateNode = { containerInfo: e.containerInfo, pendingChildren: null, implementation: e.implementation }, t;
}
function vd(e, t, n, r, l) {
  this.tag = t, this.containerInfo = e, this.finishedWork = this.pingCache = this.current = this.pendingChildren = null, this.timeoutHandle = -1, this.callbackNode = this.pendingContext = this.context = null, this.callbackPriority = 0, this.eventTimes = xl(0), this.expirationTimes = xl(-1), this.entangledLanes = this.finishedLanes = this.mutableReadLanes = this.expiredLanes = this.pingedLanes = this.suspendedLanes = this.pendingLanes = 0, this.entanglements = xl(0), this.identifierPrefix = r, this.onRecoverableError = l, this.mutableSourceEagerHydrationData = null;
}
function Pu(e, t, n, r, l, o, u, i, s) {
  return e = new vd(e, t, n, i, s), t === 1 ? (t = 1, o === !0 && (t |= 8)) : t = 0, o = xe(3, null, null, t), e.current = o, o.stateNode = e, o.memoizedState = { element: r, isDehydrated: n, cache: null, transitions: null, pendingSuspenseBoundaries: null }, fu(o), e;
}
function hd(e, t, n) {
  var r = 3 < arguments.length && arguments[3] !== void 0 ? arguments[3] : null;
  return { $$typeof: Ot, key: r == null ? null : "" + r, children: e, containerInfo: t, implementation: n };
}
function Xa(e) {
  if (!e) return dt;
  e = e._reactInternals;
  e: {
    if (Mt(e) !== e || e.tag !== 1) throw Error(y(170));
    var t = e;
    do {
      switch (t.tag) {
        case 3:
          t = t.stateNode.context;
          break e;
        case 1:
          if (de(t.type)) {
            t = t.stateNode.__reactInternalMemoizedMergedChildContext;
            break e;
          }
      }
      t = t.return;
    } while (t !== null);
    throw Error(y(171));
  }
  if (e.tag === 1) {
    var n = e.type;
    if (de(n)) return Xs(e, n, t);
  }
  return t;
}
function Ga(e, t, n, r, l, o, u, i, s) {
  return e = Pu(n, r, !0, e, l, o, u, i, s), e.context = Xa(null), n = e.current, r = ue(), l = at(n), o = We(r, l), o.callback = t ?? null, it(n, o, l), e.current.lanes = l, Gn(e, l, r), pe(e, r), e;
}
function fl(e, t, n, r) {
  var l = t.current, o = ue(), u = at(l);
  return n = Xa(n), t.context === null ? t.context = n : t.pendingContext = n, t = We(o, u), t.payload = { element: e }, r = r === void 0 ? null : r, r !== null && (t.callback = r), e = it(l, t, u), e !== null && (Oe(e, l, u, o), xr(e, l, u)), u;
}
function br(e) {
  if (e = e.current, !e.child) return null;
  switch (e.child.tag) {
    case 5:
      return e.child.stateNode;
    default:
      return e.child.stateNode;
  }
}
function $i(e, t) {
  if (e = e.memoizedState, e !== null && e.dehydrated !== null) {
    var n = e.retryLane;
    e.retryLane = n !== 0 && n < t ? n : t;
  }
}
function Lu(e, t) {
  $i(e, t), (e = e.alternate) && $i(e, t);
}
function yd() {
  return null;
}
var Za = typeof reportError == "function" ? reportError : function(e) {
  console.error(e);
};
function Tu(e) {
  this._internalRoot = e;
}
dl.prototype.render = Tu.prototype.render = function(e) {
  var t = this._internalRoot;
  if (t === null) throw Error(y(409));
  fl(e, t, null, null);
};
dl.prototype.unmount = Tu.prototype.unmount = function() {
  var e = this._internalRoot;
  if (e !== null) {
    this._internalRoot = null;
    var t = e.containerInfo;
    Lt(function() {
      fl(null, e, null, null);
    }), t[Ke] = null;
  }
};
function dl(e) {
  this._internalRoot = e;
}
dl.prototype.unstable_scheduleHydration = function(e) {
  if (e) {
    var t = zs();
    e = { blockedOn: null, target: e, priority: t };
    for (var n = 0; n < be.length && t !== 0 && t < be[n].priority; n++) ;
    be.splice(n, 0, e), n === 0 && Ls(e);
  }
};
function Mu(e) {
  return !(!e || e.nodeType !== 1 && e.nodeType !== 9 && e.nodeType !== 11);
}
function pl(e) {
  return !(!e || e.nodeType !== 1 && e.nodeType !== 9 && e.nodeType !== 11 && (e.nodeType !== 8 || e.nodeValue !== " react-mount-point-unstable "));
}
function Bi() {
}
function gd(e, t, n, r, l) {
  if (l) {
    if (typeof r == "function") {
      var o = r;
      r = function() {
        var c = br(u);
        o.call(c);
      };
    }
    var u = Ga(t, r, e, 0, null, !1, !1, "", Bi);
    return e._reactRootContainer = u, e[Ke] = u.current, $n(e.nodeType === 8 ? e.parentNode : e), Lt(), u;
  }
  for (; l = e.lastChild; ) e.removeChild(l);
  if (typeof r == "function") {
    var i = r;
    r = function() {
      var c = br(s);
      i.call(c);
    };
  }
  var s = Pu(e, 0, !1, null, null, !1, !1, "", Bi);
  return e._reactRootContainer = s, e[Ke] = s.current, $n(e.nodeType === 8 ? e.parentNode : e), Lt(function() {
    fl(t, s, n, r);
  }), s;
}
function ml(e, t, n, r, l) {
  var o = n._reactRootContainer;
  if (o) {
    var u = o;
    if (typeof l == "function") {
      var i = l;
      l = function() {
        var s = br(u);
        i.call(s);
      };
    }
    fl(t, u, e, l);
  } else u = gd(n, t, e, l, r);
  return br(u);
}
_s = function(e) {
  switch (e.tag) {
    case 3:
      var t = e.stateNode;
      if (t.current.memoizedState.isDehydrated) {
        var n = kn(t.pendingLanes);
        n !== 0 && (Zo(t, n | 1), pe(t, Q()), !(R & 6) && (rn = Q() + 500, vt()));
      }
      break;
    case 13:
      Lt(function() {
        var r = Ye(e, 1);
        if (r !== null) {
          var l = ue();
          Oe(r, e, 1, l);
        }
      }), Lu(e, 1);
  }
};
Jo = function(e) {
  if (e.tag === 13) {
    var t = Ye(e, 134217728);
    if (t !== null) {
      var n = ue();
      Oe(t, e, 134217728, n);
    }
    Lu(e, 134217728);
  }
};
Ns = function(e) {
  if (e.tag === 13) {
    var t = at(e), n = Ye(e, t);
    if (n !== null) {
      var r = ue();
      Oe(n, e, t, r);
    }
    Lu(e, t);
  }
};
zs = function() {
  return D;
};
Ps = function(e, t) {
  var n = D;
  try {
    return D = e, t();
  } finally {
    D = n;
  }
};
ro = function(e, t, n) {
  switch (t) {
    case "input":
      if (Zl(e, n), t = n.name, n.type === "radio" && t != null) {
        for (n = e; n.parentNode; ) n = n.parentNode;
        for (n = n.querySelectorAll("input[name=" + JSON.stringify("" + t) + '][type="radio"]'), t = 0; t < n.length; t++) {
          var r = n[t];
          if (r !== e && r.form === e.form) {
            var l = ll(r);
            if (!l) throw Error(y(90));
            os(r), Zl(r, l);
          }
        }
      }
      break;
    case "textarea":
      is(e, n);
      break;
    case "select":
      t = n.value, t != null && Qt(e, !!n.multiple, t, !1);
  }
};
ms = Cu;
vs = Lt;
var wd = { usingClientEntryPoint: !1, Events: [Jn, Ut, ll, ds, ps, Cu] }, yn = { findFiberByHostInstance: kt, bundleType: 0, version: "18.3.1", rendererPackageName: "react-dom" }, kd = { bundleType: yn.bundleType, version: yn.version, rendererPackageName: yn.rendererPackageName, rendererConfig: yn.rendererConfig, overrideHookState: null, overrideHookStateDeletePath: null, overrideHookStateRenamePath: null, overrideProps: null, overridePropsDeletePath: null, overridePropsRenamePath: null, setErrorHandler: null, setSuspenseHandler: null, scheduleUpdate: null, currentDispatcherRef: Ge.ReactCurrentDispatcher, findHostInstanceByFiber: function(e) {
  return e = gs(e), e === null ? null : e.stateNode;
}, findFiberByHostInstance: yn.findFiberByHostInstance || yd, findHostInstancesForRefresh: null, scheduleRefresh: null, scheduleRoot: null, setRefreshHandler: null, getCurrentFiber: null, reconcilerVersion: "18.3.1-next-f1338f8080-20240426" };
if (typeof __REACT_DEVTOOLS_GLOBAL_HOOK__ < "u") {
  var yr = __REACT_DEVTOOLS_GLOBAL_HOOK__;
  if (!yr.isDisabled && yr.supportsFiber) try {
    el = yr.inject(kd), Ue = yr;
  } catch {
  }
}
we.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED = wd;
we.createPortal = function(e, t) {
  var n = 2 < arguments.length && arguments[2] !== void 0 ? arguments[2] : null;
  if (!Mu(t)) throw Error(y(200));
  return hd(e, t, null, n);
};
we.createRoot = function(e, t) {
  if (!Mu(e)) throw Error(y(299));
  var n = !1, r = "", l = Za;
  return t != null && (t.unstable_strictMode === !0 && (n = !0), t.identifierPrefix !== void 0 && (r = t.identifierPrefix), t.onRecoverableError !== void 0 && (l = t.onRecoverableError)), t = Pu(e, 1, !1, null, null, n, !1, r, l), e[Ke] = t.current, $n(e.nodeType === 8 ? e.parentNode : e), new Tu(t);
};
we.findDOMNode = function(e) {
  if (e == null) return null;
  if (e.nodeType === 1) return e;
  var t = e._reactInternals;
  if (t === void 0)
    throw typeof e.render == "function" ? Error(y(188)) : (e = Object.keys(e).join(","), Error(y(268, e)));
  return e = gs(t), e = e === null ? null : e.stateNode, e;
};
we.flushSync = function(e) {
  return Lt(e);
};
we.hydrate = function(e, t, n) {
  if (!pl(t)) throw Error(y(200));
  return ml(null, e, t, !0, n);
};
we.hydrateRoot = function(e, t, n) {
  if (!Mu(e)) throw Error(y(405));
  var r = n != null && n.hydratedSources || null, l = !1, o = "", u = Za;
  if (n != null && (n.unstable_strictMode === !0 && (l = !0), n.identifierPrefix !== void 0 && (o = n.identifierPrefix), n.onRecoverableError !== void 0 && (u = n.onRecoverableError)), t = Ga(t, null, e, 1, n ?? null, l, !1, o, u), e[Ke] = t.current, $n(e), r) for (e = 0; e < r.length; e++) n = r[e], l = n._getVersion, l = l(n._source), t.mutableSourceEagerHydrationData == null ? t.mutableSourceEagerHydrationData = [n, l] : t.mutableSourceEagerHydrationData.push(
    n,
    l
  );
  return new dl(t);
};
we.render = function(e, t, n) {
  if (!pl(t)) throw Error(y(200));
  return ml(null, e, t, !1, n);
};
we.unmountComponentAtNode = function(e) {
  if (!pl(e)) throw Error(y(40));
  return e._reactRootContainer ? (Lt(function() {
    ml(null, null, e, !1, function() {
      e._reactRootContainer = null, e[Ke] = null;
    });
  }), !0) : !1;
};
we.unstable_batchedUpdates = Cu;
we.unstable_renderSubtreeIntoContainer = function(e, t, n, r) {
  if (!pl(n)) throw Error(y(200));
  if (e == null || e._reactInternals === void 0) throw Error(y(38));
  return ml(e, t, n, !1, r);
};
we.version = "18.3.1-next-f1338f8080-20240426";
function Ja() {
  if (!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__ > "u" || typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE != "function"))
    try {
      __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(Ja);
    } catch (e) {
      console.error(e);
    }
}
Ja(), Ji.exports = we;
var Sd = Ji.exports, qa, Vi = Sd;
qa = Vi.createRoot, Vi.hydrateRoot;
let ba = w.createContext(
  /** @type {any} */
  null
);
function Ed() {
  let e = w.useContext(ba);
  if (!e) throw new Error("RenderContext not found");
  return e;
}
function xd() {
  return Ed().model;
}
function me(e) {
  let t = xd(), [n, r] = w.useState(t.get(e));
  return w.useEffect(() => {
    let l = () => r(t.get(e));
    return t.on(`change:${e}`, l), () => t.off(`change:${e}`, l);
  }, [t, e]), [
    n,
    (l) => {
      t.set(e, l), t.save_changes();
    }
  ];
}
function Cd(e) {
  return ({ el: t, model: n, experimental: r }) => {
    let l = qa(t);
    return l.render(
      w.createElement(
        w.StrictMode,
        null,
        w.createElement(
          ba.Provider,
          { value: { model: n, experimental: r } },
          w.createElement(e)
        )
      )
    ), () => l.unmount();
  };
}
function jo({ tooltip: e }) {
  return /* @__PURE__ */ w.createElement("span", { className: "tooltip-icon ml-1.5", "data-tooltip": e }, /* @__PURE__ */ w.createElement(
    "svg",
    {
      xmlns: "http://www.w3.org/2000/svg",
      width: "16",
      height: "16",
      viewBox: "0 0 24 24",
      fill: "none",
      stroke: "currentColor",
      strokeWidth: "2",
      strokeLinecap: "round",
      strokeLinejoin: "round"
    },
    /* @__PURE__ */ w.createElement("circle", { cx: "12", cy: "12", r: "10" }),
    /* @__PURE__ */ w.createElement("line", { x1: "12", y1: "16", x2: "12", y2: "12" }),
    /* @__PURE__ */ w.createElement("line", { x1: "12", y1: "8", x2: "12.01", y2: "8" })
  ));
}
function _d({
  value: e,
  uiLabel: t,
  uiTooltip: n,
  fitToContent: r = !1,
  labelInline: l = !0
}) {
  const o = Math.min(Math.max(e, 0), 100);
  return /* @__PURE__ */ w.createElement("div", { className: `input-container progress-bar-container ${r ? "fit-to-content" : ""} ${l ? "label-inline" : ""}` }, t && !l && /* @__PURE__ */ w.createElement("label", { className: "input-label progress-label" }, /* @__PURE__ */ w.createElement("span", null, t), n && /* @__PURE__ */ w.createElement(jo, { tooltip: n })), /* @__PURE__ */ w.createElement("div", { className: "input-wrapper progress-track-container" }, t && l && /* @__PURE__ */ w.createElement("label", { className: "input-label progress-label" }, /* @__PURE__ */ w.createElement("span", null, t), n && /* @__PURE__ */ w.createElement(jo, { tooltip: n })), /* @__PURE__ */ w.createElement(
    "div",
    {
      className: "progress-track",
      role: "progressbar",
      "aria-valuenow": o,
      "aria-valuemin": 0,
      "aria-valuemax": 100
    },
    /* @__PURE__ */ w.createElement(
      "div",
      {
        className: "progress-fill",
        style: { width: `${o}%` }
      }
    )
  ), /* @__PURE__ */ w.createElement("div", { className: "progress-value" }, Math.round(o), "%")));
}
function Nd({
  label: e,
  tooltip: t,
  onClick: n,
  disabled: r = !1,
  value: l = !1,
  className: o = "",
  icon: u,
  variant: i = "default",
  fitToContent: s = !1
}) {
  const c = o || (i === "process-step" ? "relative w-16 h-16 rounded-full bg-white/20 border border-white/10 transition-all group" : `widget-button${s ? " fit-to-content" : ""}`);
  return /* @__PURE__ */ w.createElement("div", { className: `button-container${s ? " fit-to-content" : ""}` }, /* @__PURE__ */ w.createElement(
    "button",
    {
      className: c,
      onClick: n,
      disabled: r,
      title: t
    },
    i === "process-step" ? /* @__PURE__ */ w.createElement("span", { className: "absolute inset-0 flex items-center justify-center" }, u || e) : /* @__PURE__ */ w.createElement(w.Fragment, null, u && /* @__PURE__ */ w.createElement("span", { className: "button-icon" }, u), e)
  ));
}
function zd({
  value: e,
  uiLabel: t,
  uiTooltip: n,
  onChange: r
}) {
  return /* @__PURE__ */ w.createElement("div", { className: "checkbox-container" }, /* @__PURE__ */ w.createElement("label", { className: "checkbox-label" }, /* @__PURE__ */ w.createElement(
    "input",
    {
      type: "checkbox",
      checked: e,
      onChange: (l) => r(l.target.checked),
      className: "checkbox-input"
    }
  ), /* @__PURE__ */ w.createElement("span", null, t), n && /* @__PURE__ */ w.createElement(jo, { tooltip: n })));
}
function Pd({
  isOpen: e,
  onClose: t,
  taskName: n,
  progress: r,
  logs: l = [],
  error: o,
  autoScroll: u = !0
}) {
  const i = w.useRef(null), [s, c] = w.useState(u);
  if (w.useEffect(() => {
    s && i.current && (i.current.scrollTop = i.current.scrollHeight);
  }, [l, s]), !e) return null;
  const v = (g) => {
    g.target === g.currentTarget && t();
  }, m = (g) => {
    try {
      return new Date(g).toLocaleTimeString([], { hour12: !1 });
    } catch {
      return g;
    }
  }, p = (g) => {
    switch (g.toLowerCase()) {
      case "error":
        return "text-red-500";
      case "warning":
        return "text-yellow-500";
      case "success":
        return "text-green-500";
      default:
        return "text-blue-500";
    }
  };
  return /* @__PURE__ */ w.createElement(
    "div",
    {
      className: "fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center z-50",
      onClick: v
    },
    /* @__PURE__ */ w.createElement("div", { className: "bg-white rounded-lg shadow-xl w-full max-w-2xl mx-4 max-h-[90vh] flex flex-col border-2 border-gray-300" }, /* @__PURE__ */ w.createElement("div", { className: "p-6 flex flex-col h-full" }, /* @__PURE__ */ w.createElement("h2", { className: "text-xl font-semibold text-gray-900 mb-4 text-center" }, n), /* @__PURE__ */ w.createElement("div", { className: "w-full mb-6" }, /* @__PURE__ */ w.createElement(_d, { value: r * 100 })), o && o.message && /* @__PURE__ */ w.createElement("div", { className: "bg-red-50 rounded-lg p-4 border border-red-200 mb-6" }, o.timestamp && /* @__PURE__ */ w.createElement("p", { className: "text-red-500 text-xs mb-2" }, m(o.timestamp)), /* @__PURE__ */ w.createElement("div", { className: "flex items-start gap-3" }, /* @__PURE__ */ w.createElement("svg", { className: "w-6 h-6 text-red-600 mt-0.5", viewBox: "0 0 20 20", fill: "currentColor" }, /* @__PURE__ */ w.createElement("path", { fillRule: "evenodd", d: "M10 18a8 8 0 100-16 8 8 0 000 16zM8.28 7.22a.75.75 0 00-1.06 1.06L8.94 10l-1.72 1.72a.75.75 0 101.06 1.06L10 11.06l1.72 1.72a.75.75 0 101.06-1.06L11.06 10l1.72-1.72a.75.75 0 00-1.06-1.06L10 8.94 8.28 7.22z", clipRule: "evenodd" })), /* @__PURE__ */ w.createElement("div", { className: "flex-1" }, /* @__PURE__ */ w.createElement("p", { className: "text-red-700 font-medium text-sm" }, typeof o.message == "object" ? JSON.stringify(o.message) : o.message), o.traceback && /* @__PURE__ */ w.createElement("pre", { className: "mt-2 text-red-600 text-xs font-mono whitespace-pre-wrap overflow-x-auto" }, o.traceback)))), /* @__PURE__ */ w.createElement(
      "div",
      {
        ref: i,
        className: "bg-gray-50 rounded-lg p-4 overflow-y-auto border border-gray-200 mb-6",
        style: {
          height: "500px",
          lineHeight: "25px"
        }
      },
      l.slice(-100).map(([g, k, S, O], f) => /* @__PURE__ */ w.createElement("div", { key: f, className: "py-1 font-mono text-xs flex gap-2 h-[25px] items-center" }, /* @__PURE__ */ w.createElement("span", { className: "text-gray-400" }, m(g)), /* @__PURE__ */ w.createElement("span", { className: `font-medium ${p(k)}` }, "[", k, "]"), /* @__PURE__ */ w.createElement("span", { className: "text-gray-500" }, S, ":"), /* @__PURE__ */ w.createElement("span", { className: "text-gray-700" }, O)))
    ), /* @__PURE__ */ w.createElement("div", { className: "flex items-center justify-between mt-auto" }, /* @__PURE__ */ w.createElement(
      zd,
      {
        value: s,
        onChange: (g) => c(g),
        uiLabel: "Auto-scroll"
      }
    ), /* @__PURE__ */ w.createElement(
      Nd,
      {
        label: "Close",
        tooltip: "Close the task details",
        onClick: t
      }
    ))))
  );
}
function Ld({
  isRunning: e,
  isCompleted: t,
  isFailed: n,
  isDisabled: r,
  started: l,
  progress: o,
  onStart: u,
  onStop: i,
  onReset: s,
  onExpand: c = () => {
  },
  taskName: v,
  error: m,
  logs: p = []
}) {
  const f = 2 * Math.PI * 18.5, a = f * (1 - o), [d, h] = w.useState(!1), [E, _] = w.useState(!1), N = () => r ? "disabled" : t ? "completed" : n ? "failed" : e ? "running" : "idle", z = () => {
    if (e)
      i();
    else if (t || n || l && !e) {
      s();
      return;
    } else l || u();
  }, F = () => {
    _(!0), c == null || c();
  }, T = () => t ? "completed" : n ? "failed" : e ? "running" : "idle";
  return /* @__PURE__ */ w.createElement("div", { className: "task-button-wrapper" }, /* @__PURE__ */ w.createElement(
    "button",
    {
      className: `task-button ${N()} ${d ? "hovering" : ""}`,
      onClick: z,
      onMouseEnter: () => h(!0),
      onMouseLeave: () => h(!1),
      style: { width: 40, height: 40 },
      disabled: r
    },
    /* @__PURE__ */ w.createElement(
      "svg",
      {
        className: "progress-ring",
        width: 40,
        height: 40
      },
      /* @__PURE__ */ w.createElement(
        "circle",
        {
          className: "progress-ring-background",
          strokeWidth: 3,
          fill: "none",
          r: 18.5,
          cx: 20,
          cy: 20
        }
      ),
      /* @__PURE__ */ w.createElement(
        "circle",
        {
          className: "progress-ring-circle",
          strokeWidth: 3,
          strokeLinecap: "round",
          fill: "none",
          r: 18.5,
          cx: 20,
          cy: 20,
          style: {
            strokeDasharray: `${f} ${f}`,
            strokeDashoffset: a
          }
        }
      )
    ),
    /* @__PURE__ */ w.createElement("div", { className: "button-icon" }, (t || n) && d ? /* @__PURE__ */ w.createElement("svg", { viewBox: "0 0 24 24", fill: "currentColor", className: "reset-icon" }, /* @__PURE__ */ w.createElement("path", { d: "M17.65 6.35C16.2 4.9 14.21 4 12 4c-4.42 0-7.99 3.58-7.99 8s3.57 8 7.99 8c3.73 0 6.84-2.55 7.73-6h-2.08c-.82 2.33-3.04 4-5.65 4-3.31 0-6-2.69-6-6s2.69-6 6-6c1.66 0 3.14.69 4.22 1.78L13 11h7V4l-2.35 2.35z" })) : t ? /* @__PURE__ */ w.createElement("svg", { viewBox: "0 0 24 24", fill: "currentColor", className: "check-icon" }, /* @__PURE__ */ w.createElement("path", { d: "M9 16.17L4.83 12l-1.42 1.41L9 19 21 7l-1.41-1.41z" })) : n ? /* @__PURE__ */ w.createElement("svg", { viewBox: "0 0 24 24", fill: "currentColor", className: "x-icon" }, /* @__PURE__ */ w.createElement("path", { d: "M19 6.41L17.59 5 12 10.59 6.41 5 5 6.41 10.59 12 5 17.59 6.41 19 12 13.41 17.59 19 19 17.59 13.41 12z" })) : e ? /* @__PURE__ */ w.createElement("svg", { viewBox: "0 0 24 24", fill: "currentColor", className: "stop-icon" }, /* @__PURE__ */ w.createElement("path", { d: "M7 7h10v10H7z" })) : l && !e && !t && !n ? /* @__PURE__ */ w.createElement("svg", { viewBox: "0 0 24 24", fill: "currentColor", className: "reset-icon" }, /* @__PURE__ */ w.createElement("path", { d: "M17.65 6.35C16.2 4.9 14.21 4 12 4c-4.42 0-7.99 3.58-7.99 8s3.57 8 7.99 8c3.73 0 6.84-2.55 7.73-6h-2.08c-.82 2.33-3.04 4-5.65 4-3.31 0-6-2.69-6-6s2.69-6 6-6c1.66 0 3.14.69 4.22 1.78L13 11h7V4l-2.35 2.35z" })) : /* @__PURE__ */ w.createElement("svg", { viewBox: "0 0 24 24", fill: "currentColor", className: "play-icon" }, /* @__PURE__ */ w.createElement("path", { d: "M8 5v14l11-7z" })))
  ), /* @__PURE__ */ w.createElement(
    "button",
    {
      className: "expand-button",
      onClick: F,
      disabled: r
    },
    /* @__PURE__ */ w.createElement("svg", { viewBox: "0 0 24 24", fill: "currentColor", className: "expand-icon" }, /* @__PURE__ */ w.createElement("path", { d: "M11 7h2v2h-2zm0 4h2v6h-2zm1-9C6.48 2 2 6.48 2 12s4.48 10 10 10 10-4.48 10-10S17.52 2 12 2zm0 18c-4.41 0-8-3.59-8-8s3.59-8 8-8 8 3.59 8 8-3.59 8-8 8z" }))
  ), /* @__PURE__ */ w.createElement(
    Pd,
    {
      isOpen: E,
      onClose: () => _(!1),
      taskName: v,
      progress: o,
      status: T(),
      logs: p,
      error: m,
      onStart: u,
      onStop: i,
      onReset: s
    }
  ));
}
function Td() {
  const [e, t] = me("is_running"), [n, r] = me("is_completed"), [l, o] = me("is_failed"), [u] = me("is_disabled"), [i, s] = me("started"), [c, v] = me("progress"), [m, p] = me("logs"), [g] = me("error"), [k, S] = me("last_sync"), [O] = me("sync_enabled"), [f] = me("sync_interval"), [a, d] = me("reset_flag"), [h, E] = me("stopped");
  w.useEffect(() => {
    if (O) {
      const F = setInterval(() => {
        S(Date.now() / 1e3);
      }, f * 1e3);
      return () => clearInterval(F);
    }
  }, [O, S]);
  const _ = async () => {
    console.log("Resetting task"), console.log(a), d(!0);
  }, N = () => {
    !e && !u && s(!0);
  }, z = () => {
    E(!0);
  };
  return /* @__PURE__ */ w.createElement(
    Ld,
    {
      isRunning: e,
      isCompleted: n,
      isFailed: l,
      isDisabled: u,
      started: i,
      progress: c,
      onStart: N,
      onStop: z,
      onReset: _,
      taskName: "Task",
      error: g ?? void 0,
      logs: m || []
    }
  );
}
const Md = {
  render: Cd(Td)
};
export {
  Md as default
};
